/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006, 2009
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/** ============================================================================
 *   @file  Intc_setup.c
 *
 *   @path  $(CSLPATH)\example\emac\emac_dual_emac\src
 *
 *   @brief  EMAC CSL Example support file for interrupts configuration
 */

/* =============================================================================
 *  Revision History
 *  ===============
 *  16-Mar-06 PSk  file created
 *  18-August-08   modified for supporting dual EMAC
 * =============================================================================
 */

#include <stdio.h>
#include <soc.h> 
#include <csl_tmr.h>
#include <csl_intc.h>
 

extern void interrupt TimerTick(void);
extern void interrupt Hw0RxInt(void);
extern void interrupt Hw0TxInt(void);
extern void interrupt Hw1RxInt(void);
extern void interrupt Hw1TxInt(void);

 
/****** Static variable declarations ***********/
 
/* Intc objects */
static CSL_IntcContext context;
static CSL_IntcEventHandlerRecord Record[13];
 
/* timer interrupt object */
static CSL_IntcObj intcTimer;
static CSL_IntcObj intcEMACRx;
static CSL_IntcObj intcEMACTx;

static CSL_IntcHandle hIntcTimer; 
static CSL_IntcHandle hIntcEMAC0Rx; 
static CSL_IntcHandle hIntcEMAC0Tx; 
static CSL_IntcHandle hIntcEMAC1Rx; 
static CSL_IntcHandle hIntcEMAC1Tx; 

 
/* Timer object */
static CSL_TmrObj     tmrObj;
/* handle for Timer */
static CSL_TmrHandle  hTimer;


static volatile Bool bRun = TRUE;   // boolean that indicating if testcase is complete
 
/******* local function definitions **********/
void DoTimerInitialization(void)
{  
   CSL_Status     status;  
   CSL_TmrHwSetup hwSetup;
   CSL_TmrEnamode tmr_ena_mode = CSL_TMR_ENAMODE_CONT;
 
   hTimer   = CSL_tmrOpen(&tmrObj, CSL_TMR_0, NULL, &status);
   /* Get existing hwSetup values from Timer Registers */
   status   = CSL_tmrGetHwSetup(hTimer, &hwSetup);
   /* Timer 0 HW Setup Modifications */
   hwSetup.tmrTimerPeriodHi = 0;
   hwSetup.tmrTimerPeriodLo = 850000; // assuming CPU clock 500 MHz
   hwSetup.tmrIpGateHi = CSL_TMR_CLOCK_INP_NOGATE;
   hwSetup.tmrIpGateLo = CSL_TMR_CLOCK_INP_NOGATE;
   hwSetup.tmrTimerCounterHi = 0x0;
   hwSetup.tmrTimerCounterLo = 0x0;
   hwSetup.tmrIpGateLo = CSL_TMR_CLOCK_INP_NOGATE;
   hwSetup.tmrClksrcLo= CSL_TMR_CLKSRC_INTERNAL;
   hwSetup.tmrClockPulseLo = CSL_TMR_CP_PULSE;      
   hwSetup.tmrInvOutpHi    = CSL_TMR_INVOUTP_UNINVERTED;      
   hwSetup.tmrInvOutpLo    = CSL_TMR_INVOUTP_UNINVERTED;      
   hwSetup.tmrTimerMode    = CSL_TMR_TIMMODE_DUAL_UNCHAINED;
 
   /* Program Timer 0 HW based on hwSetup Structure Modifications*/
   status   = CSL_tmrHwSetup(hTimer, &hwSetup);
   /* Start Timer 0 - And Enable */  
   status  = CSL_tmrHwControl(hTimer, CSL_TMR_CMD_START64, &tmr_ena_mode );
  
}

/*********************************************************
 * Intc setup
 *
 ********************************************************/
void DoInterruptsInitialization()
{
   CSL_IntcParam vectId1;
   CSL_IntcParam vectId2;
   CSL_IntcParam vectId3;
   CSL_IntcParam vectId4;
   CSL_IntcParam vectId5;

   CSL_IntcGlobalEnableState state;
   
   /* Setup the global Interrupt */
   context.numEvtEntries = 13;
   context.eventhandlerRecord = Record; 

   /* VectorID for the Global Edma Event  */
   vectId1 = CSL_INTC_VECTID_8;
   vectId2 = CSL_INTC_VECTID_9;
   vectId3 = CSL_INTC_VECTID_10;
   vectId4 = CSL_INTC_VECTID_11;
   vectId5 = CSL_INTC_VECTID_12;
	
   CSL_intcInit(&context);
   /* Enable NMIs  */
   CSL_intcGlobalNmiEnable();
   /* Enable Global Interrupts  */
   CSL_intcGlobalEnable(&state);
   
   /* Opening a handle for the timer */
   hIntcTimer = CSL_intcOpen(&intcTimer, CSL_INTC_EVENTID_TINTLO_LOCAL, &vectId1, NULL);
 
   /* Opening a handle for EMAC0 Rx interrupt */
   hIntcEMAC0Rx = CSL_intcOpen(&intcEMACRx, CSL_INTC_EVENTID_MACRXINT0, &vectId2, NULL);
   /* Opening a handle for EMAC0 Tx interrupt */
   hIntcEMAC0Tx = CSL_intcOpen(&intcEMACTx, CSL_INTC_EVENTID_MACTXINT0, &vectId3, NULL);
   /* Opening a handle for EMAC1 Rx interrupt */
   hIntcEMAC1Rx = CSL_intcOpen(&intcEMACRx, CSL_INTC_EVENTID_MACRXINT1, &vectId4, NULL);
   /* Opening a handle for EMAC1 Tx interrupt */
   hIntcEMAC1Tx = CSL_intcOpen(&intcEMACTx, CSL_INTC_EVENTID_MACTXINT1, &vectId5, NULL);

   /* Hook the ISRs */
   CSL_intcHookIsr(vectId1,&TimerTick);
   CSL_intcHookIsr(vectId2,&Hw0RxInt);
   CSL_intcHookIsr(vectId3,&Hw0TxInt);
   CSL_intcHookIsr(vectId4,&Hw1RxInt);
   CSL_intcHookIsr(vectId5,&Hw1TxInt);
  
   /* Clear the Interrupt */
   CSL_intcHwControl(hIntcTimer, CSL_INTC_CMD_EVTCLEAR, NULL);
   CSL_intcHwControl(hIntcEMAC0Rx, CSL_INTC_CMD_EVTCLEAR, NULL);
   CSL_intcHwControl(hIntcEMAC0Tx, CSL_INTC_CMD_EVTCLEAR, NULL);
   CSL_intcHwControl(hIntcEMAC1Rx, CSL_INTC_CMD_EVTCLEAR, NULL);
   CSL_intcHwControl(hIntcEMAC1Tx, CSL_INTC_CMD_EVTCLEAR, NULL);
     
    /* Enable the Event & the interrupt */
   CSL_intcHwControl(hIntcTimer, CSL_INTC_CMD_EVTENABLE, NULL);   
   CSL_intcHwControl(hIntcEMAC0Rx, CSL_INTC_CMD_EVTENABLE, NULL);   
   CSL_intcHwControl(hIntcEMAC0Tx, CSL_INTC_CMD_EVTENABLE, NULL);   
   CSL_intcHwControl(hIntcEMAC1Rx, CSL_INTC_CMD_EVTENABLE, NULL);   
   CSL_intcHwControl(hIntcEMAC1Tx, CSL_INTC_CMD_EVTENABLE, NULL);   
}

/*********************************************************
 * Intc close 
 *
 ********************************************************/

void DoInterruptEnd(void)
{
   CSL_intcGlobalDisable(NULL);
   CSL_intcClose(hIntcEMAC0Rx);
   CSL_intcClose(hIntcEMAC0Tx);
   CSL_intcClose(hIntcEMAC1Rx);
   CSL_intcClose(hIntcEMAC1Tx);
   CSL_intcClose(hIntcTimer);
}

