/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *
 *   @file  hpi_common.c
 *
 *   @path  $(CSLPATH)\example\hpi\src
 *
 *   @desc  Common functions defined for HPI read and write example.
 *
 ****************************************************************************
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  03-Aug-2006 NG Created
 * =============================================================================
 */
#include <csl.h>

/* Device specific file */
#include "hpi_common.h"
#include <csl_gpio.h>
#include <soc.h>

#define FAIL    1
#define PASS    0

CSL_GpioHandle       hGpio;
CSL_GpioPinData      gpioPinData;
CSL_GpioPinConfig    gpioConfig;

/*
 * =============================================================================
 *   @func   Wait_For_Memory_Initialization
 *
 *   @desc
 *  @n This function is to Wait until Pre-loaded memory is properly initialized
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void Wait_For_Memory_Initialization (
    Uint32 *dsp_src_buff, 
    Uint32 length
)
{
    Uint32 tmp_val;
  
    /* Wait for the pre-loaded data */
    while (1) {
        tmp_val = dsp_src_buff[length - 1];

        if (tmp_val != 0) {
            break;
        }
    }

    /* Perform a Write and wait until Read is completed */
    dsp_src_buff[length - 1] = 0xC0FE1111;

    while ((dsp_src_buff[length - 1]) != 0xC0FE1111);

    dsp_src_buff[length - 1] = tmp_val;
}

/*
 * =============================================================================
 *   @func   Data_Compare_HPI
 *
 *   @desc
 *  @n This function is to Compare Source and Destination Buffer
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
Uint32 Data_Compare_HPI (
    Uint32 *dsp_src_addr, 
    Uint32 *dsp_dst_addr,
    Uint32 length
)
{
    Uint32 i;

    for (i = 0; i < length; i++) {
        if(dsp_src_addr[i] != dsp_dst_addr[i]) {
            return (FAIL);
        }
    }
    return (PASS);
}

/*
 * =============================================================================
 *   @func   setup_gpio
 *
 *   @desc
 *  @n This function is used for handshaking between testbench and dsp
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void setup_gpio (
)
{
    /* TB Synchronisation-> Setting GPIO 12 as O/p and 13 as I/P */
    hGpio->regs->DIR = 0x2000;
  
    /* TB Synchronisation-> Setting GPIO 12 */
    hGpio->regs->OUT_DATA = 0x1000;

	while(hGpio->regs->IN_DATA != 0x3000) {
         ;
	}

    hGpio->regs->OUT_DATA = 0x0000;

	while(hGpio->regs->IN_DATA != 0x0000) {
         ;
	}
}

/* End of hpi_common.c */
