/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *
 *   @file  smc_interrupt.c
 *
 *   @path  $(CSLPATH)\example\smc\src
 *
 *   @desc  Common functions for interrupt setup and ISRs
 *
 * =============================================================================
 */
#include <csl_intc.h>
#include <cslr_intc.h>
#include <smc_interrupt.h>
#include <csl_smc.h>
#include <csl_smcp.h>

CSL_IntcContext context;
CSL_IntcEventHandlerRecord Record[8];

CSL_IntcObj intcSmcObj0;
CSL_IntcObj intcSmcObj1;

CSL_IntcHandle hIntcSmc0;
CSL_IntcHandle hIntcSmc1;

extern volatile Bool INT_OCCURED;

/*
 * =============================================================================
 *   @func   smcIntSetup
 *
 *   @desc
 *  @n Setup the SMC and SMCP interrupts
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void smcIntSetup (
    void
)
{
    CSL_IntcParam vectId1 = CSL_INTC_VECTID_9;
    CSL_IntcParam vectId2 = CSL_INTC_VECTID_10;

    CSL_IntcGlobalEnableState state;

    /* Setup the global Interrupt */
    context.numEvtEntries = 9;
    context.eventhandlerRecord = Record;
    CSL_intcInit(&context);

    /* Enable NMIs  */
    CSL_intcGlobalNmiEnable();

    /* Enable Global Interrupts  */
    CSL_intcGlobalEnable(&state);
    
    /*Open Intc handles */
    hIntcSmc0 = CSL_intcOpen(&intcSmcObj0, CSL_INTC_EVENTID_SMCMPINT,
                             &vectId1, NULL);

    hIntcSmc1 = CSL_intcOpen(&intcSmcObj1, CSL_INTC_EVENTID_SMCPEVT,
                             &vectId2, NULL);

    CSL_intcHookIsr(vectId1, &isr_smc_mprot);
    CSL_intcHookIsr(vectId2, &isr_smc_pe);

    /* Clear the Interrupt */
    CSL_intcHwControl(hIntcSmc0,CSL_INTC_CMD_EVTCLEAR,NULL);
    CSL_intcHwControl(hIntcSmc1,CSL_INTC_CMD_EVTCLEAR,NULL);

    /* Enable the Interrupt */
    CSL_intcHwControl(hIntcSmc0,CSL_INTC_CMD_EVTENABLE,NULL);
    CSL_intcHwControl(hIntcSmc1,CSL_INTC_CMD_EVTENABLE,NULL);
}
/*
 * =============================================================================
 *   @func   smcIntClose
 *
 *   @desc
 *  @n Closed SMC and SMCP interrupt handlers
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */

void smcIntClose (
    void
)
{
    CSL_intcClose(hIntcSmc0);
    CSL_intcClose(hIntcSmc1);
}

/*
 * =============================================================================
 *  @func   isr_smc_mprot
 *
 *  @desc
 *  @n Interrupt service routine for mprot interrupt
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
interrupt void isr_smc_mprot()
{
}

/*
 * =============================================================================
 *  @func   isr_smc_pe
 *
 *  @desc
 *  @n Interrupt service routine for profiler interrupt
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
interrupt void isr_smc_pe()
{
    INT_OCCURED = TRUE ;
}


