/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2009
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  Tsip_dlb_example.c
 *
 *   @path  $(CSLPATH)\example\tsip\tsip_dlb_example\src
 *
 *   @desc  This is an example program for TSIP of CSL 3x.  
 *
 *  ============================================================================
 *   @n Target Platform: Tomohawk EVM
 *  ============================================================================
 *   @n <b> Example Description </b>
 *   @n The example shows the functionality of TSIP in internal data loop back mode,
 *      with channel 0 of TSIP 0 on DSP core 0.
 *
 *          - Enable LPSC domains of 3 TSIPs 
 *          - Setup TSIP channel
 *          - Setup TSIP Interrupt
 *          - Wait for the TB synchronisation
 *          - Enable TSIP DMA channel
 *          - Wait till transfer completes
 *          - Verify the data
 *          - Closes the opened instance
 *
 * =============================================================================
 *      
 *   <b> Procedure to run the example </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Launch CCS window
 *      3. Open project Tsip_dlb_example.pjt
 *      4. Build the project and load the .out file of the project.
 *          
 *   @endverbatim
 *   
 * =============================================================================
 */ 
#include <stdio.h>
#include "example_init.h"
#include "example_config.h"
#include "tsip_interrupt.h"
#include "tsip_data.h"
#include <csl_types.h>

#define FAIL    1

extern __cregister volatile Uint32 DNUM;
#define GEM_ID ((Uint32)(DNUM)) 


CSL_TsipHandle hTsip0;
CSL_TsipHandle hTsip1;
CSL_TsipHandle hTsip2;

CSL_TsipObj    tsipObj0;
CSL_TsipObj    tsipObj1;
CSL_TsipObj    tsipObj2;

CSL_TsipHwSetup tsipSetup;

CSL_Status     status;

CSL_TsipGblSetup        gblsetup;

/** Xmt Clock setup */
CSL_TsipXclkSetup       xclk;

/** Rcv Clock setup*/
CSL_TsipRclkSetup       rclk;

/** Transmit Frame Setup */
CSL_TsipFrameSetup      xframesetup;

/** Receive Frame Setup */
CSL_TsipFrameSetup      rframesetup;

/** Receive Interrupt Setup */
CSL_TsipIntSetup        xint;

/** Receive Interrupt Setup */
CSL_TsipIntSetup        rint;

Uint32    ChannelNumber;

Uint32    xbitmapa1[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb1[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa1[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb1[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa2[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb2[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa2[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb2[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa3[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb3[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa3[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb3[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa4[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb4[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa4[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb4[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa5[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb5[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa5[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb5[CSL_TSIP_BITMAP_SIZE];

Uint32    Rcv0aDestAddr[BUFF_SIZE/4];

Uint32    Xmt0bSrcAddr[BUFF_SIZE/4];
Uint32    Rcv0bDestAddr[BUFF_SIZE/4];

CSL_TsipChanSetup    xchannela;
CSL_TsipChanSetup    xchannelb;
CSL_TsipChanSetup    rchannela;
CSL_TsipChanSetup    rchannelb;

Uint32 interruptIteration[6] = {0, 0, 0, 0, 0, 0};

volatile Uint32 TsipDone = 0;

Uint32 arg;
Uint32  channel;
Uint32 TSIP_ID = 0;

Uint32* SrcDataIncPtr;
void tsip_basic_setup();
void tsip_Channel_setup();
void CID_Init();

void Bitmap_Generation( Uint32 Total_Bitmap_Count);
void Bitmap_simple(void);
void resetTsip(int port);

extern void PllSetup(void);

/*
 * =============================================================================
 *   @func   tsip_txRx
 *
 *   @desc
 *  @n This function initializes TSIP0 for basic setup.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      result 
 *          0 - data transmit and receive successful.
 *          1 - data transmit/receive not successful.
 * =============================================================================
 */
Uint32 tsip_txRx (
    void
) 
{
    volatile Uint32 TraceCounter = 0;
    CSL_Status     status;
    volatile Uint32 i;
    Uint32 result = 1;

    /* Opening TSIP Handle */
    hTsip0 = CSL_tsipOpen(&tsipObj0, CSL_TSIP_0, NULL, &status);

    // Reset TSIP
    if(GEM_ID == 0) {
        /*  Enable LPSC domains of 3 TSIPs */
        TSIP_Domain_Enable();
        resetTsip(0);
    }
            
    tsip_basic_setup();

    /* Initialising Data Buffers */
    Init_Mem((Xmt0aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4),
                  NUM_SLOTS, FRAME_COUNTS+1, 0x12ab34cd, 0);
                                    
    Init_Mem((Rcv0aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4),
                  NUM_SLOTS, FRAME_COUNTS+1, 0, 0);


    if(GEM_ID == 0) {
        /* Initialising TSIP SIU and DMA Logic */
        arg = 1;
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_RST_SIU, &arg);
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_RST_DMA, &arg);

		/* send the configuration to tsip */        
        CSL_tsipHwSetup(hTsip0, &tsipSetup);        
    }
    
    /* Configures each TSIP channel to the corresponding GEM L2 buffer */
    tsip_Channel_setup(Test_List[GEM_ID].ChannelNumber);
    CSL_tsipChHwSetup(hTsip0, &tsipSetup);
    CID_Init();

    printf("CID Initialization done \n");
    if(GEM_ID ==0) {
        setup_Tsip_Interrupt();

        switch(LOOPBACK_MODE) 
        {
            case LOOPBACK_DATA:
                CSL_FINST(hTsip0->regs->EMUTST, TSIP_EMUTST_SIUTST, LOOPBACK_MODE);
                CSL_FINST(hTsip0->regs->EMUTST, TSIP_EMUTST_FREE, DISABLE);
                break;

            case LOOPBACK_LINK:
                CSL_FINST(hTsip0->regs->EMUTST, TSIP_EMUTST_LBS, LLB);
                CSL_FINST(hTsip0->regs->EMUTST, TSIP_EMUTST_FREE, DISABLE);                
                break;

            default:
            case LOOPBACK_NONE:
                CSL_FINST(hTsip0->regs->EMUTST, TSIP_EMUTST_SIUTST, NORMAL_MODE);
                break;
        }

        // Enabling TSIP SIU
        arg = 0x1;
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_SIU_XMT, &arg);
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_SIU_RCV, &arg);

   
        // Disable Transmit channel 0 Enable register
        arg = 0; 
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_DIS_CHAN, &arg);

        // Disable Receive channel 0 Enable register
        arg = CSL_TSIP_RCV_CHAN_MASK | 0; 
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_DIS_CHAN, &arg);
        

        /* enable DMA */
        arg = 1;
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_DMA, &arg);

        // Enable Transmit channel 0 Enable register
        arg = 0; // channel 0
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_CHAN, &arg);

        // Enable Receive channel 0 Enable register
        arg = CSL_TSIP_RCV_CHAN_MASK | 0; 
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_CHAN, &arg);
        
        while(TsipDone == 0) {
            TraceCounter++;
        }
        printf("TSIP0 Transfer Over \n");
        
        if(GEM_ID == 0)
        {
            arg = 1;
            CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_RST_SIU, &arg);
            CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_RST_DMA, &arg);    
        }
        

        result = Verify_Transfer((Test_List[GEM_ID].xmt_frame_count-1), 
                                 (FrameSize[TSIP_ID][GEM_ID]), 
                                 (Xmt0aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                                 (Rcv0aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) 
        {
            printf("TSIP0 Channel %d Passed \n", GEM_ID);
        }
        else
        {
            printf("TSIP0 Channel %d Failed \n", GEM_ID);
        }    
    }

    /* close tsip instance */
    CSL_tsipClose(hTsip0);

    return (result);
}

/*
 * =============================================================================
 *   @func   tsip_basic_setup
 *
 *   @desc
 *  @n This function sets up the TSIP to transmit and receive the data.
 *     loopback.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void tsip_basic_setup (
)
{

    tsipSetup.gbl = &gblsetup;
    tsipSetup.xframe = &xframesetup;
    tsipSetup.rframe = &rframesetup;
    tsipSetup.xclk = &xclk;
    tsipSetup.rclk = &rclk;
    tsipSetup.xint = &xint;
    tsipSetup.rint = &rint;

    // global set up
    tsipSetup.gbl->clkd   = CSL_TSIP_CLKD_REDUN;
    tsipSetup.gbl->endian = CSL_TSIP_ENDIAN_BIG; 
    tsipSetup.gbl->pri    = CSL_TSIP_PRI_0;     // or CSL_TSIP_PRI_1
    tsipSetup.gbl->maxpri = CSL_TSIP_PRI_0;         

    // transmit frame
    tsipSetup.xframe->fcount = (CSL_TsipFramecount)((int)FRAME_COUNTS_SUPER-1); // zero-based
    tsipSetup.xframe->fsize  = (CSL_TsipFramesize)(NUM_SLOTS-1);  // zero-based


    // transmit clock
    tsipSetup.xclk->clksrc = CSL_TSIP_CLKSRC_A;
    tsipSetup.xclk->datd   = 0x0;
    tsipSetup.xclk->outdis = CSL_TSIP_XMTDIS_HIGHIMP;
    tsipSetup.xclk->fsyncp = CSL_TSIP_FSYNCP_ALOW;
    tsipSetup.xclk->fclkp  = CSL_TSIP_CLKP_RISING;
    tsipSetup.xclk->dclkp  = CSL_TSIP_CLKP_RISING;
    tsipSetup.xclk->drate  = CSL_TSIP_DATARATE_16M;
    tsipSetup.xclk->clkmode= CSL_TSIP_CLKM_SGL;
        
    // transmit interrupt settings
    tsipSetup.xint->sfint  = CSL_TSIP_INT_ACK;
    tsipSetup.xint->frint  = CSL_TSIP_INT_ACK;
    tsipSetup.xint->fdelay = CSL_TSIP_INT_ACK; // 0

    // receive frame
    tsipSetup.rframe->fcount = (CSL_TsipFramecount)((int)FRAME_COUNTS_SUPER-1); // zero-based
    tsipSetup.rframe->fsize  = (CSL_TsipFramesize)(NUM_SLOTS-1);  // zero-based

    // receiving clock        
    tsipSetup.rclk->clksrc = CSL_TSIP_CLKSRC_A;
    tsipSetup.rclk->datd   = 0x0;
    tsipSetup.rclk->fsyncp = CSL_TSIP_FSYNCP_ALOW;
    tsipSetup.rclk->fclkp  = CSL_TSIP_CLKP_RISING;
    tsipSetup.rclk->dclkp  = CSL_TSIP_CLKP_FALLING;
    tsipSetup.rclk->drate  = CSL_TSIP_DATARATE_16M;
    tsipSetup.rclk->clkmode= CSL_TSIP_CLKM_SGL;

    // receiving interrupt settings
    tsipSetup.rint->sfint  = CSL_TSIP_INT_ACK;
    tsipSetup.rint->frint  = CSL_TSIP_INT_ACK;
    tsipSetup.rint->fdelay = CSL_TSIP_INT_ACK; 

}

/*
 * =============================================================================
 *   @func   tsip_Channel_setup
 *
 *   @desc
 *  @n This function sets up the TSIP to transmit and receive the data.
 *     loopback.
 *
 *  @arg  
 *      ChannelNumber - channel number to configure particular TSIP channel.
 *
 *  @return
 *      None
 * =============================================================================
 */
void tsip_Channel_setup (
    Uint32 ChannelNumber
)
{
    Uint32 channel;
    
    Uint32  j;

    channel = ChannelNumber;
    tsipSetup.ChannelNumber = &channel;

    switch (channel) {
        case 0 :
        {
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           0 * 0x1000000 + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           0 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 1 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           1 * 0x1000000 + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           1 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 2 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           2 * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           2 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 3 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           3 * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           3 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 4 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           4 * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           4 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 5 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           5 * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           5 * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        default :
           break;
    }

    /* CID + FC at the header and footer */
    xchannela.falloc = (FrameSize[0][channel]);
    xchannela.fsize  = (FrameSize[0][channel]);
    rchannela.falloc = (FrameSize[0][channel]);
    rchannela.fsize  = (FrameSize[0][channel]);

    /* considering first dummy frame */
    xchannela.fcount = Test_List[channel].xmt_frame_count;   
    rchannela.fcount = Test_List[channel].xmt_frame_count;   

    /* Configuring bitmaps based on bitmap generated for the corresponding frame size */
    for (j = 0; ((j < CSL_TSIP_BITMAP_SIZE )); j++)
    {
        *(Uint32 *) (xbitmapa0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4) = bitmaptx[TSIP_ID][channel][j];
        *(Uint32 *) (rbitmapa0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4) = bitmaptx[TSIP_ID][channel][j];
    }
    xchannela.bitmap = ((xbitmapa0 + GEM_ID * 0x1000000/4 + 0x10000000/4));
    rchannela.bitmap = (rbitmapa0 + GEM_ID * 0x1000000/4 + 0x10000000/4);

    /* Configuring dummy parameters for PONG Buffer */
    xchannelb.baseaddr = (Uint32) ((Uint8 *)Xmt0bSrcAddr + 
                                   GEM_ID * 0x1000000 + 0x10000000);
    xchannelb.falloc = 0x10;
    xchannelb.fsize = 0x10;
    xchannelb.fcount = 0x4;
    for (j = 0; j < CSL_TSIP_BITMAP_SIZE; j++) {
        *(Uint32 *)(xbitmapb0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4)=0x0;
    }
    xchannelb.bitmap = ((xbitmapb0 + GEM_ID * 0x1000000/4 + 0x10000000/4));

    rchannelb.baseaddr = (Uint32) ((Uint8 *)Rcv0bDestAddr + 
                                   GEM_ID * 0x1000000 + 0x10000000);
    rchannelb.falloc = 0x10;
    rchannelb.fsize = 0x10;
    rchannelb.fcount = 0x1;
    for (j = 0; j < CSL_TSIP_BITMAP_SIZE; j++) {
        *(Uint32 *)(rbitmapb0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4)=0x0;
    }
    rchannelb.bitmap = (rbitmapb0 + GEM_ID * 0x1000000/4 + 0x10000000/4);

    tsipSetup.xchana = (CSL_TsipChanSetup*) &(xchannela);
    tsipSetup.xchanb = (CSL_TsipChanSetup*) &(xchannelb);
    tsipSetup.rchana = (CSL_TsipChanSetup*) &(rchannela);
    tsipSetup.rchanb = (CSL_TsipChanSetup*) &(rchannelb);    
}

/*
 * =============================================================================
 *   @func   CID_Init
 *
 *   @desc
 *  @n This function initalizes the TSIP data for channel 0 (for now.)
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void CID_Init (
)
{
    Uint32 i; 
    
    for (i = 0; i <= Test_List[0].xmt_frame_count + 1 ; i++) 
    {
        *(Uint32*)(Xmt0aSrcAddr + i * (FrameSize[TSIP_ID][0])/4 + 
            0 * 0x1000000/4 + 0x10000000/4) = 
                (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }


    // Enable Tramsmit (channel=0) Enable register
    arg = 0; 
    CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_CHAN, &arg);
    
    CSL_FINS(hTsip0->regs->XCHEN[0].XCHEN, 
             TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));


    // Enable Receive (channel=0) Enable register
    arg = CSL_TSIP_RCV_CHAN_MASK | 0; 
    CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_CHAN, &arg);    
        
    CSL_FINS(hTsip0->regs->RCHEN[0].RCHEN, 
             TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    
}

/*
 * =============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine, which invokes TSIP external loopback example. 
 * =============================================================================
 */
void main (
    void
)
{
    Uint32 result = FAIL;

    printf("TSIP Example \n");

    /* Bitmap Generation for all 6 channels */
    Bitmap_Generation(NUM_SLOTS * 6);

    result = tsip_txRx();

    if (result == 0) {
        printf("Core%d : TSIP loopback example Passed\n", GEM_ID);
    }
    else {
        printf("Core%d : TSIP loopback example Failed\n", GEM_ID);
    }	
}



void resetTsip(int port)
{
    int i;
    Uint32 arg = 0x1;
    
    
    CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_RST_SIU, &arg);    
    CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_DIS_DMA, &arg);

    for(i=0; i<1000;i++);
}


void Bitmap_Generation( Uint32 Total_Bitmap_Count)
{
    Uint32  channelnum ;
    Uint32  i,j, k;
    Uint32  randomnumber;
    
    /* Intializing btimap with zero for all bitmaps */
    /* For 3 TSIPs */
    for (i = 0; i < 3; i++)
     {
        /* For 6 TSIP Channels */
        for (j = 0; j < 6; j++)
        {
            FrameSize[i][j] = 0;
            bitmaptx_disable_count[i][j] = 0;
            for (k = 0; ((k < CSL_TSIP_BITMAP_SIZE )); k++)
            {
                bitmaptx[i][j][k] = 0;
            }
        }
     }

     /* Loop for 3 TSIPs */
     for (i = 0; i < 3; i++)
     {
        /* Dummy Bytes */
        DUMMYBYTE_COUNT[i][0] = 0 ;
        DUMMYBYTE_COUNT[i][1] = 0 ;
        DUMMYBYTE_COUNT[i][2] = 0 ;
        DUMMYBYTE_COUNT[i][3] = 0 ;
        DUMMYBYTE_COUNT[i][4] = 0 ;
        DUMMYBYTE_COUNT[i][5] = 0 ;
        /* Configuring Bitmap array */
        for (j = 0; ((j < Total_Bitmap_Count)); j++)
        {
            channelnum = j%6;
            /* Enabling Linear PCM bitmap */
            randomnumber = 0x01;  
            bitmaptx_linear_count[i][channelnum]++;
            /* Deriving FrameSize */
            FrameSize[i][channelnum]++;
            
            if (randomnumber != 0)
            {
               bitmaptx[i][channelnum][j/16] |= (randomnumber << ((15-(j%16))*2));
            }
        }
            
        /* PAD Bytes */
        PADBYTE_COUNT[i][0] = 0 ;
        PADBYTE_COUNT[i][1] = 0 ;
        PADBYTE_COUNT[i][2] = 0 ;
        PADBYTE_COUNT[i][3] = 0 ;
        PADBYTE_COUNT[i][4] = 0 ;
        PADBYTE_COUNT[i][5] = 0 ;
        
        /* Checking whether Padbytes are required */
        if ((FrameSize[i][0]%4) != 0)
        {
               PADBYTE_COUNT[i][0] = 4 - (FrameSize[i][0]%4);
               FrameSize[i][0] += (4 - (FrameSize[i][0]%4));
        }
        if ((FrameSize[i][1]%4) != 0)
        {
               PADBYTE_COUNT[i][1] = 4 - (FrameSize[i][1]%4);
               FrameSize[i][1] += (4 - (FrameSize[i][1]%4));
        }
        if ((FrameSize[i][2]%4) != 0)
        {
               PADBYTE_COUNT[i][2] = 4 - (FrameSize[i][2]%4);
               FrameSize[i][2] += (4 - (FrameSize[i][2]%4));
        }
        if ((FrameSize[i][3]%4) != 0)
        {
               PADBYTE_COUNT[i][3] = 4 - (FrameSize[i][3]%4);
               FrameSize[i][3] += (4 - (FrameSize[i][3]%4));
        }
        if ((FrameSize[i][4]%4) != 0)
        {
               PADBYTE_COUNT[i][4] = 4 - (FrameSize[i][4]%4);
               FrameSize[i][4] += (4 - (FrameSize[i][4]%4));
        }
        if ((FrameSize[i][5]%4) != 0)
        {
               PADBYTE_COUNT[i][5] = 4 - (FrameSize[i][5]%4);
               FrameSize[i][5] += (4 - (FrameSize[i][5]%4));
        }


        /* Incrementing FrameSize for CID + FRFC Word at 
        the first and last location of a frame buffer */
        FrameSize[i][0] += 8;
        FrameSize[i][1] += 8;
        FrameSize[i][2] += 8;
        FrameSize[i][3] += 8;
        FrameSize[i][4] += 8;
        FrameSize[i][5] += 8;
     }
}
