/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  Tsip_elb_example.c
 *
 *   @path  $(CSLPATH)\example\tsip_elb_example\tsip\src
 *
 *   @desc  This is an example program for TSIP of CSL 3x.  
 *
 *  ============================================================================
 *  ============================================================================
 *   @n <b> Example Description </b>
 *   @n The example shows the functionality of TSIP in external loop back mode
 *          - TB Synchronisation-> Setting GPIO 12 as O/p and 13 as I/P
 *          - Enable LPSC domains of 3 TSIPs 
 *          - Setup TSIP channel
 *          - Setup TSIP Interrupt
 *          - Wait for the TB synchronisation
 *          - Enable TSIP DMA channel
 *          - Wait till transmit completes
 *          - Verify the data
 *          - Closes the opened instance
 *
 * =============================================================================
 *      
 *   <b> Procedure to run the example </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Please refer CCS manual for setup configuration and loading 
 *         proper GEL file
 *      3. Launch CCS window
 *      4. Open project Tsip_elb_example.pjt
 *      5. Build the project and load the .out file of the project.
 *          
 *   @endverbatim
 *   
 * =============================================================================
 */ 
/** ============================================================================
 *  Revision History
 *  ===============*
 *  18-Dec-2006 NG  File Created
 *
 * =============================================================================
 */

#include <stdio.h>
#include "example_init.h"
#include <csl_types.h>
#include <csl_gpio.h>

#define FAIL    0

#define BufferSize 128
#define GEM_ID 	((Uint32) (0))

CSL_GpioHandle      hGpio;
CSL_GpioPinData     gpioPinData;
CSL_GpioPinConfig   gpioConfig;

CSL_TsipHandle hTsip0;
CSL_TsipHandle hTsip1;
CSL_TsipHandle hTsip2;

CSL_TsipObj    tsipObj0;
CSL_TsipObj    tsipObj1;
CSL_TsipObj    tsipObj2;

CSL_TsipHwSetup tsipSetup;

CSL_Status     status;

CSL_TsipGblSetup        gblsetup;

/** Xmt Clock setup */
CSL_TsipXclkSetup       xclk;

/** Rcv Clock setup*/
CSL_TsipRclkSetup       rclk;

/** Transmit Frame Setup */
CSL_TsipFrameSetup      xframesetup;

/** Receive Frame Setup */
CSL_TsipFrameSetup      rframesetup;

/** Receive Interrupt Setup */
CSL_TsipIntSetup        xint;

/** Receive Interrupt Setup */
CSL_TsipIntSetup        rint;

Uint32    ChannelNumber;

Uint32    xbitmapa1[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb1[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa1[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb1[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa2[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb2[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa2[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb2[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa3[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb3[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa3[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb3[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa4[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb4[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa4[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb4[CSL_TSIP_BITMAP_SIZE];

Uint32    xbitmapa5[CSL_TSIP_BITMAP_SIZE];
Uint32    xbitmapb5[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapa5[CSL_TSIP_BITMAP_SIZE];
Uint32    rbitmapb5[CSL_TSIP_BITMAP_SIZE];

Uint32    Rcv0aDestAddr[BufferSize];

Uint32    Xmt0bSrcAddr[BufferSize];
Uint32    Rcv0bDestAddr[BufferSize];

Uint32    Rcv1aDestAddr[BufferSize];

Uint32    Xmt1bSrcAddr[BufferSize];
Uint32    Rcv1bDestAddr[BufferSize];

Uint32    Rcv2aDestAddr[BufferSize];

Uint32    Xmt2bSrcAddr[BufferSize];
Uint32    Rcv2bDestAddr[BufferSize];

Uint32    Rcv3aDestAddr[BufferSize];

Uint32    Xmt3bSrcAddr[BufferSize];
Uint32    Rcv3bDestAddr[BufferSize];

Uint32    Rcv4aDestAddr[BufferSize];

Uint32    Xmt4bSrcAddr[BufferSize];
Uint32    Rcv4bDestAddr[BufferSize];

Uint32    Rcv5aDestAddr[BufferSize];

Uint32    Xmt5bSrcAddr[BufferSize];
Uint32    Rcv5bDestAddr[BufferSize];

CSL_TsipChanSetup    xchannela;
CSL_TsipChanSetup    xchannelb;
CSL_TsipChanSetup    rchannela;
CSL_TsipChanSetup    rchannelb;

Uint32 interruptIteration[6] = {0, 0, 0, 0, 0, 0};

Uint32 arg;
Uint32  channel;
volatile Uint32 TsipDone = 0;
Uint32 result = 0;
Uint32 TSIP_ID = 0;
Uint32 bitmappos = 0;
Uint32* SrcDataIncPtr;
void tsip_basic_setup();
void tsip_Channel_setup();
void CID_Init();

/*
 * =============================================================================
 *   @func   tsip_txRx
 *
 *   @desc
 *  @n This function transmit and receive the data using test bench as external
 *     loopback.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      result 
 *          0 - data transmit and receive successful.
 *          1 - data transmit/receive not successful.
 * =============================================================================
 */
Uint32 tsip_txRx (
    void
) 
{
    Uint32         TraceCounter = 0;
    CSL_GpioObj    gpioObj;
    CSL_Status     status;

    if (GEM_ID == 0) {
        hGpio = CSL_gpioOpen(&gpioObj, CSL_GPIO, NULL, &status);
    
        /* TB Synchronisation-> Setting GPIO 12 as O/p and 13 as I/P */
        hGpio->regs->DIR = 0x2000;
        
        /* Enable LPSC domains of 3 TSIPs */
        TSIP_Domain_Enable();
    
        hTsip0 = CSL_tsipOpen(&tsipObj0, CSL_TSIP_0, NULL, &status);
        tsip_basic_setup();
        hTsip1 = CSL_tsipOpen(&tsipObj1, CSL_TSIP_1, NULL, &status);
        hTsip2 = CSL_tsipOpen(&tsipObj2, CSL_TSIP_2, NULL, &status);
        CSL_tsipHwSetup(hTsip0, &tsipSetup);

        tsip_Channel_setup(Test_List[0].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);

        tsip_Channel_setup(Test_List[1].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);
    
        tsip_Channel_setup(Test_List[2].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);

        tsip_Channel_setup(Test_List[3].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);

        tsip_Channel_setup(Test_List[4].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);

        tsip_Channel_setup(Test_List[5].ChannelNumber);
        CSL_tsipChHwSetup(hTsip0, &tsipSetup);

        CID_Init();
        printf("CID Initialization done \n");
    
        arg = 0x1;
        CSL_FINS( hTsip0->regs->SIUCTL, TSIP_SIUCTL_XMTENB, arg );
        CSL_FINS( hTsip0->regs->SIUCTL, TSIP_SIUCTL_RCVENB, arg );
    
        setup_Tsip_Interrupt();
    
        arg = 1;
        CSL_tsipHwControl(hTsip0, CSL_TSIP_CMD_ENA_DMA, &arg);
    
        /* TB Synchronisation-> Setting GPIO 12 */
        hGpio->regs->OUT_DATA = 0x1000;
    
        /* TB Synchronisation-> Setting GPIO 12 */
        hGpio->regs->OUT_DATA = 0x0000;

        while(TsipDone == 0) {
            TraceCounter++;
        }
    
        result = Verify_Transfer((Test_List[0].xmt_frame_count ), 
                 ((Test_List[0].xmt_frame_size + 9)), 
                 (Xmt0aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                 (Rcv0aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 0 Passed \n");
    	}
    
        result += Verify_Transfer((Test_List[1].xmt_frame_count ), 
                  ((Test_List[1].xmt_frame_size + 9)), 
                  (Xmt1aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                  (Rcv1aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 1 Passed \n");
    	}
    
        result += Verify_Transfer((Test_List[2].xmt_frame_count ), 
                  ((Test_List[2].xmt_frame_size + 9)), 
                  (Xmt2aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                  (Rcv2aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 2 Passed \n");
    	}
    
        result += Verify_Transfer((Test_List[3].xmt_frame_count ), 
                  ((Test_List[3].xmt_frame_size + 9)), 
                  (Xmt3aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                  (Rcv3aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 3 Passed \n");
    	}
    
        result += Verify_Transfer((Test_List[4].xmt_frame_count ), 
                  ((Test_List[4].xmt_frame_size + 9)), 
                  (Xmt4aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                  (Rcv4aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 4 Passed \n");
    	}
    
        result += Verify_Transfer((Test_List[5].xmt_frame_count ), 
                  ((Test_List[5].xmt_frame_size + 9)), 
                  (Xmt5aSrcAddr + GEM_ID * 0x1000000/4 + 0x10000000/4), 
                  (Rcv5aDestAddr + GEM_ID * 0x1000000/4 + 0x10000000/4));
        if (!result) {
    	    printf("Channel 5 Passed \n");
    	}
    }

    CSL_gpioClose(hGpio);

    return (result);
}

/*
 * =============================================================================
 *   @func   tsip_basic_setup
 *
 *   @desc
 *  @n This function sets up the TSIP to transmit and receive the data.
 *     loopback.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void tsip_basic_setup (
)
{

    tsipSetup.gbl = &gblsetup;
    tsipSetup.xframe = &xframesetup;
    tsipSetup.rframe = &rframesetup;
    tsipSetup.xclk = &xclk;
    tsipSetup.rclk = &rclk;
    tsipSetup.xint = &xint;
    tsipSetup.rint = &rint;

    xframesetup.fcount = (CSL_TsipFramecount)3;
    xframesetup.fsize = (CSL_TsipFramesize)127;

    rframesetup.fcount = (CSL_TsipFramecount)3;
    rframesetup.fsize = (CSL_TsipFramesize)127;

    gblsetup.clkd = (CSL_TsipClkd)Tsip0.ClockDiv; 
    gblsetup.endian = (CSL_TsipEndian)Tsip0.Endian; 
    gblsetup.pri = (CSL_TsipPri)Tsip0.priority; 
    gblsetup.maxpri = (CSL_TsipPri)Tsip0.max_priority; 
   
    xclk.clksrc = (CSL_TsipClkSrc)Tsip0.xclk_clksrc;
    xclk.datd = Tsip0.xclk_datadelay;
    xclk.outdis = (CSL_TsipXmtDis)Tsip0.xclk_outdis;
    xclk.fsyncp = (CSL_TsipFsyncp)Tsip0.xclk_fsyncp;
    xclk.fclkp = (CSL_TsipClkp)Tsip0.xclk_fclkp;
    xclk.dclkp = (CSL_TsipClkp)Tsip0.xclk_dclkp;
    xclk.drate = (CSL_TsipDataRate)Tsip0.xclk_drate;
    xclk.clkmode = (CSL_TsipClkm)Tsip0.xclk_clkmode;

    rclk.clksrc = (CSL_TsipClkSrc)Tsip0.rclk_clksrc;
    rclk.datd = Tsip0.rclk_datadelay;
    rclk.fsyncp = (CSL_TsipFsyncp)Tsip0.rclk_fsyncp;
    rclk.fclkp = (CSL_TsipClkp)Tsip0.rclk_fclkp;
    rclk.dclkp = (CSL_TsipClkp)Tsip0.rclk_dclkp;
    rclk.drate = (CSL_TsipDataRate)Tsip0.rclk_drate;
    rclk.clkmode = (CSL_TsipClkm)Tsip0.rclk_clkmode;

    xint.sfint = (CSL_TsipInt)0;
    xint.frint = (CSL_TsipInt)0;
    xint.fdelay = (CSL_TsipInt)0; 

    rint.sfint = (CSL_TsipInt)0;
    rint.frint = (CSL_TsipInt)0;
    rint.fdelay = (CSL_TsipInt)0; 


}

/*
 * =============================================================================
 *   @func   tsip_Channel_setup
 *
 *   @desc
 *  @n This function sets up the TSIP to transmit and receive the data.
 *     loopback.
 *
 *  @arg  
 *      ChannelNumber - channel number to configure particular TSIP channel.
 *
 *  @return
 *      None
 * =============================================================================
 */
void tsip_Channel_setup (
    Uint32 ChannelNumber
)
{

    Uint32  randomnumber;
    Uint32  bitmap;
    Uint32  bitmapcount;
    Uint32  FrameSize;
    Uint32  j;

    channel = ChannelNumber;
    tsipSetup.ChannelNumber = &channel;

    switch (channel) {
        case 0 :
        {
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt0aSrcAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv0aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt0aSrcAddr;
           break;
        }
        case 1 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt1aSrcAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv1aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt1aSrcAddr;
           break;
        }
        case 2 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt2aSrcAddr) + 
                                           GEM_ID * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv2aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt2aSrcAddr;
           break;
        }
        case 3 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt3aSrcAddr) + 
                                           GEM_ID * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv3aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt3aSrcAddr;
           break;
        }
        case 4 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt4aSrcAddr) + 
                                           GEM_ID * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv4aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt4aSrcAddr;
           break;
        }
        case 5 :
        {
        
           xchannela.baseaddr = (Uint32) (((Uint8 *)Xmt5aSrcAddr) + 
                                           GEM_ID * 0x1000000  + 0x10000000);
           rchannela.baseaddr = (Uint32) (((Uint8 *)Rcv5aDestAddr) + 
                                           GEM_ID * 0x1000000 + 0x10000000);
            SrcDataIncPtr = Xmt5aSrcAddr;
           break;
        }
        default :
           break;
        }

        /* CID + FC at the header and footer */
        xchannela.falloc = (Test_List[channel].xmt_frame_size + 9) ;
        xchannela.fsize = (Test_List[channel].xmt_frame_size + 9)  ;
        rchannela.falloc = (Test_List[channel].xmt_frame_size + 9)  ;
        rchannela.fsize = (Test_List[channel].xmt_frame_size + 9)  ;

        /* considering first dummy frame */
        xchannela.fcount = Test_List[channel].xmt_frame_count + 2;
        rchannela.fcount = Test_List[channel].xmt_frame_count + 2;

        /* Generate random bitmaps for the corresponding frame size */
        bitmapcount = 0;
        FrameSize = Test_List[channel].xmt_frame_size + 1;
        bitmap = 0;
        for (j = 0; ((j < CSL_TSIP_BITMAP_SIZE * 16)); j++) {
            if ((bitmapcount < FrameSize) && (j >= bitmappos)) {
                randomnumber = 0x01;
                if ((randomnumber != 0)) {
                   bitmapcount++;
                }
                bitmap |= (randomnumber << ((j%16)*2)); 
            }
                if ((j % 16) == 15) {
                    *(Uint32 *) (xbitmapa0 + j/16 + GEM_ID * 0x1000000/4 + 
                                 0x10000000/4) = bitmap;
                    *(Uint32 *) (rbitmapa0 + j/16 + GEM_ID * 0x1000000/4 + 
                                 0x10000000/4) = bitmap;
                    bitmap = 0;
                }
        }
        bitmappos += bitmapcount;
        xchannela.bitmap = ((xbitmapa0 + GEM_ID * 0x1000000/4 + 0x10000000/4));
        rchannela.bitmap = (rbitmapa0 + GEM_ID * 0x1000000/4 + 0x10000000/4);

        xchannelb.baseaddr = (Uint32) ((Uint8 *)Xmt0bSrcAddr + 
                                       GEM_ID * 0x1000000 + 0x10000000);
        xchannelb.falloc = 0x10;
        xchannelb.fsize = 0x10;
        xchannelb.fcount = 0x4;
        for (j = 0; j < CSL_TSIP_BITMAP_SIZE; j++) {
            *(Uint32 *)(xbitmapb0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4)=0x0;
        }
        xchannelb.bitmap = ((xbitmapb0 + GEM_ID * 0x1000000/4 + 0x10000000/4));

        rchannelb.baseaddr = (Uint32) ((Uint8 *)Rcv1bDestAddr + 
                                       GEM_ID * 0x1000000 + 0x10000000);
        rchannelb.falloc = 0x10;
        rchannelb.fsize = 0x10;
        rchannelb.fcount = 0x1;
        for (j = 0; j < CSL_TSIP_BITMAP_SIZE; j++) {
            *(Uint32 *)(rbitmapb0 + j + GEM_ID * 0x1000000/4 + 0x10000000/4)=0x0;
        }
        rchannelb.bitmap = (rbitmapb0 + GEM_ID * 0x1000000/4 + 0x10000000/4);

        tsipSetup.xchana = (CSL_TsipChanSetup*) &(xchannela);
        tsipSetup.xchanb = (CSL_TsipChanSetup*) &(xchannelb);
        tsipSetup.rchana = (CSL_TsipChanSetup*) &(rchannela);
        tsipSetup.rchanb = (CSL_TsipChanSetup*) &(rchannelb);
    
}

/*
 * =============================================================================
 *   @func   CID_Init
 *
 *   @desc
 *  @n This function initalizes the TSIP data for different channels.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void CID_Init (
)
{
    Uint32 i; 

    for (i = 0; i <= Test_List[0].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt0aSrcAddr + i * (Test_List[0].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4 + 0x10000000/4) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    for (i = 0; i <= Test_List[1].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt1aSrcAddr + i * (Test_List[1].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4+ 0x10000000/4 ) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    for (i = 0; i <= Test_List[2].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt2aSrcAddr + i * (Test_List[2].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4 + 0x10000000/4) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    for(i = 0; i <= Test_List[3].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt3aSrcAddr + i * (Test_List[3].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4 + 0x10000000/4) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    for(i = 0; i <= Test_List[4].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt4aSrcAddr + i * (Test_List[4].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4 + 0x10000000/4) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    for(i = 0; i <= Test_List[5].xmt_frame_count + 1 ; i++) {
        *(Uint32*)(Xmt5aSrcAddr + i * (Test_List[5].xmt_frame_size + 9)/4 + 
            GEM_ID * 0x1000000/4 + 0x10000000/4) = 
            (((TSIP_ID + GEM_ID << 24)) | (i+1));
    }
    
    CSL_FINST(hTsip0->regs->XCHEN[0].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[0].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->XCHEN[1].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[1].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->XCHEN[2].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[2].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->XCHEN[3].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[3].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->XCHEN[4].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[4].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->XCHEN[5].XCHEN, TSIP_XCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->XCHEN[5].XCHEN, TSIP_XCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));

    CSL_FINST(hTsip0->regs->RCHEN[0].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[0].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->RCHEN[1].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[1].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->RCHEN[2].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[2].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->RCHEN[3].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[3].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->RCHEN[4].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[4].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
    CSL_FINST(hTsip0->regs->RCHEN[5].RCHEN, TSIP_RCHEN_CHENB, ENB);
    CSL_FINS(hTsip0->regs->RCHEN[5].RCHEN, TSIP_RCHEN_CID, 
             ((TSIP_ID + GEM_ID << 24)));
}

/*
 * =============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine, which invokes TSIP external loopback example. 
 * =============================================================================
 */
void main (
    void
)
{
    Uint32 result = FAIL;

    printf("TSIP External Loopback Example \n");
    result = tsip_txRx();

	if (result == 0) {
	    printf("TSIP loopback example Passed\n");
	}
	else {
	    printf("TSIP loopback example Failed\n");
	}
}

