/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
 
/*  ============================================================================
 *  lnk.cmd   v5.00                                                         
 *         
 *    Usage:  lnk6x <obj files...>    -o <out file> -m <map file> lnk.cmd   
 *            cl6x  <src files...> -z -o <out file> -m <map file> lnk.cmd   
 *                                                                          
 *    Description: This file is a sample linker command file that can be    
 *                 used for linking programs built with the C compiler and  
 *                 running the resulting .out file on a C620x/C670x         
 *                 simulator.  Use it as a guideline.  You will want to     
 *                 change the memory layout to match your specific C6xxx    
 *                 target system.  You may want to change the allocation    
 *                 scheme according to the size of your program.            
 *                                                                          
 *    Notes: (1)   You must specivy a directory in which rts6x00.lib is     
 *                 located.  either add a -i"<directory>" line to this      
 *                 file or use the system environment variable C_DIR to     
 *                 specify a search path for the libraries.                 
 *                                                                          
 *           (2)   If the run-time library you are using is not named       
 *                 rts6200[e].lib, rts6400[e].lib, or rts6700[e].lib, be    
 *                 sure to use the correct name here.                       
 *                                                                          
 *  ============================================================================
 */

-e __c_int00
-c
-x
-heap  0x20000
-stack 0x4000
/* -l/dsp/tomahawk/src/c_tests/lib/tomahawk.lib */
/* -lrts6400.lib */


/****************************************************************************/
/*  Specify the Memory Configuration                                        */
/****************************************************************************/

MEMORY
{
  GEM0_VECS     	: origin = 0x00800000 length = 0x1000

  GEM0_L2_P0    	: origin = 0x00801000 length = 0x7E000
  GEM0_L2_P1 		: origin = 0x00881000 length = 0x7EFFF
  GEM0_L2_P0BD  	: origin = 0x0087FF80 length = 0x1000

  R0M_LOC       	: origin = 0x01000000 length = 0xC0000
  RAM_LOC       	: origin = 0x02000000 length = 0xC0000
}

/****************************************************************************/
/*  Specify the Output Sections                                             */
/****************************************************************************/


SECTIONS
{
    .boot_vectors_1 :  load = GEM0_VECS
    .boot_vectors_2 :  load = GEM0_VECS
    .boot_vectors_3 :  load = GEM0_VECS
    .boot_vectors_4 :  load = GEM0_VECS
    .boot_vectors_5 :  load = GEM0_VECS
    .boot_vectors_6 :  load = GEM0_VECS
    .text           :  load = GEM0_L2_P0
    .Program        :  load = GEM0_L2_P0
    .stack          :  load = GEM0_L2_P0  
    .cinit          :  load = GEM0_L2_P0
    .cio            :  load = GEM0_L2_P0
    .const          :  load = GEM0_L2_P0
    .data           :  load = GEM0_L2_P0
    .switch         :  load = GEM0_L2_P0
    .far            :  load = GEM0_L2_P0
    .bss            :  load = GEM0_L2_P0
    .sysmem         :  load = GEM0_L2_P0
    .csl_vect       :  load = GEM0_L2_P0
    .ram_dump       :  load = RAM_LOC
    .dump_locations :  load = RAM_LOC
    .dma_buffers    :  load = RAM_LOC
   
	/* EMAC */
    .emac_data          :  load = GEM0_L2_P0
    .emac_dataRx        :  load = GEM0_L2_P0
    .emac_dataTx        :  load = GEM0_L2_P0
    .emac_buffDescEmac0 :  load = GEM0_L2_P0
    .emac_buffDescEmac1 :  load = GEM0_L2_P0

	/* EDMA */
     Int_Dat_L2_src     :  load = GEM0_L2_P0
     Int_Dat_L2_dst     :  load = GEM0_L2_P1

    .testData           :  load = GEM0_L2_P0
    .sharedData         :  load = GEM0_L2_P0
}

