/*  ============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  utopia_interrupt.c
 *
 *   @path  $(CSLPATH)\example\utopia2\src
 *
 *   @desc  This file contains the intterupt setup for UTOPIA.  
 *
 *  ============================================================================
 */

#include <csl_intc.h>
#include <csl_intcAux.h>
Uint32 profileStopLowRcv[6] = {0,0,0,0,0,0};
Uint32 profileStopHighRcv[6] = {0,0,0,0,0,0};
void disable_interrupt(void);

interrupt void PDMATX_ISR(void);
interrupt void PDMARX_ISR(void);
interrupt void UTOPIA_ISR(void);

void UTOPIA_Setup_Interrupt();
void Close_Interrupt_Handle();

CSL_IntcEventHandlerRecord Record1[3];

CSL_IntcHandle hIntcUtopia  = NULL,hIntcPdmaTx = NULL,hIntcPdmaRx = NULL;

CSL_IntcObj intcUtopiaObj,intcPdmaTxObj,intcPdmaRxObj;


volatile Uint32 Test_Done =0;
Uint32 Tput_Test_Done = 0;

/*
 * =============================================================================
 *   @func   UTOPIA_Setup_Interrupt
 *
 *   @desc
 *  @n This function is to setup interrupt for UTOPIA
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void UTOPIA_Setup_Interrupt (
    void
)
{
    CSL_IntcContext context1;
    CSL_IntcParam vectId_0, vectId_1,vectId_2;
    CSL_IntcGlobalEnableState state;
    

    /* Setup the global Interrupt */
    context1.numEvtEntries = 24;
    context1.eventhandlerRecord = Record1; 
    CSL_intcInit(&context1);

    /* Enable NMIs  */
    CSL_intcGlobalNmiEnable();

    /* Enable Global Interrupts  */
    CSL_intcGlobalEnable(&state);

    /* Opening a handle for the Global Edma Event  */
    vectId_0 = CSL_INTC_VECTID_7;
    vectId_1 = CSL_INTC_VECTID_9;
    vectId_2 = CSL_INTC_VECTID_10;

    /* Event Id - 56 */
    hIntcUtopia	= CSL_intcOpen(&intcUtopiaObj,CSL_INTC_EVENTID_UINT,&vectId_0,
                               NULL);
    /* Event Id - 30 */
    hIntcPdmaRx = CSL_intcOpen(&intcPdmaRxObj,CSL_INTC_EVENTID_PRINT,&vectId_1,
                               NULL);
    /* Event Id - 31 */
    hIntcPdmaTx  = CSL_intcOpen(&intcPdmaTxObj,CSL_INTC_EVENTID_PXINT,&vectId_2,
                                NULL);

   	/*Hook the ISR*/
    CSL_intcHookIsr(vectId_0, &UTOPIA_ISR);
    CSL_intcHookIsr(vectId_1, &PDMARX_ISR);
    CSL_intcHookIsr(vectId_2, &PDMATX_ISR);

	/*Clear interrupts*/  
    CSL_intcHwControl(hIntcPdmaRx, CSL_INTC_CMD_EVTCLEAR,NULL);
    CSL_intcHwControl(hIntcPdmaTx, CSL_INTC_CMD_EVTCLEAR,NULL);
    CSL_intcHwControl(hIntcUtopia, CSL_INTC_CMD_EVTCLEAR,NULL);

   	/* Enable Event & interrupt */
    CSL_intcHwControl(hIntcUtopia,CSL_INTC_CMD_EVTENABLE,NULL);
    CSL_intcHwControl(hIntcPdmaTx,CSL_INTC_CMD_EVTENABLE,NULL);
    CSL_intcHwControl(hIntcPdmaRx,CSL_INTC_CMD_EVTENABLE,NULL);
}

/*
 * =============================================================================
 *   @func   UTOPIA_ISR
 *
 *   @desc
 *  @n This function is the ISR routine for utopia.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
interrupt void UTOPIA_ISR (
    void
)
{
    Uint32 loopCnt = 0;
	while (loopCnt < 0x100)
	    loopCnt++;
}

/*
 * =============================================================================
 *   @func   PDMATX_ISR
 *
 *   @desc
 *  @n This function is the PDMA transmit interrupt service routine.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
interrupt void PDMATX_ISR (
    void
)
{   
    Uint32 loopCnt = 0;

	while (loopCnt < 0x100)
	    loopCnt++;

    Test_Done++; 
	Tput_Test_Done++;
	CSL_intcHwControl(hIntcPdmaTx, CSL_INTC_CMD_EVTCLEAR, 
                      (void*)CSL_INTC_EVENTID_PXINT);
}

/*
 * =============================================================================
 *   @func   PDMARX_ISR
 *
 *   @desc
 *  @n This function is the PDMA receive interrupt service routine.
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
interrupt void PDMARX_ISR (
    void
)
{   
    Uint32 loopCnt = 0;

	while (loopCnt < 0x100)
	    loopCnt++;

	Tput_Test_Done++;
	Test_Done++;
	CSL_intcHwControl(hIntcPdmaRx, CSL_INTC_CMD_EVTCLEAR, 
                      (void*)CSL_INTC_EVENTID_PRINT);
}

/*
 * =============================================================================
 *   @func   disable_interrupt
 *
 *   @desc
 *  @n This function is to disable the interrupts
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void disable_interrupt (
    void
)
{
	CSL_intcHwControl(hIntcPdmaTx, CSL_INTC_CMD_EVTDISABLE,
                      (void*)CSL_INTC_EVENTID_PXINT);
	CSL_intcHwControl(hIntcPdmaRx, CSL_INTC_CMD_EVTDISABLE, 
                      (void*)CSL_INTC_EVENTID_PRINT);
}

/*
 * =============================================================================
 *   @func   Close_Interrupt_Handle
 *
 *   @desc
 *  @n This function is to close pdma, interrupt and/or utopia instances
 *
 *  @arg  
 *      None
 *
 *  @return
 *      None
 * =============================================================================
 */
void Close_Interrupt_Handle (
    void
)
{
	if (hIntcPdmaTx != NULL) {
        	CSL_intcClose(hIntcPdmaTx);
	}
	if (hIntcPdmaRx != NULL) {
        	CSL_intcClose(hIntcPdmaRx);
	}
	if (hIntcUtopia != NULL) {
        	CSL_intcClose(hIntcUtopia);
	}
}
/*****************************************************************************\
* End of utopia_interrupt.c
\*****************************************************************************/
