/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  _csl_tsip.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  
 *    - Header file for private functional layer of TSIP CSL 
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  @(#) PSP/CSL 3.00.01.00[5912PG1_0] (2003-11-12)
 *
 *  23-Mar-2006 NG  File taken from TI code base and modified for c6486.
 *                  Updated according coding guidelines (doxygen compliant)
 *
 * =============================================================================
 */
#ifndef __CSL_TSIP_H_
#define __CSL_TSIP_H_

#include <csl_types.h>
#include <csl_error.h>
#include <csl_tsip.h>

/** ============================================================================
 *   @n@b _CSL_tsipCfgTimeslot
 *
 *   @b Description
 *   @n Function to configure a time slot for a particular data format
 *
 *   @b Arguments
 *   @verbatim
            hTsip       Handle to TSIP Obj used
            
            slot        time slot to be configured
 *   @endverbatim
 *
 *   <b> Return Value </b> 
 *   @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Both CSL_tsipInit() and CSL_tsipOpen() must be called successfully 
 *       in order before calling this function. 
 * 
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Modifies
 *   @n TSIP Handle
 *
 *   @b Example
 *   @verbatim
        CSL_Status             status;
        CSL_TsipHandle         hTsip;
        CSL_TsipTimeslotCfg    timeslot;
        ...      
        hTsip = CSL_tsipOpen(hTsip, CSL_TSIP_1, NULL, &status);
        ...
        _CSL_tsipCfgTimeslot(hTsip, &timeslot);
        ...
 *   @endverbatim
 *  ============================================================================
 */
void  _CSL_tsipCfgTimeslot (
    CSL_TsipHandle         hTsip,
    CSL_TsipTimeslotCfg    *slot
);


#endif

