/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  csl_smcAux.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  Header file for functional layer of CSL
 *    - This decribes the definitions of the inline functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  23-May-2006 NG  File Created
 *  20-Nov-2006 KNG  File Updated
 *
 * =============================================================================
 */
#ifndef _CSL_SMCAUX_H_
#define _CSL_SMCAUX_H_

#include <csl_smc.h>

#ifdef __cplusplus
extern "C" {
#endif

/* Status Query Functions of smc. */

/** ============================================================================
 *   @n@b CSL_smcGetMode
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetMode(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetMode (
    CSL_SmcHandle    hSmc,
    void              *response
)
{
    *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2MPFSR, SMC_SL2MPFSR_MODE));
}

/** ============================================================================
 *   @n@b CSL_smcGetCpuId
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetCpuId(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetCpuId (
    CSL_SmcHandle    hSmc,
    void              *response
)
{
    *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2MPFSR, SMC_SL2MPFSR_CPU_ID));
}


/** ============================================================================
 *   @n@b CSL_smcGetFaultAddr
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetFaultAddr(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetFaultAddr (
    CSL_SmcHandle    hSmc,
    void             *response
)
{
    *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2MPFAR, 
                                    SMC_SL2MPFAR_FAULT_ADDRESS));
}


/** ============================================================================
 *   @n@b CSL_smcGetPwdnPageSts
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetPwdnPageSts(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetPwdnPageSts (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    *(Uint32 *)response = hSmc->regs->SL2PDSTAT & response->index;
}

/** ============================================================================
 *   @n@b CSL_smcGetAMLLinkDataSts
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetAMLLinkDataSts(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetAMLLinkDataSts (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    if (response->index == 0) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT0, 
                                        SMC_SL2AMLSTAT0_LINKDTV));
    }
    else if (response->index == 1) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT1, 
                                        SMC_SL2AMLSTAT1_LINKDTV));
    }
    else if (response->index == 2) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT2, 
                                        SMC_SL2AMLSTAT2_LINKDTV));
    }
    else {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT3, 
                                        SMC_SL2AMLSTAT3_LINKDTV));
    }
}

/** ============================================================================
 *   @n@b CSL_smcGetAtomicLink
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetAtomicLink(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetAtomicLink (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    if (response->index == 0) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT0, 
                                        SMC_SL2AMLSTAT0_LINKV));
    }
    else if (response->index == 1) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT1, 
                                        SMC_SL2AMLSTAT1_LINKV));
    }
    else if (response->index == 2) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT2, 
                                        SMC_SL2AMLSTAT2_LINKV));
    }
    else {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT3, 
                                        SMC_SL2AMLSTAT3_LINKV));
    }

}

/** ============================================================================
 *   @n@b CSL_smcGetLinkOwner
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetLinkOwner(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetLinkOwner (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    if (response->index == 0) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT0,
                                        SMC_SL2AMLSTAT0_CPU_ID));
    }
    else if (response->index == 1) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT1,
                                        SMC_SL2AMLSTAT1_CPU_ID));
    }
    else if (response->index == 2) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT2,
                                        SMC_SL2AMLSTAT2_CPU_ID));
    }
    else {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT3,
                                        SMC_SL2AMLSTAT3_CPU_ID));
    }
}

/** ============================================================================
 *   @n@b CSL_smcGetLinkAddr
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetLinkAddr(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetLinkAddr (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    if (response->index == 0) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT0,
                                        SMC_SL2AMLSTAT0_ADDR));
    }
    else if (response->index == 1) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT1,
                                        SMC_SL2AMLSTAT1_ADDR));
    }
    else if (response->index == 2) {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT2,
                                        SMC_SL2AMLSTAT2_ADDR));
    }
    else {
        *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLSTAT3,
                                        SMC_SL2AMLSTAT3_ADDR));
    }

}

/** ============================================================================
 *   @n@b CSL_smcGetAMLLinkData
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmc           Handle to SMC instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smc must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcGetAMLLinkData(hSmc, response);

     @endverbatim
 * =============================================================================
 */
CSL_IDEF_INLINE
void CSL_smcGetAMLLinkData (
    CSL_SmcHandle    hSmc,
    CSL_SmcData      *response
)
{
    *(Uint32 *)response = (CSL_FEXT(hSmc->regs->SL2AMLDATA[response->index], 
                                    SMC_SL2AMLDATA_LINKDATA));
}


#ifdef __cplusplus
extern "C" {
#endif

#endif /* CSL_SMCAUX_H_ */


