/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  csl_smcpAux.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  Header file for functional layer of CSL
 *    - This decribes the definitions of the inline functions
 *
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  23-Mar-2006 NG  File Created
 *
 * =============================================================================
 */
#ifndef _CSL_SMCPAUX_H_
#define _CSL_SMCPAUX_H_

#include <csl_smcp.h>

#ifdef __cplusplus
extern "C" {
#endif

/* Status Query Functions of smcp. */

/** ============================================================================
 *   @n@b CSL_smcpGetBank
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetBank(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetBank (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = hSmcp->regs->SL2BNKMSK & response->index;
}

/** ============================================================================
 *   @n@b CSL_smcpGetPwsSts
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetPwsSts(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetPwsSts (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = (CSL_FEXT(hSmcp->regs->SL2PWSCNT[response->index], 
                                    SMCP_SL2PWSCNT_WSCNT));
}

/** ============================================================================
 *   @n@b CSL_smcpGetPfcCnt
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetPfcCnt(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetPfcCnt (
    CSL_SmcpHandle    hSmcp,
    Uint32      *response
)
{
    *(Uint32 *)response = (CSL_FEXT(hSmcp->regs->SL2PFCCNT, 
                                    SMCP_SL2PFCCNT_PFCCNT));
}

/** ============================================================================
 *   @n@b CSL_smcpGetPwsCntSat
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetPwsCntSat(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetPwsCntSat (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = hSmcp->regs->SL2PSTAT & response->index;
}

/** ============================================================================
 *   @n@b CSL_smcpGetProfilerSts
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetProfilerSts(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetProfilerSts (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = CSL_FEXT(hSmcp->regs->SL2PCMD, SMCP_SL2PCMD_ENPROFILE);
}

/** ============================================================================
 *   @n@b CSL_smcpGetWsMask
 *
 *   @b Description
 *   @n This function gets the current Transmit Free Running Frame Count 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetWsMask(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetWsMask (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = hSmcp->regs->SL2STATMASK & response->index;
}

/** ============================================================================
 *   @n@b CSL_smcpGetCntClrSts
 *
 *   @b Description
 *   @n This function gets the count clear status 
 *
 *   @b Arguments
 *   @verbatim

            hSmcp           Handle to SMCP instance

            response        Placeholder to return status.

     @endverbatim
 *
 *   <b> Return Value </b>  
 *	 @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  Smcp must be initialized and opened properly
 *
 *   <b> Post Condition </b>
 *    @n None
 *
 *   @b Modifies
 *   @n  None
 *
 *   @b Example
 *   @verbatim

        CSL_smcpGetCntClrSts(hSmcp, response);

     @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE
void CSL_smcpGetCntClrSts (
    CSL_SmcpHandle    hSmcp,
    CSL_SmcpData      *response
)
{
    response->data = CSL_FEXT(hSmcp->regs->SL2PCMD, SMCP_SL2PCMD_CLEAR);
}

#ifdef __cplusplus
extern "C" {
#endif

#endif /* CSL_SMCPAUX_H_ */

