/* =============================================================================
 *  Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_bwmngmt.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for BWMNGMT
 *  ============================================================================
 */
#ifndef _CSLR_BWMNGMT_H_
#define _CSLR_BWMNGMT_H_

#include <cslr.h>
#include <csl_types.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 CPUARBEXT;
    volatile Uint32 IDMAARBEXT;
    volatile Uint32 SLAPARBEXT;
    volatile Uint32 MAPARBEXT;
    volatile Uint8 RSVD0[134640];
    volatile Uint32 CPUARBL2;
    volatile Uint32 IDMAARBL2;
    volatile Uint32 SLAPARBL2;
    volatile Uint32 UCARBL2;
    volatile Uint8 RSVD1[48];
    volatile Uint32 CPUARBL1D;
    volatile Uint32 IDMAARBL1D;
    volatile Uint32 SLAPARBL1D;
    volatile Uint32 UCARBL1D;
} CSL_BwmngmtRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_BwmngmtRegs        *CSL_BwmngmtRegsOvly;
/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* CPUARBL1D */

#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MASK          (0x0000003Fu)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_SHIFT         (0x00000000u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_RESETVAL      (0x00000010u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT0      (0x00000000u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT1      (0x00000001u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT2      (0x00000002u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT4      (0x00000004u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT8      (0x00000008u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT16     (0x00000010u)
#define CSL_BWMNGMT_CPUARBL1D_MAXWAIT_MAXWAIT32     (0x00000020u)

#define CSL_BWMNGMT_CPUARBL1D_PRI_MASK              (0x00070000u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_SHIFT             (0x00000010u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_RESETVAL          (0x00000001u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI0              (0x00000000u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI1              (0x00000001u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI2              (0x00000002u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI3              (0x00000003u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI4              (0x00000004u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI5              (0x00000005u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI6              (0x00000006u)
#define CSL_BWMNGMT_CPUARBL1D_PRI_PRI7              (0x00000007u)
                                                    
#define CSL_BWMNGMT_CPUARBL1D_RESETVAL              (0x00010010u)

/* CPUARBL2 */

#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MASK           (0x0000003Fu)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_SHIFT          (0x00000000u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_RESETVAL       (0x00000010u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT0       (0x00000000u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT1       (0x00000001u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT2       (0x00000002u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT4       (0x00000004u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT8       (0x00000008u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT16      (0x00000010u)
#define CSL_BWMNGMT_CPUARBL2_MAXWAIT_MAXWAIT32      (0x00000020u)

#define CSL_BWMNGMT_CPUARBL2_PRI_MASK               (0x00070000u)
#define CSL_BWMNGMT_CPUARBL2_PRI_SHIFT              (0x00000010u)
#define CSL_BWMNGMT_CPUARBL2_PRI_RESETVAL           (0x00000001u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI0               (0x00000000u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI1               (0x00000001u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI2               (0x00000002u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI3               (0x00000003u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI4               (0x00000004u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI5               (0x00000005u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI6               (0x00000006u)
#define CSL_BWMNGMT_CPUARBL2_PRI_PRI7               (0x00000007u)
                                                    
#define CSL_BWMNGMT_CPUARBL2_RESETVAL               (0x00010010u)

/* CPUARBEXT */

#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MASK          (0x0000003Fu)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_SHIFT         (0x00000000u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_RESETVAL      (0x00000010u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT0      (0x00000000u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT1      (0x00000001u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT2      (0x00000002u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT4      (0x00000004u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT8      (0x00000008u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT16     (0x00000010u)
#define CSL_BWMNGMT_CPUARBEXT_MAXWAIT_MAXWAIT32     (0x00000020u)

#define CSL_BWMNGMT_CPUARBEXT_PRI_MASK              (0x00070000u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_SHIFT             (0x00000010u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_RESETVAL          (0x00000001u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI0              (0x00000000u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI1              (0x00000001u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI2              (0x00000002u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI3              (0x00000003u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI4              (0x00000004u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI5              (0x00000005u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI6              (0x00000006u)
#define CSL_BWMNGMT_CPUARBEXT_PRI_PRI7              (0x00000007u)
                                                    
#define CSL_BWMNGMT_CPUARBEXT_RESETVAL              (0x00010010u)

/* IDMAARBL1D */

#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MASK         (0x0000003Fu)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_SHIFT        (0x00000000u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_RESETVAL     (0x00000010u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT0     (0x00000000u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT1     (0x00000001u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT2     (0x00000002u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT4     (0x00000004u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT8     (0x00000008u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT16    (0x00000010u)
#define CSL_BWMNGMT_IDMAARBL1D_MAXWAIT_MAXWAIT32    (0x00000020u)

#define CSL_BWMNGMT_IDMAARBL1D_RESETVAL             (0x00000010u)

/* IDMAARBL2 */

#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MASK          (0x0000003Fu)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_SHIFT         (0x00000000u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_RESETVAL      (0x00000010u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT0      (0x00000000u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT1      (0x00000001u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT2      (0x00000002u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT4      (0x00000004u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT8      (0x00000008u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT16     (0x00000010u)
#define CSL_BWMNGMT_IDMAARBL2_MAXWAIT_MAXWAIT32     (0x00000020u)

#define CSL_BWMNGMT_IDMAARBL2_RESETVAL              (0x00000010u)

/* IDMAARBEXT */

#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MASK         (0x0000003Fu)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_SHIFT        (0x00000000u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_RESETVAL     (0x00000010u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT0     (0x00000000u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT1     (0x00000001u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT2     (0x00000002u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT4     (0x00000004u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT8     (0x00000008u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT16    (0x00000010u)
#define CSL_BWMNGMT_IDMAARBEXT_MAXWAIT_MAXWAIT32    (0x00000020u)

#define CSL_BWMNGMT_IDMAARBEXT_RESETVAL             (0x00000010u)

/* SLAPARBL1D */

#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MASK         (0x0000003Fu)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_SHIFT        (0x00000000u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_RESETVAL     (0x00000001u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT0     (0x00000000u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT1     (0x00000001u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT2     (0x00000002u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT4     (0x00000004u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT8     (0x00000008u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT16    (0x00000010u)
#define CSL_BWMNGMT_SLAPARBL1D_MAXWAIT_MAXWAIT32    (0x00000020u)

#define CSL_BWMNGMT_SLAPARBL1D_RESETVAL             (0x00000001u)

/* SLAPARBL2 */

#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MASK          (0x0000003Fu)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_SHIFT         (0x00000000u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_RESETVAL      (0x00000001u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT0      (0x00000000u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT1      (0x00000001u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT2      (0x00000002u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT4      (0x00000004u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT8      (0x00000008u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT16     (0x00000010u)
#define CSL_BWMNGMT_SLAPARBL2_MAXWAIT_MAXWAIT32     (0x00000020u)

#define CSL_BWMNGMT_SLAPARBL2_RESETVAL              (0x00000001u)

/* SLAPARBEXT */

#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MASK         (0x0000003Fu)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_SHIFT        (0x00000000u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_RESETVAL     (0x00000001u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT0     (0x00000000u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT1     (0x00000001u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT2     (0x00000002u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT4     (0x00000004u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT8     (0x00000008u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT16    (0x00000010u)
#define CSL_BWMNGMT_SLAPARBEXT_MAXWAIT_MAXWAIT32    (0x00000020u)

#define CSL_BWMNGMT_SLAPARBEXT_RESETVAL             (0x00000001u)

/* UCARBL1D */

#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MASK           (0x0000003Fu)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_SHIFT          (0x00000000u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_RESETVAL       (0x00000020u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT0       (0x00000000u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT1       (0x00000001u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT2       (0x00000002u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT4       (0x00000004u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT8       (0x00000008u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT16      (0x00000010u)
#define CSL_BWMNGMT_UCARBL1D_MAXWAIT_MAXWAIT32      (0x00000020u)
                                                
#define CSL_BWMNGMT_UCARBL1D_RESETVAL               (0x00000020u)

/* UCARBL2 */

#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MASK            (0x0000003Fu)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_SHIFT           (0x00000000u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_RESETVAL        (0x00000020u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT0        (0x00000000u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT1        (0x00000001u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT2        (0x00000002u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT4        (0x00000004u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT8        (0x00000008u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT16       (0x00000010u)
#define CSL_BWMNGMT_UCARBL2_MAXWAIT_MAXWAIT32       (0x00000020u)

#define CSL_BWMNGMT_UCARBL2_RESETVAL                (0x00000020u)

/* MAPARBEXT */

#define CSL_BWMNGMT_MAPARBEXT_PRI_MASK              (0x00070000u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_SHIFT             (0x00000010u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_RESETVAL          (0x00000007u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI0              (0x00000000u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI1              (0x00000001u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI2              (0x00000002u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI3              (0x00000003u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI4              (0x00000004u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI5              (0x00000005u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI6              (0x00000006u)
#define CSL_BWMNGMT_MAPARBEXT_PRI_PRI7              (0x00000007u)

#define CSL_BWMNGMT_MAPARBEXT_RESETVAL              (0x00070000u)

#endif
