/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_dtf.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for DTF
 * =============================================================================
 */

#ifndef _CSLR_DTF_H_
#define _CSLR_DTF_H_

#include <cslr.h>
#include <tistdtypes.h>


/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 DTFCR;
} CSL_DtfRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_DtfRegs  *CSL_DtfRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* DTFCR */

#define CSL_DTF_DTFCR_AOWN_MASK          (0x80000000u)
#define CSL_DTF_DTFCR_AOWN_SHIFT         (0x0000001Fu)
#define CSL_DTF_DTFCR_AOWN_RESETVAL      (0x00000000u)

#define CSL_DTF_DTFCR_AOWN_APP           (0x00000001u)
#define CSL_DTF_DTFCR_AOWN_EMU           (0x00000000u)

#define CSL_DTF_DTFCR__RESV_MASK         (0x7FFFFFE0u)
#define CSL_DTF_DTFCR__RESV_SHIFT        (0x00000005u)
#define CSL_DTF_DTFCR__RESV_RESETVAL     (0x00000000u)

#define CSL_DTF_DTFCR_DTFFLUSH_MASK      (0x00000010u)
#define CSL_DTF_DTFCR_DTFFLUSH_SHIFT     (0x00000004u)
#define CSL_DTF_DTFCR_DTFFLUSH_RESETVAL  (0x00000000u)

#define CSL_DTF_DTFCR_DTFENABLE_MASK     (0x00000008u)
#define CSL_DTF_DTFCR_DTFENABLE_SHIFT    (0x00000003u)
#define CSL_DTF_DTFCR_DTFENABLE_RESETVAL (0x00000000u)
/*----DTFENABLE Tokens----*/
#define CSL_DTF_DTFCR_DTFENABLE_ENABLE   (0x00000001u)

#define CSL_DTF_DTFCR_SPMDISABLE_MASK    (0x00000004u)
#define CSL_DTF_DTFCR_SPMDISABLE_SHIFT   (0x00000002u)
#define CSL_DTF_DTFCR_SPMDISABLE_RESETVAL (0x00000000u)
/*----SPMDISABLE Tokens----*/
#define CSL_DTF_DTFCR_SPMDISABLE_DISABLE (0x00000001u)
#define CSL_DTF_DTFCR_SPMDISABLE_ENABLE  (0x00000000u)

#define CSL_DTF_DTFCR_DTFOWN_ST_MASK     (0x00000003u)
#define CSL_DTF_DTFCR_DTFOWN_ST_SHIFT    (0x00000000u)
#define CSL_DTF_DTFCR_DTFOWN_ST_RESETVAL (0x00000000u)
/*----DTFOWN_ST Tokens----*/
#define CSL_DTF_DTFCR_DTFOWN_ST_RELEASE  (0x00000000u)
#define CSL_DTF_DTFCR_DTFOWN_ST_CLAIM    (0x00000001u)
#define CSL_DTF_DTFCR_DTFOWN_ST_ENABLE   (0x00000002u)

#define CSL_DTF_DTFCR_RESETVAL           (0x00000000u)

#endif

