/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_ectl.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for ECTL
 *  ============================================================================
 */
#ifndef _CSLR_ECTL_H_
#define _CSLR_ECTL_H_

#include <cslr.h>

#include <tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 PSCFG;
    volatile Uint8 RSVD0[24];
    volatile Uint32 EW_INTCTL[6];
    volatile Uint8 RSVD1[200];
    volatile Uint32 RPCFG[8];
    volatile Uint32 RPSTAT[8];
    volatile Uint32 TPCFG[8];
    volatile Uint32 TPSTAT[8];
} CSL_EctlRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */

#define CSL_ECTC_PID_PID_MASK            (0xFFFFFFFFu)
#define CSL_ECTL_PID_PID_SHIFT           (0x00000000u)
#define CSL_ECTL_PID_PID_RESETVAL        (0x400A0900u)

#define CSL_ECTL_PID_RESETVAL            (0x400A0900u)

/* PSCFG */

#define CSL_ECTL_PSCFG_PRESCALE_CFG_MASK (0x0000FFFFu)
#define CSL_ECTL_PSCFG_PRESCALE_CFG_SHIFT (0x00000000u)
#define CSL_ECTL_PSCFG_PRESCALE_CFG_RESETVAL (0x00000000u)

#define CSL_ECTL_PSCFG_RESETVAL          (0x00000000u)


/* EW_INTCTL */

#define CSL_ECTL_EW_INTCTL_RX7_MASK      (0x00800000u)
#define CSL_ECTL_EW_INTCTL_RX7_SHIFT     (0x00000017u)
#define CSL_ECTL_EW_INTCTL_RX7_RESETVAL  (0x00000000u)

/*----RX7 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX7_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX7_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX6_MASK      (0x00400000u)
#define CSL_ECTL_EW_INTCTL_RX6_SHIFT     (0x00000016u)
#define CSL_ECTL_EW_INTCTL_RX6_RESETVAL  (0x00000000u)

/*----RX6 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX6_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX6_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX5_MASK      (0x00200000u)
#define CSL_ECTL_EW_INTCTL_RX5_SHIFT     (0x00000015u)
#define CSL_ECTL_EW_INTCTL_RX5_RESETVAL  (0x00000000u)

/*----RX5 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX5_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX5_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX4_MASK      (0x00100000u)
#define CSL_ECTL_EW_INTCTL_RX4_SHIFT     (0x00000014u)
#define CSL_ECTL_EW_INTCTL_RX4_RESETVAL  (0x00000000u)

/*----RX4 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX4_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX4_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX3_MASK      (0x00080000u)
#define CSL_ECTL_EW_INTCTL_RX3_SHIFT     (0x00000013u)
#define CSL_ECTL_EW_INTCTL_RX3_RESETVAL  (0x00000000u)

/*----RX3 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX3_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX3_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX2_MASK      (0x00040000u)
#define CSL_ECTL_EW_INTCTL_RX2_SHIFT     (0x00000012u)
#define CSL_ECTL_EW_INTCTL_RX2_RESETVAL  (0x00000000u)

/*----RX2 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX2_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX2_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX1_MASK      (0x00020000u)
#define CSL_ECTL_EW_INTCTL_RX1_SHIFT     (0x00000011u)
#define CSL_ECTL_EW_INTCTL_RX1_RESETVAL  (0x00000000u)

/*----RX1 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX1_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX1_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RX0_MASK      (0x00010000u)
#define CSL_ECTL_EW_INTCTL_RX0_SHIFT     (0x00000010u)
#define CSL_ECTL_EW_INTCTL_RX0_RESETVAL  (0x00000000u)

/*----RX0 Tokens----*/
#define CSL_ECTL_EW_INTCTL_RX0_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_RX0_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX7_MASK      (0x00008000u)
#define CSL_ECTL_EW_INTCTL_TX7_SHIFT     (0x0000000Fu)
#define CSL_ECTL_EW_INTCTL_TX7_RESETVAL  (0x00000000u)

/*----TX7 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX7_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX7_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX6_MASK      (0x00004000u)
#define CSL_ECTL_EW_INTCTL_TX6_SHIFT     (0x0000000Eu)
#define CSL_ECTL_EW_INTCTL_TX6_RESETVAL  (0x00000000u)

/*----TX6 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX6_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX6_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX5_MASK      (0x00002000u)
#define CSL_ECTL_EW_INTCTL_TX5_SHIFT     (0x0000000Du)
#define CSL_ECTL_EW_INTCTL_TX5_RESETVAL  (0x00000000u)

/*----TX5 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX5_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX5_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX4_MASK      (0x00001000u)
#define CSL_ECTL_EW_INTCTL_TX4_SHIFT     (0x0000000Cu)
#define CSL_ECTL_EW_INTCTL_TX4_RESETVAL  (0x00000000u)

/*----TX4 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX4_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX4_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX3_MASK      (0x00000800u)
#define CSL_ECTL_EW_INTCTL_TX3_SHIFT     (0x0000000Bu)
#define CSL_ECTL_EW_INTCTL_TX3_RESETVAL  (0x00000000u)

/*----TX3 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX3_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX3_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX2_MASK      (0x00000400u)
#define CSL_ECTL_EW_INTCTL_TX2_SHIFT     (0x0000000Au)
#define CSL_ECTL_EW_INTCTL_TX2_RESETVAL  (0x00000000u)

/*----TX2 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX2_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX2_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX1_MASK      (0x00000200u)
#define CSL_ECTL_EW_INTCTL_TX1_SHIFT     (0x00000009u)
#define CSL_ECTL_EW_INTCTL_TX1_RESETVAL  (0x00000000u)

/*----TX1 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX1_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX1_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_TX0_MASK      (0x00000100u)
#define CSL_ECTL_EW_INTCTL_TX0_SHIFT     (0x00000008u)
#define CSL_ECTL_EW_INTCTL_TX0_RESETVAL  (0x00000000u)

/*----TX0 Tokens----*/
#define CSL_ECTL_EW_INTCTL_TX0_DISABLE   (0x00000000u)
#define CSL_ECTL_EW_INTCTL_TX0_ENABLE    (0x00000001u)

#define CSL_ECTL_EW_INTCTL_MDIO_USER_MASK (0x00000010u)
#define CSL_ECTL_EW_INTCTL_MDIO_USER_SHIFT (0x00000004u)
#define CSL_ECTL_EW_INTCTL_MDIO_USER_RESETVAL (0x00000000u)

/*----MDIO_USER Tokens----*/
#define CSL_ECTL_EW_INTCTL_MDIO_USER_DISABLE (0x00000000u)
#define CSL_ECTL_EW_INTCTL_MDIO_USER_ENABLE (0x00000001u)

#define CSL_ECTL_EW_INTCTL_MDIO_LINT_MASK (0x00000008u)
#define CSL_ECTL_EW_INTCTL_MDIO_LINT_SHIFT (0x00000003u)
#define CSL_ECTL_EW_INTCTL_MDIO_LINT_RESETVAL (0x00000000u)

/*----MDIO_LINT Tokens----*/
#define CSL_ECTL_EW_INTCTL_MDIO_LINT_DISABLE (0x00000000u)
#define CSL_ECTL_EW_INTCTL_MDIO_LINT_ENABLE (0x00000001u)

#define CSL_ECTL_EW_INTCTL_STAT_MASK     (0x00000004u)
#define CSL_ECTL_EW_INTCTL_STAT_SHIFT    (0x00000002u)
#define CSL_ECTL_EW_INTCTL_STAT_RESETVAL (0x00000000u)

/*----STAT Tokens----*/
#define CSL_ECTL_EW_INTCTL_STAT_DISABLE  (0x00000000u)
#define CSL_ECTL_EW_INTCTL_STAT_ENABLE   (0x00000001u)

#define CSL_ECTL_EW_INTCTL_HOST_MASK     (0x00000002u)
#define CSL_ECTL_EW_INTCTL_HOST_SHIFT    (0x00000001u)
#define CSL_ECTL_EW_INTCTL_HOST_RESETVAL (0x00000000u)

/*----HOST Tokens----*/
#define CSL_ECTL_EW_INTCTL_HOST_DISABLE  (0x00000000u)
#define CSL_ECTL_EW_INTCTL_HOST_ENABLE   (0x00000001u)

#define CSL_ECTL_EW_INTCTL_RESETVAL      (0x00000000u)

/* RPCFG */

#define CSL_ECTL_RPCFG_TIME_CFG_MASK     (0x0FFF0000u)
#define CSL_ECTL_RPCFG_TIME_CFG_SHIFT    (0x00000010u)
#define CSL_ECTL_RPCFG_TIME_CFG_RESETVAL (0x00000000u)

#define CSL_ECTL_RPCFG_CNT_CFG_MASK      (0x0000FF00u)
#define CSL_ECTL_RPCFG_CNT_CFG_SHIFT     (0x00000008u)
#define CSL_ECTL_RPCFG_CNT_CFG_RESETVAL  (0x00000000u)

#define CSL_ECTL_RPCFG_TU_MASK           (0x00000008u)
#define CSL_ECTL_RPCFG_TU_SHIFT          (0x00000003u)
#define CSL_ECTL_RPCFG_TU_RESETVAL       (0x00000000u)

/*----TU Tokens----*/
#define CSL_ECTL_RPCFG_TU_ENABLE         (0x00000001u)

#define CSL_ECTL_RPCFG_CU_MASK           (0x00000004u)
#define CSL_ECTL_RPCFG_CU_SHIFT          (0x00000002u)
#define CSL_ECTL_RPCFG_CU_RESETVAL       (0x00000000u)

/*----CU Tokens----*/
#define CSL_ECTL_RPCFG_CU_ENABLE         (0x00000001u)

#define CSL_ECTL_RPCFG_TR_MASK           (0x00000002u)
#define CSL_ECTL_RPCFG_TR_SHIFT          (0x00000001u)
#define CSL_ECTL_RPCFG_TR_RESETVAL       (0x00000000u)

/*----TR Tokens----*/
#define CSL_ECTL_RPCFG_TR_RESET          (0x00000001u)

#define CSL_ECTL_RPCFG_CR_MASK           (0x00000001u)
#define CSL_ECTL_RPCFG_CR_SHIFT          (0x00000000u)
#define CSL_ECTL_RPCFG_CR_RESETVAL       (0x00000000u)

/*----CR Tokens----*/
#define CSL_ECTL_RPCFG_CR_RESET          (0x00000001u)

#define CSL_ECTL_RPCFG_RESETVAL          (0x00000000u)

/* RPSTAT */

#define CSL_ECTL_RPSTAT_TIME_MASK        (0x0FFF0000u)
#define CSL_ECTL_RPSTAT_TIME_SHIFT       (0x00000010u)
#define CSL_ECTL_RPSTAT_TIME_RESETVAL    (0x00000000u)

#define CSL_ECTL_RPSTAT_CNT_MASK         (0x0000FF00u)
#define CSL_ECTL_RPSTAT_CNT_SHIFT        (0x00000008u)
#define CSL_ECTL_RPSTAT_CNT_RESETVAL     (0x00000000u)

#define CSL_ECTL_RPSTAT_TIM_SM_MASK      (0x0000000Cu)
#define CSL_ECTL_RPSTAT_TIM_SM_SHIFT     (0x00000002u)
#define CSL_ECTL_RPSTAT_TIM_SM_RESETVAL  (0x00000000u)

/*----TIM_SM Tokens----*/
#define CSL_ECTL_RPSTAT_TIM_SM_WAITING   (0x00000000u)
#define CSL_ECTL_RPSTAT_TIM_SM_DELAY     (0x00000001u)
#define CSL_ECTL_RPSTAT_TIM_SM_OUTPUT    (0x00000002u)

#define CSL_ECTL_RPSTAT_DIV_SM_MASK      (0x00000003u)
#define CSL_ECTL_RPSTAT_DIV_SM_SHIFT     (0x00000000u)
#define CSL_ECTL_RPSTAT_DIV_SM_RESETVAL  (0x00000000u)

/*----DIV_SM Tokens----*/
#define CSL_ECTL_RPSTAT_DIV_SM_WAITING   (0x00000000u)
#define CSL_ECTL_RPSTAT_DIV_SM_COUNT     (0x00000001u)
#define CSL_ECTL_RPSTAT_DIV_SM_OUTPUT    (0x00000002u)

#define CSL_ECTL_RPSTAT_RESETVAL         (0x00000000u)

/* TPCFG */

#define CSL_ECTL_TPCFG_TIME_CFG_MASK     (0x0FFF0000u)
#define CSL_ECTL_TPCFG_TIME_CFG_SHIFT    (0x00000010u)
#define CSL_ECTL_TPCFG_TIME_CFG_RESETVAL (0x00000000u)

#define CSL_ECTL_TPCFG_CNT_CFG_MASK      (0x0000FF00u)
#define CSL_ECTL_TPCFG_CNT_CFG_SHIFT     (0x00000008u)
#define CSL_ECTL_TPCFG_CNT_CFG_RESETVAL  (0x00000000u)

#define CSL_ECTL_TPCFG_TU_MASK           (0x00000008u)
#define CSL_ECTL_TPCFG_TU_SHIFT          (0x00000003u)
#define CSL_ECTL_TPCFG_TU_RESETVAL       (0x00000000u)

/*----TU Tokens----*/
#define CSL_ECTL_TPCFG_TU_ENABLE         (0x00000001u)

#define CSL_ECTL_TPCFG_CU_MASK           (0x00000004u)
#define CSL_ECTL_TPCFG_CU_SHIFT          (0x00000002u)
#define CSL_ECTL_TPCFG_CU_RESETVAL       (0x00000000u)

/*----CU Tokens----*/
#define CSL_ECTL_TPCFG_CU_ENABLE         (0x00000001u)

#define CSL_ECTL_TPCFG_TR_MASK           (0x00000002u)
#define CSL_ECTL_TPCFG_TR_SHIFT          (0x00000001u)
#define CSL_ECTL_TPCFG_TR_RESETVAL       (0x00000000u)

/*----TR Tokens----*/
#define CSL_ECTL_TPCFG_TR_RESET          (0x00000001u)

#define CSL_ECTL_TPCFG_CR_MASK           (0x00000001u)
#define CSL_ECTL_TPCFG_CR_SHIFT          (0x00000000u)
#define CSL_ECTL_TPCFG_CR_RESETVAL       (0x00000000u)

/*----CR Tokens----*/
#define CSL_ECTL_TPCFG_CR_RESET          (0x00000001u)

#define CSL_ECTL_TPCFG_RESETVAL          (0x00000000u)

/* TPSTAT */

#define CSL_ECTL_TPSTAT_TIME_MASK        (0x0FFF0000u)
#define CSL_ECTL_TPSTAT_TIME_SHIFT       (0x00000010u)
#define CSL_ECTL_TPSTAT_TIME_RESETVAL    (0x00000000u)

#define CSL_ECTL_TPSTAT_CNT_MASK         (0x0000FF00u)
#define CSL_ECTL_TPSTAT_CNT_SHIFT        (0x00000008u)
#define CSL_ECTL_TPSTAT_CNT_RESETVAL     (0x00000000u)

#define CSL_ECTL_TPSTAT_TIM_SM_MASK      (0x0000000Cu)
#define CSL_ECTL_TPSTAT_TIM_SM_SHIFT     (0x00000002u)
#define CSL_ECTL_TPSTAT_TIM_SM_RESETVAL  (0x00000000u)

/*----TIM_SM Tokens----*/
#define CSL_ECTL_TPSTAT_TIM_SM_WAITING   (0x00000000u)
#define CSL_ECTL_TPSTAT_TIM_SM_DELAY     (0x00000001u)
#define CSL_ECTL_TPSTAT_TIM_SM_OUTPUT    (0x00000002u)

#define CSL_ECTL_TPSTAT_DIV_SM_MASK      (0x00000003u)
#define CSL_ECTL_TPSTAT_DIV_SM_SHIFT     (0x00000000u)
#define CSL_ECTL_TPSTAT_DIV_SM_RESETVAL  (0x00000000u)

/*----DIV_SM Tokens----*/
#define CSL_ECTL_TPSTAT_DIV_SM_WAITING   (0x00000000u)
#define CSL_ECTL_TPSTAT_DIV_SM_COUNT     (0x00000001u)
#define CSL_ECTL_TPSTAT_DIV_SM_OUTPUT    (0x00000002u)

#define CSL_ECTL_TPSTAT_RESETVAL         (0x00000000u)

#endif
