/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_pim.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for PIM
 *  ============================================================================
 */
#ifndef _CSLR_PIM_H_
#define _CSLR_PIM_H_

#include <cslr.h>

#include "tistdtypes.h"

/**************************************************************************\
* Register Overlay Structure for CHPROXY
\**************************************************************************/
typedef struct  {
    volatile Uint32 SAR;
    volatile Uint32 PAR;
    volatile Uint32 BUFSIZE;
    volatile Uint32 TCR;
} CSL_PimChproxyRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 GCSR;
    volatile Uint8 RSVD0[24];
    volatile Uint32 STATR[8];
    volatile Uint8 RSVD1[32];
    volatile Uint32 PCR[8];
    volatile Uint32 MMCR[8];
    volatile Uint8 RSVD2[96];
    CSL_PimChproxyRegs CHPROXY[16];
} CSL_PimRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_PimRegs              *CSL_PdmaRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SAR */

#define CSL_PIM_SAR_MSB_MASK             (0xFFFF0000u)
#define CSL_PIM_SAR_MSB_SHIFT            (0x00000010u)
#define CSL_PIM_SAR_MSB_RESETVAL         (0x00000000u)

#define CSL_PIM_SAR_LSB_MASK             (0x0000FFFFu)
#define CSL_PIM_SAR_LSB_SHIFT            (0x00000000u)
#define CSL_PIM_SAR_LSB_RESETVAL         (0x00000000u)
/*----LSB Tokens----*/
#define CSL_PIM_SAR_LSB_CLR              (0x00000001u)

#define CSL_PIM_SAR_RESETVAL             (0x00000000u)

/* PAR */

#define CSL_PIM_PAR_MSB_MASK             (0xFFFF0000u)
#define CSL_PIM_PAR_MSB_SHIFT            (0x00000010u)
#define CSL_PIM_PAR_MSB_RESETVAL         (0x00000000u)

#define CSL_PIM_PAR_LSB_MASK             (0x0000FFFFu)
#define CSL_PIM_PAR_LSB_SHIFT            (0x00000000u)
#define CSL_PIM_PAR_LSB_RESETVAL         (0x00000000u)
/*----LSB Tokens----*/
#define CSL_PIM_PAR_LSB_CLR              (0x00000001u)

#define CSL_PIM_PAR_RESETVAL             (0x00000000u)

/* BUFSIZE */

#define CSL_PIM_BUFSIZE_PBUF_MASK        (0xFFFF0000u)
#define CSL_PIM_BUFSIZE_PBUF_SHIFT       (0x00000010u)
#define CSL_PIM_BUFSIZE_PBUF_RESETVAL    (0x00000000u)

#define CSL_PIM_BUFSIZE_SBUF_MASK        (0x0000FFFFu)
#define CSL_PIM_BUFSIZE_SBUF_SHIFT       (0x00000000u)
#define CSL_PIM_BUFSIZE_SBUF_RESETVAL    (0x00000000u)

#define CSL_PIM_BUFSIZE_RESETVAL         (0x00000000u)

/* TCR */

#define CSL_PIM_TCR_STRT_MASK            (0x80000000u)
#define CSL_PIM_TCR_STRT_SHIFT           (0x0000001Fu)
#define CSL_PIM_TCR_STRT_RESETVAL        (0x00000000u)

#define CSL_PIM_TCR_IMOD_MASK            (0x10000000u)
#define CSL_PIM_TCR_IMOD_SHIFT           (0x0000001Cu)
#define CSL_PIM_TCR_IMOD_RESETVAL        (0x00000000u)

#define CSL_PIM_TCR_IE_MASK              (0x08000000u)
#define CSL_PIM_TCR_IE_SHIFT             (0x0000001Bu)
#define CSL_PIM_TCR_IE_RESETVAL          (0x00000000u)

#define CSL_PIM_TCR_SINT_MASK            (0x07000000u)
#define CSL_PIM_TCR_SINT_SHIFT           (0x00000018u)
#define CSL_PIM_TCR_SINT_RESETVAL        (0x00000000u)

#define CSL_PIM_TCR_PSIZ_MASK            (0x00C00000u)
#define CSL_PIM_TCR_PSIZ_SHIFT           (0x00000016u)
#define CSL_PIM_TCR_PSIZ_RESETVAL        (0x00000000u)

#define CSL_PIM_TCR_SSIZ_MASK            (0x00300000u)
#define CSL_PIM_TCR_SSIZ_SHIFT           (0x00000014u)
#define CSL_PIM_TCR_SSIZ_RESETVAL        (0x00000000u)

#define CSL_PIM_TCR_FF_MASK              (0x00020000u)
#define CSL_PIM_TCR_FF_SHIFT             (0x00000011u)
#define CSL_PIM_TCR_FF_RESETVAL          (0x00000000u)

#define CSL_PIM_TCR_BCZ_MASK             (0x00010000u)
#define CSL_PIM_TCR_BCZ_SHIFT            (0x00000010u)
#define CSL_PIM_TCR_BCZ_RESETVAL         (0x00000000u)

#define CSL_PIM_TCR_WRPTR_MASK           (0x00007F00u)
#define CSL_PIM_TCR_WRPTR_SHIFT          (0x00000008u)
#define CSL_PIM_TCR_WRPTR_RESETVAL       (0x00000000u)

#define CSL_PIM_TCR_RDPTR_MASK           (0x0000007Fu)
#define CSL_PIM_TCR_RDPTR_SHIFT          (0x00000000u)
#define CSL_PIM_TCR_RDPTR_RESETVAL       (0x00000000u)

#define CSL_PIM_TCR_RESETVAL             (0x00000000u)

/* PID */

#define CSL_PIM_PID_TID_MASK             (0x00FF0000u)
#define CSL_PIM_PID_TID_SHIFT            (0x00000010u)
#define CSL_PIM_PID_TID_RESETVAL         (0x00000001u)

#define CSL_PIM_PID_CID_MASK             (0x0000FF00u)
#define CSL_PIM_PID_CID_SHIFT            (0x00000008u)
#define CSL_PIM_PID_CID_RESETVAL         (0x00000004u)

#define CSL_PIM_PID_PREV_MASK            (0x000000FFu)
#define CSL_PIM_PID_PREV_SHIFT           (0x00000000u)
#define CSL_PIM_PID_PREV_RESETVAL        (0x00000001u)

#define CSL_PIM_PID_RESETVAL             (0x00010401u)

/* GCSR */

#define CSL_PIM_GCSR_STRT_MASK           (0x80000000u)
#define CSL_PIM_GCSR_STRT_SHIFT          (0x0000001Fu)
#define CSL_PIM_GCSR_STRT_RESETVAL       (0x00000000u)
/*----STRT Tokens----*/
#define CSL_PIM_GCSR_STRT_HALTED         (0x00000000u)
#define CSL_PIM_GCSR_STRT_ENABLED        (0x00000001u)

#define CSL_PIM_GCSR_SOFT_MASK           (0x00000002u)
#define CSL_PIM_GCSR_SOFT_SHIFT          (0x00000001u)
#define CSL_PIM_GCSR_SOFT_RESETVAL       (0x00000001u)
/*----SOFT Tokens----*/
#define CSL_PIM_GCSR_SOFT_HALTED         (0x00000001u)

#define CSL_PIM_GCSR_FREE_MASK           (0x00000001u)
#define CSL_PIM_GCSR_FREE_SHIFT          (0x00000000u)
#define CSL_PIM_GCSR_FREE_RESETVAL       (0x00000001u)
/*----FREE Tokens----*/
#define CSL_PIM_GCSR_FREE_HALT           (0x00000000u)
#define CSL_PIM_GCSR_FREE_RUN            (0x00000001u)

#define CSL_PIM_GCSR_RESETVAL            (0x00000003u)

/* STATR */

#define CSL_PIM_STATR_WAIT_MASK          (0xFFFF0000u)
#define CSL_PIM_STATR_WAIT_SHIFT         (0x00000010u)
#define CSL_PIM_STATR_WAIT_RESETVAL      (0x00000000u)

#define CSL_PIM_STATR_ERROR_MASK         (0x0000FFFFu)
#define CSL_PIM_STATR_ERROR_SHIFT        (0x00000000u)
#define CSL_PIM_STATR_ERROR_RESETVAL     (0x00000000u)

#define CSL_PIM_STATR_RESETVAL           (0x00000000u)

/* PCR */

#define CSL_PIM_PCR_BEND_MASK            (0x04000000u)
#define CSL_PIM_PCR_BEND_SHIFT           (0x0000001Au)
#define CSL_PIM_PCR_BEND_RESETVAL        (0x00000000u)
/*----BEND Tokens----*/
#define CSL_PIM_PCR_BEND_LITTLE_ENDIAN   (0x00000000u)
#define CSL_PIM_PCR_BEND_BIG_ENDIAN      (0x00000001u)

#define CSL_PIM_PCR_CLRS_MASK            (0x02000000u)
#define CSL_PIM_PCR_CLRS_SHIFT           (0x00000019u)
#define CSL_PIM_PCR_CLRS_RESETVAL        (0x00000000u)
/*----CLRS Tokens----*/
#define CSL_PIM_PCR_CLRS_DISABLE         (0x00000000u)
#define CSL_PIM_PCR_CLRS_ENABLE          (0x00000001u)

#define CSL_PIM_PCR_SFRM_MASK            (0x01000000u)
#define CSL_PIM_PCR_SFRM_SHIFT           (0x00000018u)
#define CSL_PIM_PCR_SFRM_RESETVAL        (0x00000000u)
/*----SFRM Tokens----*/
#define CSL_PIM_PCR_SFRM_DISABLE         (0x00000000u)
#define CSL_PIM_PCR_SFRM_ENABLE          (0x00000001u)

#define CSL_PIM_PCR_PE_MASK              (0x00C00000u)
#define CSL_PIM_PCR_PE_SHIFT             (0x00000016u)
#define CSL_PIM_PCR_PE_RESETVAL          (0x00000000u)

/*----_RESV Tokens----*/
#define CSL_PIM_PCR__RESV_ACLK           (0x00000000u)

#define CSL_PIM_PCR_SYNC_MASK            (0x00100000u)
#define CSL_PIM_PCR_SYNC_SHIFT           (0x00000014u)
#define CSL_PIM_PCR_SYNC_RESETVAL        (0x00000000u)
/*----SYNC Tokens----*/
#define CSL_PIM_PCR_SYNC_DISABLE         (0x00000000u)
#define CSL_PIM_PCR_SYNC_ENABLE          (0x00000001u)

#define CSL_PIM_PCR_PRI_MASK             (0x000C0000u)
#define CSL_PIM_PCR_PRI_SHIFT            (0x00000012u)
#define CSL_PIM_PCR_PRI_RESETVAL         (0x00000000u)
/*----PRI Tokens----*/
#define CSL_PIM_PCR_PRI_LOWEST           (0x00000000u)
#define CSL_PIM_PCR_PRI_LOW              (0x00000001u)
#define CSL_PIM_PCR_PRI_HIGH             (0x00000002u)
#define CSL_PIM_PCR_PRI_HIGHEST          (0x00000002u)

#define CSL_PIM_PCR_ABU_MASK             (0x00020000u)
#define CSL_PIM_PCR_ABU_SHIFT            (0x00000011u)
#define CSL_PIM_PCR_ABU_RESETVAL         (0x00000000u)
/*----ABU Tokens----*/
#define CSL_PIM_PCR_ABU_DISABLE          (0x00000000u)
#define CSL_PIM_PCR_ABU_ENABLE           (0x00000001u)

#define CSL_PIM_PCR_DIR_MASK             (0x00010000u)
#define CSL_PIM_PCR_DIR_SHIFT            (0x00000010u)
#define CSL_PIM_PCR_DIR_RESETVAL         (0x00000000u)
/*----DIR Tokens----*/
#define CSL_PIM_PCR_DIR_SW_TO_PERI       (0x00000000u)
#define CSL_PIM_PCR_DIR_PERI_TO_SW       (0x00000001u)

#define CSL_PIM_PCR_PBLEN_MASK           (0x0000F000u)
#define CSL_PIM_PCR_PBLEN_SHIFT          (0x0000000Cu)
#define CSL_PIM_PCR_PBLEN_RESETVAL       (0x00000000u)

#define CSL_PIM_PCR_PMOD_MASK            (0x00000800u)
#define CSL_PIM_PCR_PMOD_SHIFT           (0x0000000Bu)
#define CSL_PIM_PCR_PMOD_RESETVAL        (0x00000000u)
/*----PMOD Tokens----*/
#define CSL_PIM_PCR_PMOD_INCR            (0x00000000u)
#define CSL_PIM_PCR_PMOD_CONST           (0x00000001u)

#define CSL_PIM_PCR_SBLEN_MASK           (0x000000F0u)
#define CSL_PIM_PCR_SBLEN_SHIFT          (0x00000004u)
#define CSL_PIM_PCR_SBLEN_RESETVAL       (0x00000000u)

#define CSL_PIM_PCR_SMOD_MASK            (0x00000008u)
#define CSL_PIM_PCR_SMOD_SHIFT           (0x00000003u)
#define CSL_PIM_PCR_SMOD_RESETVAL        (0x00000000u)
/*----SMOD Tokens----*/
#define CSL_PIM_PCR_SMOD_INCR            (0x00000000u)
#define CSL_PIM_PCR_SMOD_CONST           (0x00000001u)

#define CSL_PIM_PCR_RESETVAL             (0x00000000u)

/* MMCR */

#define CSL_PIM_MMCR_SYNC_MASK           (0x00100000u)
#define CSL_PIM_MMCR_SYNC_SHIFT          (0x00000014u)
#define CSL_PIM_MMCR_SYNC_RESETVAL       (0x00000000u)
/*----SYNC Tokens----*/
#define CSL_PIM_MMCR_SYNC_DISABLE        (0x00000000u)
#define CSL_PIM_MMCR_SYNC_ENABLE         (0x00000001u)

#define CSL_PIM_MMCR_PRI_MASK            (0x000C0000u)
#define CSL_PIM_MMCR_PRI_SHIFT           (0x00000012u)
#define CSL_PIM_MMCR_PRI_RESETVAL        (0x00000000u)
/*----PRI Tokens----*/
#define CSL_PIM_MMCR_PRI_LOWEST          (0x00000000u)
#define CSL_PIM_MMCR_PRI_LOW             (0x00000001u)
#define CSL_PIM_MMCR_PRI_HIGH            (0x00000002u)
#define CSL_PIM_MMCR_PRI_HIGHEST         (0x00000002u)

#define CSL_PIM_MMCR_ABU_MASK            (0x00020000u)
#define CSL_PIM_MMCR_ABU_SHIFT           (0x00000011u)
#define CSL_PIM_MMCR_ABU_RESETVAL        (0x00000000u)
/*----ABU Tokens----*/
#define CSL_PIM_MMCR_ABU_DISABLE         (0x00000000u)
#define CSL_PIM_MMCR_ABU_ENABLE          (0x00000001u)

#define CSL_PIM_MMCR_DIR_MASK            (0x00010000u)
#define CSL_PIM_MMCR_DIR_SHIFT           (0x00000010u)
#define CSL_PIM_MMCR_DIR_RESETVAL        (0x00000000u)
/*----DIR Tokens----*/
#define CSL_PIM_MMCR_DIR_SW_TO_PERI      (0x00000000u)
#define CSL_PIM_MMCR_DIR_PERI_TO_SW      (0x00000001u)

#define CSL_PIM_MMCR_PBLEN_MASK          (0x0000F000u)
#define CSL_PIM_MMCR_PBLEN_SHIFT         (0x0000000Cu)
#define CSL_PIM_MMCR_PBLEN_RESETVAL      (0x00000000u)

#define CSL_PIM_MMCR_PMOD_MASK           (0x00000800u)
#define CSL_PIM_MMCR_PMOD_SHIFT          (0x0000000Bu)
#define CSL_PIM_MMCR_PMOD_RESETVAL       (0x00000000u)
/*----PMOD Tokens----*/
#define CSL_PIM_MMCR_PMOD_INCR           (0x00000000u)
#define CSL_PIM_MMCR_PMOD_CONST          (0x00000001u)

#define CSL_PIM_MMCR_SBLEN_MASK          (0x000000F0u)
#define CSL_PIM_MMCR_SBLEN_SHIFT         (0x00000004u)
#define CSL_PIM_MMCR_SBLEN_RESETVAL      (0x00000000u)

#define CSL_PIM_MMCR_SMOD_MASK           (0x00000008u)
#define CSL_PIM_MMCR_SMOD_SHIFT          (0x00000003u)
#define CSL_PIM_MMCR_SMOD_RESETVAL       (0x00000000u)
/*----SMOD Tokens----*/
#define CSL_PIM_MMCR_SMOD_INCR           (0x00000000u)
#define CSL_PIM_MMCR_SMOD_CONST          (0x00000001u)

#define CSL_PIM_MMCR_RESETVAL            (0x00000000u)

#endif
