/* =============================================================================
 *  Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_pllc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for PLLC
 *  ============================================================================
 */

#ifndef _CSLR_PLLC_H_
#define _CSLR_PLLC_H_

#include <cslr.h>

#include "tistdtypes.h"


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint8 RSVD0[220];
    volatile Uint32 FUSERR;
    volatile Uint32 RSTYPE;
    volatile Uint8 RSVD1[24];
    volatile Uint32 PLLCTL;
    volatile Uint8 RSVD2[12];
    volatile Uint32 PLLM;
    volatile Uint8 RSVD5[4];
    volatile Uint32 PLLDIV1;
    volatile Uint32 PLLDIV2;
    volatile Uint32 PLLDIV3;
    volatile Uint8 RSVD3[20];
    volatile Uint32 PLLCMD;
    volatile Uint32 PLLSTAT;
    volatile Uint32 ALNCTL;
    volatile Uint32 DCHANGE;
    volatile Uint8 RSVD6[8];
    volatile Uint32 SYSTAT;
    volatile Uint32 CKCTL;
    volatile Uint8 RSVD4[8];
    volatile Uint32 PLLDIV4;
    volatile Uint32 PLLDIV5;
    volatile Uint32 PLLDIV6;
    volatile Uint32 PLLDIV7;
    volatile Uint32 PLLDIV8;
    volatile Uint32 PLLDIV9;
    volatile Uint32 PLLDIV10;
} CSL_PllcRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_PllcRegs             *CSL_PllcRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */


#define CSL_PLLC_PID_TYPE_MASK           (0x00FF0000u)
#define CSL_PLLC_PID_TYPE_SHIFT          (0x00000010u)
#define CSL_PLLC_PID_TYPE_RESETVAL       (0x00000001u)

#define CSL_PLLC_PID_CLASS_MASK          (0x0000FF00u)
#define CSL_PLLC_PID_CLASS_SHIFT         (0x00000008u)
#define CSL_PLLC_PID_CLASS_RESETVAL      (0x00000008u)

#define CSL_PLLC_PID_REV_MASK            (0x000000FFu)
#define CSL_PLLC_PID_REV_SHIFT           (0x00000000u)
#define CSL_PLLC_PID_REV_RESETVAL        (0x00000002u)

#define CSL_PLLC_PID_RESETVAL            (0x00010802u)

/* FUSERR */


#define CSL_PLLC_FUSERR_ERR_MASK         (0x0000001Fu)
#define CSL_PLLC_FUSERR_ERR_SHIFT        (0x00000000u)
#define CSL_PLLC_FUSERR_ERR_RESETVAL     (0x00000000u)

#define CSL_PLLC_FUSERR_RESETVAL         (0x00000000u)

/* RSTYPE */


#define CSL_PLLC_RSTYPE_SRST_MASK        (0x00000008u)
#define CSL_PLLC_RSTYPE_SRST_SHIFT       (0x00000003u)
#define CSL_PLLC_RSTYPE_SRST_RESETVAL    (0x00000000u)
/*----SRST Tokens----*/
#define CSL_PLLC_RSTYPE_SRST_NO          (0x00000000u)
#define CSL_PLLC_RSTYPE_SRST_YES         (0x00000001u)

#define CSL_PLLC_RSTYPE_MRST_MASK        (0x00000004u)
#define CSL_PLLC_RSTYPE_MRST_SHIFT       (0x00000002u)
#define CSL_PLLC_RSTYPE_MRST_RESETVAL    (0x00000000u)
/*----MRST Tokens----*/
#define CSL_PLLC_RSTYPE_MRST_NO          (0x00000000u)
#define CSL_PLLC_RSTYPE_MRST_YES         (0x00000001u)

#define CSL_PLLC_RSTYPE_XWRST_MASK       (0x00000002u)
#define CSL_PLLC_RSTYPE_XWRST_SHIFT      (0x00000001u)
#define CSL_PLLC_RSTYPE_XWRST_RESETVAL   (0x00000000u)
/*----XWRST Tokens----*/
#define CSL_PLLC_RSTYPE_XWRST_NO         (0x00000000u)
#define CSL_PLLC_RSTYPE_XWRST_YES        (0x00000001u)

#define CSL_PLLC_RSTYPE_POR_MASK         (0x00000001u)
#define CSL_PLLC_RSTYPE_POR_SHIFT        (0x00000000u)
#define CSL_PLLC_RSTYPE_POR_RESETVAL     (0x00000000u)
/*----POR Tokens----*/
#define CSL_PLLC_RSTYPE_POR_NO           (0x00000000u)
#define CSL_PLLC_RSTYPE_POR_YES          (0x00000001u)

#define CSL_PLLC_RSTYPE_RESETVAL         (0x00000000u)

#define CSL_PLLC_PLLCTL_PLLRST_MASK      (0x00000008u)
#define CSL_PLLC_PLLCTL_PLLRST_SHIFT     (0x00000003u)
#define CSL_PLLC_PLLCTL_PLLRST_RESETVAL  (0x00000000u)
/*----PLLRST Tokens----*/
#define CSL_PLLC_PLLCTL_PLLRST_NO        (0x00000000u)
#define CSL_PLLC_PLLCTL_PLLRST_YES       (0x00000001u)


#define CSL_PLLC_PLLCTL_PLLPWRDN_MASK    (0x00000002u)
#define CSL_PLLC_PLLCTL_PLLPWRDN_SHIFT   (0x00000001u)
#define CSL_PLLC_PLLCTL_PLLPWRDN_RESETVAL (0x00000000u)
/*----PLLPWRDN Tokens----*/
#define CSL_PLLC_PLLCTL_PLLPWRDN_NO      (0x00000000u)
#define CSL_PLLC_PLLCTL_PLLPWRDN_YES     (0x00000001u)

#define CSL_PLLC_PLLCTL_PLLEN_MASK       (0x00000001u)
#define CSL_PLLC_PLLCTL_PLLEN_SHIFT      (0x00000000u)
#define CSL_PLLC_PLLCTL_PLLEN_RESETVAL   (0x00000000u)
/*----PLLEN Tokens----*/
#define CSL_PLLC_PLLCTL_PLLEN_BYPASS     (0x00000000u)
#define CSL_PLLC_PLLCTL_PLLEN_PLL        (0x00000001u)

#define CSL_PLLC_PLLCTL_RESETVAL         (0x00000040u)

/* PLLM */


#define CSL_PLLC_PLLM_PLLM_MASK          (0x0000003Fu)
#define CSL_PLLC_PLLM_PLLM_SHIFT         (0x00000000u)
#define CSL_PLLC_PLLM_PLLM_RESETVAL      (0x00000000u)

#define CSL_PLLC_PLLM_RESETVAL           (0x00000000u)


/* PLLDIV1 */


#define CSL_PLLC_PLLDIV1_D1EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV1_D1EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV1_D1EN_RESETVAL   (0x00000000u)
/*----D1EN Tokens----*/
#define CSL_PLLC_PLLDIV1_D1EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV1_D1EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV1_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV1_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV1_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV1_RESETVAL        (0x00000000u)

/* PLLDIV2 */


#define CSL_PLLC_PLLDIV2_D2EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV2_D2EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV2_D2EN_RESETVAL   (0x00000000u)
/*----D2EN Tokens----*/
#define CSL_PLLC_PLLDIV2_D2EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV2_D2EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV2_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV2_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV2_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV2_RESETVAL        (0x00000000u)

/* PLLDIV3 */


#define CSL_PLLC_PLLDIV3_D3EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV3_D3EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV3_D3EN_RESETVAL   (0x00000000u)
/*----D3EN Tokens----*/
#define CSL_PLLC_PLLDIV3_D3EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV3_D3EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV3_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV3_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV3_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV3_RESETVAL        (0x00000000u)

/* PLLCMD */


#define CSL_PLLC_PLLCMD_OSCPWRDN_MASK    (0x00000002u)
#define CSL_PLLC_PLLCMD_OSCPWRDN_SHIFT   (0x00000001u)
#define CSL_PLLC_PLLCMD_OSCPWRDN_RESETVAL (0x00000000u)
/*----OSCPWRDN Tokens----*/
#define CSL_PLLC_PLLCMD_OSCPWRDN_CLRBIT  (0x00000000u)
#define CSL_PLLC_PLLCMD_OSCPWRDN_SET     (0x00000001u)

#define CSL_PLLC_PLLCMD_GOSET_MASK       (0x00000001u)
#define CSL_PLLC_PLLCMD_GOSET_SHIFT      (0x00000000u)
#define CSL_PLLC_PLLCMD_GOSET_RESETVAL   (0x00000000u)
/*----GOSET Tokens----*/
#define CSL_PLLC_PLLCMD_GOSET_CLRBIT     (0x00000000u)
#define CSL_PLLC_PLLCMD_GOSET_SET        (0x00000001u)

#define CSL_PLLC_PLLCMD_RESETVAL         (0x00000000u)

/* PLLSTAT */
#define CSL_PLLC_PLLSTAT_GOSTAT_MASK     (0x00000001u)
#define CSL_PLLC_PLLSTAT_GOSTAT_SHIFT    (0x00000000u)
#define CSL_PLLC_PLLSTAT_GOSTAT_RESETVAL (0x00000000u)
/*----GOSTAT Tokens----*/
#define CSL_PLLC_PLLSTAT_GOSTAT_NONE     (0x00000000u)
#define CSL_PLLC_PLLSTAT_GOSTAT_INPROG   (0x00000001u)

#define CSL_PLLC_PLLSTAT_RESETVAL        (0x00000000u)

/* ALNCTL */


#define CSL_PLLC_ALNCTL_ALN10_MASK       (0x00000200u)
#define CSL_PLLC_ALNCTL_ALN10_SHIFT      (0x00000009u)
#define CSL_PLLC_ALNCTL_ALN10_RESETVAL   (0x00000000u)
/*----ALN10 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN10_NO         (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN10_YES        (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN9_MASK        (0x00000100u)
#define CSL_PLLC_ALNCTL_ALN9_SHIFT       (0x00000008u)
#define CSL_PLLC_ALNCTL_ALN9_RESETVAL    (0x00000000u)
/*----ALN9 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN9_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN9_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN8_MASK        (0x00000080u)
#define CSL_PLLC_ALNCTL_ALN8_SHIFT       (0x00000007u)
#define CSL_PLLC_ALNCTL_ALN8_RESETVAL    (0x00000000u)
/*----ALN8 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN8_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN8_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN7_MASK        (0x00000040u)
#define CSL_PLLC_ALNCTL_ALN7_SHIFT       (0x00000006u)
#define CSL_PLLC_ALNCTL_ALN7_RESETVAL    (0x00000000u)
/*----ALN7 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN7_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN7_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN6_MASK        (0x00000020u)
#define CSL_PLLC_ALNCTL_ALN6_SHIFT       (0x00000005u)
#define CSL_PLLC_ALNCTL_ALN6_RESETVAL    (0x00000000u)
/*----ALN6 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN6_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN6_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN5_MASK        (0x00000010u)
#define CSL_PLLC_ALNCTL_ALN5_SHIFT       (0x00000004u)
#define CSL_PLLC_ALNCTL_ALN5_RESETVAL    (0x00000000u)
/*----ALN5 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN5_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN5_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN4_MASK        (0x00000008u)
#define CSL_PLLC_ALNCTL_ALN4_SHIFT       (0x00000003u)
#define CSL_PLLC_ALNCTL_ALN4_RESETVAL    (0x00000000u)
/*----ALN4 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN4_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN4_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN3_MASK        (0x00000004u)
#define CSL_PLLC_ALNCTL_ALN3_SHIFT       (0x00000002u)
#define CSL_PLLC_ALNCTL_ALN3_RESETVAL    (0x00000000u)
/*----ALN3 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN3_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN3_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN2_MASK        (0x00000002u)
#define CSL_PLLC_ALNCTL_ALN2_SHIFT       (0x00000001u)
#define CSL_PLLC_ALNCTL_ALN2_RESETVAL    (0x00000000u)
/*----ALN2 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN2_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN2_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_ALN1_MASK        (0x00000001u)
#define CSL_PLLC_ALNCTL_ALN1_SHIFT       (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN1_RESETVAL    (0x00000000u)
/*----ALN1 Tokens----*/
#define CSL_PLLC_ALNCTL_ALN1_NO          (0x00000000u)
#define CSL_PLLC_ALNCTL_ALN1_YES         (0x00000001u)

#define CSL_PLLC_ALNCTL_RESETVAL         (0x00000000u)

/* DCHANGE */


#define CSL_PLLC_DCHANGE_SYS10_MASK      (0x00000200u)
#define CSL_PLLC_DCHANGE_SYS10_SHIFT     (0x00000009u)
#define CSL_PLLC_DCHANGE_SYS10_RESETVAL  (0x00000000u)
/*----SYS10 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS10_NO        (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS10_YES       (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS9_MASK       (0x00000100u)
#define CSL_PLLC_DCHANGE_SYS9_SHIFT      (0x00000008u)
#define CSL_PLLC_DCHANGE_SYS9_RESETVAL   (0x00000000u)
/*----SYS9 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS9_NO         (0x00000000u)

#define CSL_PLLC_DCHANGE_SYS8_MASK       (0x00000080u)
#define CSL_PLLC_DCHANGE_SYS8_SHIFT      (0x00000007u)
#define CSL_PLLC_DCHANGE_SYS8_RESETVAL   (0x00000000u)
/*----SYS8 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS8_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS8_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS7_MASK       (0x00000040u)
#define CSL_PLLC_DCHANGE_SYS7_SHIFT      (0x00000006u)
#define CSL_PLLC_DCHANGE_SYS7_RESETVAL   (0x00000000u)
/*----SYS7 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS7_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS7_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS6_MASK       (0x00000020u)
#define CSL_PLLC_DCHANGE_SYS6_SHIFT      (0x00000005u)
#define CSL_PLLC_DCHANGE_SYS6_RESETVAL   (0x00000000u)
/*----SYS6 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS6_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS6_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS5_MASK       (0x00000010u)
#define CSL_PLLC_DCHANGE_SYS5_SHIFT      (0x00000004u)
#define CSL_PLLC_DCHANGE_SYS5_RESETVAL   (0x00000000u)
/*----SYS5 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS5_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS5_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS4_MASK       (0x00000008u)
#define CSL_PLLC_DCHANGE_SYS4_SHIFT      (0x00000003u)
#define CSL_PLLC_DCHANGE_SYS4_RESETVAL   (0x00000000u)
/*----SYS4 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS4_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS4_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS3_MASK       (0x00000004u)
#define CSL_PLLC_DCHANGE_SYS3_SHIFT      (0x00000002u)
#define CSL_PLLC_DCHANGE_SYS3_RESETVAL   (0x00000000u)
/*----SYS3 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS3_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS3_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS2_MASK       (0x00000002u)
#define CSL_PLLC_DCHANGE_SYS2_SHIFT      (0x00000001u)
#define CSL_PLLC_DCHANGE_SYS2_RESETVAL   (0x00000000u)
/*----SYS2 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS2_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS2_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_SYS1_MASK       (0x00000001u)
#define CSL_PLLC_DCHANGE_SYS1_SHIFT      (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS1_RESETVAL   (0x00000000u)
/*----SYS1 Tokens----*/
#define CSL_PLLC_DCHANGE_SYS1_NO         (0x00000000u)
#define CSL_PLLC_DCHANGE_SYS1_YES        (0x00000001u)

#define CSL_PLLC_DCHANGE_RESETVAL        (0x00000000u)

/* SYSTAT */


#define CSL_PLLC_SYSTAT_SYS10ON_MASK     (0x00000200u)
#define CSL_PLLC_SYSTAT_SYS10ON_SHIFT    (0x00000009u)
#define CSL_PLLC_SYSTAT_SYS10ON_RESETVAL (0x00000000u)
/*----SYS10ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS10ON_OFF      (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS10ON_ON       (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS9ON_MASK      (0x00000100u)
#define CSL_PLLC_SYSTAT_SYS9ON_SHIFT     (0x00000008u)
#define CSL_PLLC_SYSTAT_SYS9ON_RESETVAL  (0x00000000u)
/*----SYS9ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS9ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS9ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS8ON_MASK      (0x00000080u)
#define CSL_PLLC_SYSTAT_SYS8ON_SHIFT     (0x00000007u)
#define CSL_PLLC_SYSTAT_SYS8ON_RESETVAL  (0x00000000u)
/*----SYS8ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS8ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS8ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS7ON_MASK      (0x00000040u)
#define CSL_PLLC_SYSTAT_SYS7ON_SHIFT     (0x00000006u)
#define CSL_PLLC_SYSTAT_SYS7ON_RESETVAL  (0x00000000u)
/*----SYS7ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS7ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS7ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS6ON_MASK      (0x00000020u)
#define CSL_PLLC_SYSTAT_SYS6ON_SHIFT     (0x00000005u)
#define CSL_PLLC_SYSTAT_SYS6ON_RESETVAL  (0x00000000u)
/*----SYS6ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS6ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS6ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS5ON_MASK      (0x00000010u)
#define CSL_PLLC_SYSTAT_SYS5ON_SHIFT     (0x00000004u)
#define CSL_PLLC_SYSTAT_SYS5ON_RESETVAL  (0x00000000u)
/*----SYS5ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS5ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS5ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS4ON_MASK      (0x00000008u)
#define CSL_PLLC_SYSTAT_SYS4ON_SHIFT     (0x00000003u)
#define CSL_PLLC_SYSTAT_SYS4ON_RESETVAL  (0x00000000u)
/*----SYS4ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS4ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS4ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS3ON_MASK      (0x00000004u)
#define CSL_PLLC_SYSTAT_SYS3ON_SHIFT     (0x00000002u)
#define CSL_PLLC_SYSTAT_SYS3ON_RESETVAL  (0x00000000u)
/*----SYS3ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS3ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS3ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS2ON_MASK      (0x00000002u)
#define CSL_PLLC_SYSTAT_SYS2ON_SHIFT     (0x00000001u)
#define CSL_PLLC_SYSTAT_SYS2ON_RESETVAL  (0x00000000u)
/*----SYS2ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS2ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS2ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_SYS1ON_MASK      (0x00000001u)
#define CSL_PLLC_SYSTAT_SYS1ON_SHIFT     (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS1ON_RESETVAL  (0x00000000u)
/*----SYS1ON Tokens----*/
#define CSL_PLLC_SYSTAT_SYS1ON_OFF       (0x00000000u)
#define CSL_PLLC_SYSTAT_SYS1ON_ON        (0x00000001u)

#define CSL_PLLC_SYSTAT_RESETVAL         (0x00000000u)

/* CKCTL */
#define CSL_PLLC_CKCTL_ALNBYP_MASK      (0x00000001u)
#define CSL_PLLC_CKCTL_ALNBYP_SHIFT     (0x00000000u)
#define CSL_PLLC_CKCTL_ALNBYP_RESETVAL  (0x00000000u)
/*----CKCTL Tokens----*/
#define CSL_PLLC_CKCTL_ALNBYP_YES       (0x00000001u)
#define CSL_PLLC_CKCTL_ALNBYP_NO        (0x00000000u)


/* PLLDIV4 */


#define CSL_PLLC_PLLDIV4_D4EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV4_D4EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV4_D4EN_RESETVAL   (0x00000000u)
/*----D4EN Tokens----*/
#define CSL_PLLC_PLLDIV4_D4EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV4_D4EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV4_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV4_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV4_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV4_RESETVAL        (0x00000000u)

/* PLLDIV5 */


#define CSL_PLLC_PLLDIV5_D5EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV5_D5EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV5_D5EN_RESETVAL   (0x00000000u)
/*----D5EN Tokens----*/
#define CSL_PLLC_PLLDIV5_D5EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV5_D5EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV5_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV5_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV5_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV5_RESETVAL        (0x00000000u)

/* PLLDIV6 */


#define CSL_PLLC_PLLDIV6_D6EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV6_D6EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV6_D6EN_RESETVAL   (0x00000000u)
/*----D6EN Tokens----*/
#define CSL_PLLC_PLLDIV6_D6EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV6_D6EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV6_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV6_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV6_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV6_RESETVAL        (0x00000000u)

/* PLLDIV7 */


#define CSL_PLLC_PLLDIV7_D7EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV7_D7EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV7_D7EN_RESETVAL   (0x00000000u)
/*----D7EN Tokens----*/
#define CSL_PLLC_PLLDIV7_D7EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV7_D7EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV7_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV7_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV7_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV7_RESETVAL        (0x00000000u)

/* PLLDIV8 */


#define CSL_PLLC_PLLDIV8_D8EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV8_D8EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV8_D8EN_RESETVAL   (0x00000000u)
/*----D8EN Tokens----*/
#define CSL_PLLC_PLLDIV8_D8EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV8_D8EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV8_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV8_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV8_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV8_RESETVAL        (0x00000000u)

/* PLLDIV9 */


#define CSL_PLLC_PLLDIV9_D9EN_MASK       (0x00008000u)
#define CSL_PLLC_PLLDIV9_D9EN_SHIFT      (0x0000000Fu)
#define CSL_PLLC_PLLDIV9_D9EN_RESETVAL   (0x00000000u)
/*----D9EN Tokens----*/
#define CSL_PLLC_PLLDIV9_D9EN_DISABLE    (0x00000000u)
#define CSL_PLLC_PLLDIV9_D9EN_ENABLE     (0x00000001u)


#define CSL_PLLC_PLLDIV9_RATIO_MASK      (0x0000001Fu)
#define CSL_PLLC_PLLDIV9_RATIO_SHIFT     (0x00000000u)
#define CSL_PLLC_PLLDIV9_RATIO_RESETVAL  (0x00000000u)

#define CSL_PLLC_PLLDIV9_RESETVAL        (0x00000000u)

/* PLLDIV10 */


#define CSL_PLLC_PLLDIV10_D10EN_MASK     (0x00008000u)
#define CSL_PLLC_PLLDIV10_D10EN_SHIFT    (0x0000000Fu)
#define CSL_PLLC_PLLDIV10_D10EN_RESETVAL (0x00000000u)
/*----D10EN Tokens----*/
#define CSL_PLLC_PLLDIV10_D10EN_DISABLE  (0x00000000u)
#define CSL_PLLC_PLLDIV10_D10EN_ENABLE   (0x00000001u)


#define CSL_PLLC_PLLDIV10_RATIO_MASK     (0x0000001Fu)
#define CSL_PLLC_PLLDIV10_RATIO_SHIFT    (0x00000000u)
#define CSL_PLLC_PLLDIV10_RATIO_RESETVAL (0x00000000u)

#define CSL_PLLC_PLLDIV10_RESETVAL       (0x00000000u)

#endif



