/* =============================================================================
 *  Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 *
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
/** ============================================================================
 *   @file  cslr_psc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for PSC
 *  ============================================================================
 */

#ifndef _CSLR_PSC_H_
#define _CSLR_PSC_H_

#include <cslr.h>

#include "tistdtypes.h"


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint8 RSVD0[20];
    volatile Uint32 INTEVAL;
    volatile Uint8 RSVD1[36];
    volatile Uint32 MERRPR;
    volatile Uint8 RSVD2[12];
    volatile Uint32 MERRCR;
    volatile Uint8 RSVD3[204];
    volatile Uint32 PTCMD;
    volatile Uint8 RSVD4[4];
    volatile Uint32 PTSTAT;
    volatile Uint8 RSVD5[1748];
    volatile Uint32 MDSTAT0;
    volatile Uint32 MDSTAT1;
    volatile Uint32 MDSTAT2;
    volatile Uint32 MDSTAT3;
    volatile Uint32 MDSTAT4;
    volatile Uint32 MDSTAT5;
    volatile Uint32 MDSTAT6;
    volatile Uint32 MDSTAT7;
    volatile Uint32 MDSTAT8;
    volatile Uint32 MDSTAT9;
    volatile Uint32 MDSTAT10;
    volatile Uint32 MDSTAT11;
    volatile Uint32 MDSTAT12;
    volatile Uint32 MDSTAT13;
    volatile Uint8 RSVD6[456];
    volatile Uint32 MDCTL0;
    volatile Uint32 MDCTL1;
    volatile Uint32 MDCTL2;
    volatile Uint32 MDCTL3;
    volatile Uint32 MDCTL4;
    volatile Uint32 MDCTL5;
    volatile Uint32 MDCTL6;
    volatile Uint32 MDCTL7;
    volatile Uint32 MDCTL8;
    volatile Uint32 MDCTL9;
    volatile Uint32 MDCTL10;
    volatile Uint32 MDCTL11;
    volatile Uint32 MDCTL12;
    volatile Uint32 MDCTL13;
} CSL_PscRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_PscRegs             *CSL_PscRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */

#define CSL_PSC_PID_SCHEME_MASK          (0xC0000000u)
#define CSL_PSC_PID_SCHEME_SHIFT         (0x0000001Eu)
#define CSL_PSC_PID_SCHEME_RESETVAL      (0x00000001u)

#define CSL_PSC_PID_FUNC_MASK (0x3FFF0000u)
#define CSL_PSC_PID_FUNC_SHIFT           (0x00000010u)
#define CSL_PSC_PID_FUNC_RESETVAL (0x00002808u)

#define CSL_PSC_PID_RTL_MASK             (0x0000F800u)
#define CSL_PSC_PID_RTL_SHIFT            (0x0000000Bu)
#define CSL_PSC_PID_RTL_RESETVAL         (0x00000000u)
/*----RTL Tokens----*/
#define CSL_PSC_PID_RTL_PSC1_0 (0x00000000u)
#define CSL_PSC_PID_RTL_PSC2_0 (0x00000001u)

#define CSL_PSC_PID_MAJOR_REVISION_MASK  (0x00000700u)
#define CSL_PSC_PID_MAJOR_REVISION_SHIFT (0x00000008u)
#define CSL_PSC_PID_MAJOR_REVISION_RESETVAL (0x00000001u)

#define CSL_PSC_PID_CUSTOM_MASK          (0x000000C0u)
#define CSL_PSC_PID_CUSTOM_SHIFT         (0x00000006u)
#define CSL_PSC_PID_CUSTOM_RESETVAL      (0x00000000u)

#define CSL_PSC_PID_MINOR_REVISION_MASK  (0x0000003Fu)
#define CSL_PSC_PID_MINOR_REVISION_SHIFT (0x00000000u)
#define CSL_PSC_PID_MINOR_REVISION_RESETVAL (0x00000000u)

#define CSL_PSC_PID_RESETVAL (0x68080100u)

/* INTEVAL */


#define CSL_PSC_INTEVAL_ERRSET_MASK      (0x00020000u)
#define CSL_PSC_INTEVAL_ERRSET_SHIFT     (0x00000011u)
#define CSL_PSC_INTEVAL_ERRSET_RESETVAL  (0x00000000u)
/*----ERRSET Tokens----*/
#define CSL_PSC_INTEVAL_ERRSET_PULSED (0x00000001u)

#define CSL_PSC_INTEVAL_ALLSET_MASK      (0x00010000u)
#define CSL_PSC_INTEVAL_ALLSET_SHIFT     (0x00000010u)
#define CSL_PSC_INTEVAL_ALLSET_RESETVAL  (0x00000000u)
/*----ALLSET Tokens----*/
#define CSL_PSC_INTEVAL_ALLSET_PULSED (0x00000001u)


#define CSL_PSC_INTEVAL_ERREV_MASK       (0x00000002u)
#define CSL_PSC_INTEVAL_ERREV_SHIFT      (0x00000001u)
#define CSL_PSC_INTEVAL_ERREV_RESETVAL   (0x00000000u)
/*----ERREV Tokens----*/
#define CSL_PSC_INTEVAL_ERREV_RE_EVALUATE (0x00000001u)

#define CSL_PSC_INTEVAL_ALLEV_MASK       (0x00000001u)
#define CSL_PSC_INTEVAL_ALLEV_SHIFT      (0x00000000u)
#define CSL_PSC_INTEVAL_ALLEV_RESETVAL   (0x00000000u)
/*----ALLEV Tokens----*/
#define CSL_PSC_INTEVAL_ALLEV_RE_EVALUATE (0x00000001u)

#define CSL_PSC_INTEVAL_RESETVAL         (0x00000000u)

/* MERRPR */


#define CSL_PSC_MERRPR_M13_MASK (0x00002000u)
#define CSL_PSC_MERRPR_M13_SHIFT (0x0000000Du)
#define CSL_PSC_MERRPR_M13_RESETVAL (0x00000000u)
/*----M13 Tokens----*/
#define CSL_PSC_MERRPR_M13_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M13_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M12_MASK (0x00001000u)
#define CSL_PSC_MERRPR_M12_SHIFT (0x0000000Cu)
#define CSL_PSC_MERRPR_M12_RESETVAL (0x00000000u)
/*----M12 Tokens----*/
#define CSL_PSC_MERRPR_M12_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M12_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M11_MASK (0x00000800u)
#define CSL_PSC_MERRPR_M11_SHIFT (0x0000000Bu)
#define CSL_PSC_MERRPR_M11_RESETVAL (0x00000000u)
/*----M11 Tokens----*/
#define CSL_PSC_MERRPR_M11_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M11_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M10_MASK (0x00000400u)
#define CSL_PSC_MERRPR_M10_SHIFT (0x0000000Au)
#define CSL_PSC_MERRPR_M10_RESETVAL (0x00000000u)
/*----M10 Tokens----*/
#define CSL_PSC_MERRPR_M10_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M10_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M9_MASK (0x00000200u)
#define CSL_PSC_MERRPR_M9_SHIFT (0x00000009u)
#define CSL_PSC_MERRPR_M9_RESETVAL (0x00000000u)
/*----M9 Tokens----*/
#define CSL_PSC_MERRPR_M9_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M9_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M8_MASK (0x00000100u)
#define CSL_PSC_MERRPR_M8_SHIFT (0x00000008u)
#define CSL_PSC_MERRPR_M8_RESETVAL (0x00000000u)
/*----M8 Tokens----*/
#define CSL_PSC_MERRPR_M8_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M8_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M7_MASK (0x00000080u)
#define CSL_PSC_MERRPR_M7_SHIFT (0x00000007u)
#define CSL_PSC_MERRPR_M7_RESETVAL (0x00000000u)
/*----M7 Tokens----*/
#define CSL_PSC_MERRPR_M7_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M7_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M6_MASK (0x00000040u)
#define CSL_PSC_MERRPR_M6_SHIFT (0x00000006u)
#define CSL_PSC_MERRPR_M6_RESETVAL (0x00000000u)
/*----M6 Tokens----*/
#define CSL_PSC_MERRPR_M6_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M6_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M5_MASK (0x00000020u)
#define CSL_PSC_MERRPR_M5_SHIFT (0x00000005u)
#define CSL_PSC_MERRPR_M5_RESETVAL (0x00000000u)
/*----M5 Tokens----*/
#define CSL_PSC_MERRPR_M5_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M5_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M4_MASK (0x00000010u)
#define CSL_PSC_MERRPR_M4_SHIFT (0x00000004u)
#define CSL_PSC_MERRPR_M4_RESETVAL (0x00000000u)
/*----M4 Tokens----*/
#define CSL_PSC_MERRPR_M4_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M4_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M3_MASK (0x00000008u)
#define CSL_PSC_MERRPR_M3_SHIFT (0x00000003u)
#define CSL_PSC_MERRPR_M3_RESETVAL (0x00000000u)
/*----M3 Tokens----*/
#define CSL_PSC_MERRPR_M3_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M3_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M2_MASK (0x00000004u)
#define CSL_PSC_MERRPR_M2_SHIFT (0x00000002u)
#define CSL_PSC_MERRPR_M2_RESETVAL (0x00000000u)
/*----M2 Tokens----*/
#define CSL_PSC_MERRPR_M2_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M2_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M1_MASK (0x00000002u)
#define CSL_PSC_MERRPR_M1_SHIFT (0x00000001u)
#define CSL_PSC_MERRPR_M1_RESETVAL (0x00000000u)
/*----M1 Tokens----*/
#define CSL_PSC_MERRPR_M1_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M1_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_M0_MASK (0x00000001u)
#define CSL_PSC_MERRPR_M0_SHIFT (0x00000000u)
#define CSL_PSC_MERRPR_M0_RESETVAL (0x00000000u)
/*----M0 Tokens----*/
#define CSL_PSC_MERRPR_M0_NO_ERR (0x00000000u)
#define CSL_PSC_MERRPR_M0_ERROR (0x00000001u)

#define CSL_PSC_MERRPR_RESETVAL (0x00000000u)

/* MERRCR */


#define CSL_PSC_MERRCR_M13_MASK (0x00002000u)
#define CSL_PSC_MERRCR_M13_SHIFT (0x0000000Du)
#define CSL_PSC_MERRCR_M13_RESETVAL (0x00000000u)
/*----M13 Tokens----*/
#define CSL_PSC_MERRCR_M13_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M13_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M12_MASK (0x00001000u)
#define CSL_PSC_MERRCR_M12_SHIFT (0x0000000Cu)
#define CSL_PSC_MERRCR_M12_RESETVAL (0x00000000u)
/*----M12 Tokens----*/
#define CSL_PSC_MERRCR_M12_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M12_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M11_MASK (0x00000800u)
#define CSL_PSC_MERRCR_M11_SHIFT (0x0000000Bu)
#define CSL_PSC_MERRCR_M11_RESETVAL (0x00000000u)
/*----M11 Tokens----*/
#define CSL_PSC_MERRCR_M11_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M11_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M10_MASK (0x00000400u)
#define CSL_PSC_MERRCR_M10_SHIFT (0x0000000Au)
#define CSL_PSC_MERRCR_M10_RESETVAL (0x00000000u)
/*----M10 Tokens----*/
#define CSL_PSC_MERRCR_M10_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M10_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M9_MASK (0x00000200u)
#define CSL_PSC_MERRCR_M9_SHIFT (0x00000009u)
#define CSL_PSC_MERRCR_M9_RESETVAL (0x00000000u)
/*----M9 Tokens----*/
#define CSL_PSC_MERRCR_M9_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M9_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M8_MASK (0x00000100u)
#define CSL_PSC_MERRCR_M8_SHIFT (0x00000008u)
#define CSL_PSC_MERRCR_M8_RESETVAL (0x00000000u)
/*----M8 Tokens----*/
#define CSL_PSC_MERRCR_M8_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M8_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M7_MASK (0x00000080u)
#define CSL_PSC_MERRCR_M7_SHIFT (0x00000007u)
#define CSL_PSC_MERRCR_M7_RESETVAL (0x00000000u)
/*----M7 Tokens----*/
#define CSL_PSC_MERRCR_M7_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M7_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M6_MASK (0x00000040u)
#define CSL_PSC_MERRCR_M6_SHIFT (0x00000006u)
#define CSL_PSC_MERRCR_M6_RESETVAL (0x00000000u)
/*----M6 Tokens----*/
#define CSL_PSC_MERRCR_M6_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M6_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M5_MASK (0x00000020u)
#define CSL_PSC_MERRCR_M5_SHIFT (0x00000005u)
#define CSL_PSC_MERRCR_M5_RESETVAL (0x00000000u)
/*----M5 Tokens----*/
#define CSL_PSC_MERRCR_M5_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M5_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M4_MASK (0x00000010u)
#define CSL_PSC_MERRCR_M4_SHIFT (0x00000004u)
#define CSL_PSC_MERRCR_M4_RESETVAL (0x00000000u)
/*----M4 Tokens----*/
#define CSL_PSC_MERRCR_M4_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M4_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M3_MASK (0x00000008u)
#define CSL_PSC_MERRCR_M3_SHIFT (0x00000003u)
#define CSL_PSC_MERRCR_M3_RESETVAL (0x00000000u)
/*----M3 Tokens----*/
#define CSL_PSC_MERRCR_M3_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M3_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M2_MASK (0x00000004u)
#define CSL_PSC_MERRCR_M2_SHIFT (0x00000002u)
#define CSL_PSC_MERRCR_M2_RESETVAL (0x00000000u)
/*----M2 Tokens----*/
#define CSL_PSC_MERRCR_M2_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M2_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M1_MASK (0x00000002u)
#define CSL_PSC_MERRCR_M1_SHIFT (0x00000001u)
#define CSL_PSC_MERRCR_M1_RESETVAL (0x00000000u)
/*----M1 Tokens----*/
#define CSL_PSC_MERRCR_M1_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M1_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_M0_MASK (0x00000001u)
#define CSL_PSC_MERRCR_M0_SHIFT (0x00000000u)
#define CSL_PSC_MERRCR_M0_RESETVAL (0x00000000u)
/*----M0 Tokens----*/
#define CSL_PSC_MERRCR_M0_NO_ERR (0x00000000u)
#define CSL_PSC_MERRCR_M0_ERROR (0x00000001u)

#define CSL_PSC_MERRCR_RESETVAL          (0x00000000u)

/* PTCMD */


#define CSL_PSC_PTCMD_GO8_MASK (0x00000100u)
#define CSL_PSC_PTCMD_GO8_SHIFT (0x00000008u)
#define CSL_PSC_PTCMD_GO8_RESETVAL (0x00000000u)
/*----GO8 Tokens----*/
#define CSL_PSC_PTCMD_GO8_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO_MASK (0x000001FFu)
#define CSL_PSC_PTCMD_GO_SHIFT (0x00000000u)
#define CSL_PSC_PTCMD_GO_RESETVAL (0x00000000u)
/*----GO Tokens----*/
#define CSL_PSC_PTCMD_GO_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO7_MASK (0x00000080u)
#define CSL_PSC_PTCMD_GO7_SHIFT (0x00000007u)
#define CSL_PSC_PTCMD_GO7_RESETVAL (0x00000000u)
/*----GO7 Tokens----*/
#define CSL_PSC_PTCMD_GO7_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO6_MASK (0x00000040u)
#define CSL_PSC_PTCMD_GO6_SHIFT (0x00000006u)
#define CSL_PSC_PTCMD_GO6_RESETVAL (0x00000000u)
/*----GO6 Tokens----*/
#define CSL_PSC_PTCMD_GO6_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO5_MASK (0x00000020u)
#define CSL_PSC_PTCMD_GO5_SHIFT (0x00000005u)
#define CSL_PSC_PTCMD_GO5_RESETVAL (0x00000000u)
/*----GO5 Tokens----*/
#define CSL_PSC_PTCMD_GO5_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO4_MASK (0x00000010u)
#define CSL_PSC_PTCMD_GO4_SHIFT (0x00000004u)
#define CSL_PSC_PTCMD_GO4_RESETVAL (0x00000000u)
/*----GO4 Tokens----*/
#define CSL_PSC_PTCMD_GO4_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO3_MASK (0x00000008u)
#define CSL_PSC_PTCMD_GO3_SHIFT (0x00000003u)
#define CSL_PSC_PTCMD_GO3_RESETVAL (0x00000000u)
/*----GO3 Tokens----*/
#define CSL_PSC_PTCMD_GO3_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO2_MASK (0x00000004u)
#define CSL_PSC_PTCMD_GO2_SHIFT (0x00000002u)
#define CSL_PSC_PTCMD_GO2_RESETVAL (0x00000000u)
/*----GO2 Tokens----*/
#define CSL_PSC_PTCMD_GO2_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO1_MASK (0x00000002u)
#define CSL_PSC_PTCMD_GO1_SHIFT (0x00000001u)
#define CSL_PSC_PTCMD_GO1_RESETVAL (0x00000000u)
/*----GO1 Tokens----*/
#define CSL_PSC_PTCMD_GO1_SET (0x00000001u)

#define CSL_PSC_PTCMD_GO0_MASK (0x00000001u)
#define CSL_PSC_PTCMD_GO0_SHIFT (0x00000000u)
#define CSL_PSC_PTCMD_GO0_RESETVAL (0x00000000u)
/*----GO0 Tokens----*/
#define CSL_PSC_PTCMD_GO0_SET (0x00000001u)

#define CSL_PSC_PTCMD_RESETVAL           (0x00000000u)

/* PTSTAT */


#define CSL_PSC_PTSTAT_GOSTAT8_MASK (0x00000100u)
#define CSL_PSC_PTSTAT_GOSTAT8_SHIFT (0x00000008u)
#define CSL_PSC_PTSTAT_GOSTAT8_RESETVAL (0x00000000u)
/*----GOSTAT8 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT8_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT8_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT7_MASK (0x00000080u)
#define CSL_PSC_PTSTAT_GOSTAT7_SHIFT (0x00000007u)
#define CSL_PSC_PTSTAT_GOSTAT7_RESETVAL (0x00000000u)
/*----GOSTAT7 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT7_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT7_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT6_MASK (0x00000040u)
#define CSL_PSC_PTSTAT_GOSTAT6_SHIFT (0x00000006u)
#define CSL_PSC_PTSTAT_GOSTAT6_RESETVAL (0x00000000u)
/*----GOSTAT6 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT6_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT6_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT5_MASK (0x00000020u)
#define CSL_PSC_PTSTAT_GOSTAT5_SHIFT (0x00000005u)
#define CSL_PSC_PTSTAT_GOSTAT5_RESETVAL (0x00000000u)
/*----GOSTAT5 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT5_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT5_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT4_MASK (0x00000010u)
#define CSL_PSC_PTSTAT_GOSTAT4_SHIFT (0x00000004u)
#define CSL_PSC_PTSTAT_GOSTAT4_RESETVAL (0x00000000u)
/*----GOSTAT4 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT4_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT4_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT3_MASK (0x00000008u)
#define CSL_PSC_PTSTAT_GOSTAT3_SHIFT (0x00000003u)
#define CSL_PSC_PTSTAT_GOSTAT3_RESETVAL (0x00000000u)
/*----GOSTAT3 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT3_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT3_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT2_MASK      (0x00000004u)
#define CSL_PSC_PTSTAT_GOSTAT2_SHIFT     (0x00000002u)
#define CSL_PSC_PTSTAT_GOSTAT2_RESETVAL  (0x00000000u)
/*----GOSTAT2 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT2_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT2_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT1_MASK      (0x00000002u)
#define CSL_PSC_PTSTAT_GOSTAT1_SHIFT     (0x00000001u)
#define CSL_PSC_PTSTAT_GOSTAT1_RESETVAL  (0x00000000u)
/*----GOSTAT1 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT1_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT1_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_GOSTAT0_MASK      (0x00000001u)
#define CSL_PSC_PTSTAT_GOSTAT0_SHIFT     (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT0_RESETVAL  (0x00000000u)
/*----GOSTAT0 Tokens----*/
#define CSL_PSC_PTSTAT_GOSTAT0_NO_PROGRESS (0x00000000u)
#define CSL_PSC_PTSTAT_GOSTAT0_IN_PROGRESS (0x00000001u)

#define CSL_PSC_PTSTAT_RESETVAL          (0x00000000u)

/* MDSTAT0 */


#define CSL_PSC_MDSTAT0_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT0_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT0_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT0_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT0_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT0_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT0_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT0_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT0_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT0_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT0_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT0_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT0_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT0_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT0_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT0_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT0_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT0_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT0_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT0_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT0_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT0_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT0_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT0_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT0_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT0_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT0_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT0_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT0_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT0_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT0_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT0_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT0_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT0_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT0_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT0_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT0_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT0_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT0_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT0_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT0_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT0_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT0_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT0_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT0_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT0_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT0_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT0_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT0_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT0_RESETVAL         (0x00000000u)

/* MDSTAT1 */


#define CSL_PSC_MDSTAT1_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT1_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT1_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT1_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT1_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT1_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT1_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT1_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT1_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT1_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT1_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT1_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT1_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT1_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT1_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT1_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT1_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT1_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT1_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT1_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT1_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT1_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT1_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT1_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT1_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT1_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT1_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT1_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT1_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT1_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT1_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT1_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT1_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT1_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT1_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT1_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT1_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT1_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT1_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT1_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT1_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT1_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT1_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT1_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT1_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT1_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT1_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT1_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT1_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT1_RESETVAL         (0x00000000u)

/* MDSTAT2 */


#define CSL_PSC_MDSTAT2_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT2_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT2_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT2_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT2_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT2_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT2_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT2_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT2_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT2_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT2_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT2_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT2_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT2_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT2_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT2_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT2_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT2_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT2_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT2_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT2_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT2_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT2_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT2_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT2_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT2_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT2_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT2_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT2_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT2_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT2_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT2_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT2_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT2_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT2_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT2_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT2_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT2_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT2_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT2_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT2_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT2_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT2_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT2_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT2_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT2_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT2_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT2_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT2_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT2_RESETVAL         (0x00000000u)

/* MDSTAT3 */


#define CSL_PSC_MDSTAT3_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT3_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT3_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT3_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT3_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT3_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT3_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT3_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT3_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT3_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT3_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT3_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT3_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT3_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT3_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT3_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT3_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT3_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT3_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT3_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT3_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT3_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT3_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT3_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT3_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT3_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT3_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT3_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT3_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT3_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT3_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT3_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT3_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT3_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT3_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT3_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT3_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT3_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT3_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT3_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT3_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT3_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT3_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT3_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT3_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT3_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT3_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT3_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT3_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT3_RESETVAL         (0x00000000u)

/* MDSTAT4 */


#define CSL_PSC_MDSTAT4_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT4_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT4_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT4_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT4_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT4_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT4_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT4_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT4_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT4_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT4_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT4_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT4_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT4_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT4_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT4_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT4_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT4_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT4_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT4_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT4_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT4_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT4_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT4_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT4_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT4_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT4_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT4_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT4_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT4_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT4_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT4_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT4_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT4_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT4_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT4_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT4_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT4_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT4_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT4_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT4_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT4_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT4_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT4_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT4_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT4_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT4_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT4_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT4_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT4_RESETVAL         (0x00000000u)

/* MDSTAT5 */


#define CSL_PSC_MDSTAT5_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT5_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT5_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT5_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT5_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT5_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT5_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT5_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT5_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT5_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT5_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT5_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT5_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT5_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT5_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT5_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT5_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT5_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT5_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT5_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT5_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT5_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT5_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT5_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT5_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT5_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT5_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT5_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT5_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT5_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT5_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT5_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT5_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT5_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT5_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT5_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT5_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT5_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT5_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT5_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT5_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT5_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT5_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT5_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT5_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT5_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT5_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT5_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT5_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT5_RESETVAL         (0x00000000u)

/* MDSTAT6 */


#define CSL_PSC_MDSTAT6_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT6_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT6_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT6_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT6_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT6_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT6_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT6_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT6_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT6_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT6_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT6_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT6_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT6_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT6_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT6_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT6_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT6_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT6_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT6_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT6_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT6_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT6_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT6_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT6_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT6_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT6_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT6_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT6_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT6_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT6_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT6_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT6_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT6_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT6_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT6_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT6_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT6_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT6_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT6_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT6_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT6_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT6_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT6_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT6_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT6_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT6_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT6_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT6_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT6_RESETVAL         (0x00000000u)

/* MDSTAT7 */


#define CSL_PSC_MDSTAT7_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT7_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT7_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT7_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT7_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT7_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT7_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT7_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT7_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT7_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT7_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT7_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT7_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT7_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT7_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT7_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT7_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT7_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT7_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT7_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT7_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT7_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT7_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT7_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT7_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT7_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT7_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT7_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT7_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT7_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT7_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT7_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT7_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT7_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT7_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT7_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT7_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT7_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT7_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT7_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT7_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT7_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT7_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT7_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT7_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT7_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT7_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT7_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT7_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT7_RESETVAL         (0x00000000u)

/* MDSTAT8 */


#define CSL_PSC_MDSTAT8_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT8_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT8_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT8_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT8_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT8_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT8_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT8_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT8_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT8_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT8_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT8_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT8_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT8_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT8_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT8_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT8_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT8_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT8_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT8_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT8_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT8_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT8_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT8_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT8_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT8_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT8_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT8_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT8_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT8_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT8_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT8_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT8_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT8_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT8_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT8_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT8_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT8_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT8_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT8_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT8_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT8_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT8_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT8_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT8_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT8_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT8_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT8_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT8_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT8_RESETVAL         (0x00000000u)

/* MDSTAT9 */


#define CSL_PSC_MDSTAT9_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT9_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT9_EMUIHB_RESETVAL  (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT9_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT9_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT9_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT9_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT9_EMURST_RESETVAL  (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT9_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT9_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT9_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT9_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT9_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT9_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT9_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT9_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT9_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT9_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT9_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT9_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT9_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT9_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT9_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT9_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT9_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT9_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT9_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT9_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT9_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDSTAT9_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDSTAT9_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT9_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT9_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT9_STATE_MASK       (0x0000003Fu)
#define CSL_PSC_MDSTAT9_STATE_SHIFT      (0x00000000u)
#define CSL_PSC_MDSTAT9_STATE_RESETVAL   (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT9_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT9_STATE_SYNCRST    (0x00000001u)
#define CSL_PSC_MDSTAT9_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT9_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT9_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT9_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT9_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT9_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT9_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT9_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT9_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT9_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT9_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT9_RESETVAL         (0x00000000u)

/* MDSTAT10 */


#define CSL_PSC_MDSTAT10_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT10_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT10_EMUIHB_RESETVAL (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT10_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT10_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT10_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT10_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT10_EMURST_RESETVAL (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT10_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT10_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT10_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT10_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT10_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT10_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT10_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT10_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT10_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT10_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT10_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT10_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT10_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT10_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT10_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT10_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT10_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT10_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT10_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT10_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT10_LRSTZ_MASK      (0x00000100u)
#define CSL_PSC_MDSTAT10_LRSTZ_SHIFT     (0x00000008u)
#define CSL_PSC_MDSTAT10_LRSTZ_RESETVAL  (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT10_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT10_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT10_STATE_MASK      (0x0000003Fu)
#define CSL_PSC_MDSTAT10_STATE_SHIFT     (0x00000000u)
#define CSL_PSC_MDSTAT10_STATE_RESETVAL  (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT10_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT10_STATE_SYNCRST   (0x00000001u)
#define CSL_PSC_MDSTAT10_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT10_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT10_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT10_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT10_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT10_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT10_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT10_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT10_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT10_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT10_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT10_RESETVAL        (0x00000000u)

/* MDSTAT11 */


#define CSL_PSC_MDSTAT11_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT11_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT11_EMUIHB_RESETVAL (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT11_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT11_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT11_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT11_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT11_EMURST_RESETVAL (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT11_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT11_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT11_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT11_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT11_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT11_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT11_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT11_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT11_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT11_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT11_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT11_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT11_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT11_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT11_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT11_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT11_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT11_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT11_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT11_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT11_LRSTZ_MASK      (0x00000100u)
#define CSL_PSC_MDSTAT11_LRSTZ_SHIFT     (0x00000008u)
#define CSL_PSC_MDSTAT11_LRSTZ_RESETVAL  (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT11_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT11_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT11_STATE_MASK      (0x0000003Fu)
#define CSL_PSC_MDSTAT11_STATE_SHIFT     (0x00000000u)
#define CSL_PSC_MDSTAT11_STATE_RESETVAL  (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT11_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT11_STATE_SYNCRST   (0x00000001u)
#define CSL_PSC_MDSTAT11_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT11_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT11_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT11_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT11_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT11_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT11_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT11_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT11_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT11_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT11_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT11_RESETVAL        (0x00000000u)

/* MDSTAT12 */


#define CSL_PSC_MDSTAT12_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT12_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT12_EMUIHB_RESETVAL (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT12_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT12_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT12_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT12_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT12_EMURST_RESETVAL (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT12_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT12_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT12_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT12_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT12_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT12_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT12_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT12_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT12_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT12_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT12_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT12_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT12_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT12_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT12_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT12_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT12_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT12_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT12_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT12_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT12_LRSTZ_MASK      (0x00000100u)
#define CSL_PSC_MDSTAT12_LRSTZ_SHIFT     (0x00000008u)
#define CSL_PSC_MDSTAT12_LRSTZ_RESETVAL  (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT12_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT12_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT12_STATE_MASK      (0x0000003Fu)
#define CSL_PSC_MDSTAT12_STATE_SHIFT     (0x00000000u)
#define CSL_PSC_MDSTAT12_STATE_RESETVAL  (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT12_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT12_STATE_SYNCRST   (0x00000001u)
#define CSL_PSC_MDSTAT12_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT12_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT12_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT12_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT12_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT12_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT12_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT12_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT12_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT12_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT12_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT12_RESETVAL        (0x00000000u)

/* MDSTAT13 */


#define CSL_PSC_MDSTAT13_EMUIHB_MASK (0x00020000u)
#define CSL_PSC_MDSTAT13_EMUIHB_SHIFT (0x00000011u)
#define CSL_PSC_MDSTAT13_EMUIHB_RESETVAL (0x00000000u)
/*----EMUIHB Tokens----*/
#define CSL_PSC_MDSTAT13_EMUIHB_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT13_EMUIHB_ENABLE (0x00000001u)

#define CSL_PSC_MDSTAT13_EMURST_MASK (0x00010000u)
#define CSL_PSC_MDSTAT13_EMURST_SHIFT (0x00000010u)
#define CSL_PSC_MDSTAT13_EMURST_RESETVAL (0x00000000u)
/*----EMURST Tokens----*/
#define CSL_PSC_MDSTAT13_EMURST_DISABLE (0x00000000u)
#define CSL_PSC_MDSTAT13_EMURST_ENABLE (0x00000001u)


#define CSL_PSC_MDSTAT13_MCKOUT_MASK (0x00001000u)
#define CSL_PSC_MDSTAT13_MCKOUT_SHIFT (0x0000000Cu)
#define CSL_PSC_MDSTAT13_MCKOUT_RESETVAL (0x00000000u)
/*----MCKOUT Tokens----*/
#define CSL_PSC_MDSTAT13_MCKOUT_OFF (0x00000000u)
#define CSL_PSC_MDSTAT13_MCKOUT_ON (0x00000001u)

#define CSL_PSC_MDSTAT13_MRSTDONE_MASK (0x00000800u)
#define CSL_PSC_MDSTAT13_MRSTDONE_SHIFT (0x0000000Bu)
#define CSL_PSC_MDSTAT13_MRSTDONE_RESETVAL (0x00000000u)

#define CSL_PSC_MDSTAT13_MRSTZ_MASK (0x00000400u)
#define CSL_PSC_MDSTAT13_MRSTZ_SHIFT (0x0000000Au)
#define CSL_PSC_MDSTAT13_MRSTZ_RESETVAL (0x00000000u)
/*----MRSTZ Tokens----*/
#define CSL_PSC_MDSTAT13_MRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT13_MRSTZ_DEASSERT (0x00000001u)

#define CSL_PSC_MDSTAT13_LRSTDONE_MASK (0x00000200u)
#define CSL_PSC_MDSTAT13_LRSTDONE_SHIFT (0x00000009u)
#define CSL_PSC_MDSTAT13_LRSTDONE_RESETVAL (0x00000000u)
/*----LRSTDONE Tokens----*/
#define CSL_PSC_MDSTAT13_LRSTDONE_NOT_DONE (0x00000000u)
#define CSL_PSC_MDSTAT13_LRSTDONE_DONE (0x00000001u)

#define CSL_PSC_MDSTAT13_LRSTZ_MASK      (0x00000100u)
#define CSL_PSC_MDSTAT13_LRSTZ_SHIFT     (0x00000008u)
#define CSL_PSC_MDSTAT13_LRSTZ_RESETVAL  (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDSTAT13_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDSTAT13_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDSTAT13_STATE_MASK      (0x0000003Fu)
#define CSL_PSC_MDSTAT13_STATE_SHIFT     (0x00000000u)
#define CSL_PSC_MDSTAT13_STATE_RESETVAL  (0x00000000u)
/*----STATE Tokens----*/
#define CSL_PSC_MDSTAT13_STATE_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDSTAT13_STATE_SYNCRST   (0x00000001u)
#define CSL_PSC_MDSTAT13_STATE_DISABLE (0x00000002u)
#define CSL_PSC_MDSTAT13_STATE_ENABLE (0x00000003u)
#define CSL_PSC_MDSTAT13_STATE_DISABLEIN_PROG (0x00000020u)
#define CSL_PSC_MDSTAT13_STATE_DISABLEIN_PROG2 (0x00000021u)
#define CSL_PSC_MDSTAT13_STATE_DISABLEIN_PROG3 (0x00000022u)
#define CSL_PSC_MDSTAT13_STATE_CLKOFF (0x00000023u)
#define CSL_PSC_MDSTAT13_STATE_ENABLEIN_PROG (0x00000024u)
#define CSL_PSC_MDSTAT13_STATE_DISABLECLKON (0x00000025u)
#define CSL_PSC_MDSTAT13_STATE_CLKON (0x00000026u)
#define CSL_PSC_MDSTAT13_STATE_CLKONSWRST (0x00000027u)
#define CSL_PSC_MDSTAT13_STATE_CLKOFFSYNCRST (0x00000028u)

#define CSL_PSC_MDSTAT13_RESETVAL        (0x00000000u)

/* MDCTL0 */


#define CSL_PSC_MDCTL0_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL0_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL0_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL0_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL0_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL0_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL0_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL0_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL0_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL0_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL0_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL0_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL0_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL0_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL0_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL0_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL0_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL0_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL0_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL0_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL0_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL0_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL0_RESETVAL (0x00000000u)

/* MDCTL1 */


#define CSL_PSC_MDCTL1_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL1_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL1_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL1_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL1_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL1_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL1_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL1_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL1_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL1_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL1_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL1_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL1_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL1_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL1_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL1_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL1_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL1_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL1_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL1_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL1_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL1_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL1_RESETVAL (0x00000000u)

/* MDCTL2 */


#define CSL_PSC_MDCTL2_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL2_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL2_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL2_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL2_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL2_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL2_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL2_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL2_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL2_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL2_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL2_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL2_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL2_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL2_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL2_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL2_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL2_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL2_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL2_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL2_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL2_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL2_RESETVAL (0x00000000u)

/* MDCTL3 */


#define CSL_PSC_MDCTL3_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL3_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL3_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL3_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL3_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL3_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL3_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL3_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL3_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL3_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL3_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL3_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL3_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL3_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL3_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL3_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL3_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL3_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL3_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL3_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL3_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL3_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL3_RESETVAL (0x00000000u)

/* MDCTL4 */


#define CSL_PSC_MDCTL4_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL4_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL4_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL4_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL4_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL4_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL4_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL4_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL4_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL4_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL4_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL4_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL4_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL4_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL4_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL4_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL4_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL4_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL4_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL4_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL4_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL4_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL4_RESETVAL (0x00000000u)

/* MDCTL5 */


#define CSL_PSC_MDCTL5_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL5_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL5_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL5_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL5_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL5_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL5_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL5_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL5_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL5_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL5_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL5_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL5_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL5_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL5_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL5_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL5_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL5_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL5_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL5_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL5_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL5_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL5_RESETVAL (0x00000000u)

/* MDCTL6 */


#define CSL_PSC_MDCTL6_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL6_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL6_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL6_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL6_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL6_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL6_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL6_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL6_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL6_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL6_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL6_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL6_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL6_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL6_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL6_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL6_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL6_NEXT_RESETVAL     (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL6_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL6_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL6_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL6_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL6_RESETVAL          (0x00000000u)

/* MDCTL7 */


#define CSL_PSC_MDCTL7_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL7_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL7_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL7_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL7_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL7_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL7_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL7_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL7_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL7_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL7_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL7_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL7_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL7_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL7_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL7_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL7_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL7_NEXT_RESETVAL     (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL7_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL7_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL7_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL7_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL7_RESETVAL          (0x00000000u)

/* MDCTL8 */


#define CSL_PSC_MDCTL8_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL8_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL8_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL8_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL8_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL8_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL8_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL8_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL8_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL8_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL8_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL8_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL8_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL8_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL8_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL8_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL8_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL8_NEXT_RESETVAL     (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL8_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL8_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL8_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL8_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL8_RESETVAL          (0x00000000u)

/* MDCTL9 */


#define CSL_PSC_MDCTL9_EMUIHBIE_MASK     (0x00000400u)
#define CSL_PSC_MDCTL9_EMUIHBIE_SHIFT    (0x0000000Au)
#define CSL_PSC_MDCTL9_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL9_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL9_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL9_EMURSTIE_MASK     (0x00000200u)
#define CSL_PSC_MDCTL9_EMURSTIE_SHIFT    (0x00000009u)
#define CSL_PSC_MDCTL9_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL9_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL9_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL9_LRSTZ_MASK        (0x00000100u)
#define CSL_PSC_MDCTL9_LRSTZ_SHIFT       (0x00000008u)
#define CSL_PSC_MDCTL9_LRSTZ_RESETVAL    (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL9_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL9_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL9_NEXT_MASK         (0x0000001Fu)
#define CSL_PSC_MDCTL9_NEXT_SHIFT        (0x00000000u)
#define CSL_PSC_MDCTL9_NEXT_RESETVAL     (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL9_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL9_NEXT_SYNCRST      (0x00000001u)
#define CSL_PSC_MDCTL9_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL9_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL9_RESETVAL          (0x00000000u)

/* MDCTL10 */


#define CSL_PSC_MDCTL10_EMUIHBIE_MASK    (0x00000400u)
#define CSL_PSC_MDCTL10_EMUIHBIE_SHIFT   (0x0000000Au)
#define CSL_PSC_MDCTL10_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL10_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL10_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL10_EMURSTIE_MASK    (0x00000200u)
#define CSL_PSC_MDCTL10_EMURSTIE_SHIFT   (0x00000009u)
#define CSL_PSC_MDCTL10_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL10_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL10_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL10_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDCTL10_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDCTL10_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL10_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL10_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL10_NEXT_MASK        (0x0000001Fu)
#define CSL_PSC_MDCTL10_NEXT_SHIFT       (0x00000000u)
#define CSL_PSC_MDCTL10_NEXT_RESETVAL    (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL10_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL10_NEXT_SYNCRST     (0x00000001u)
#define CSL_PSC_MDCTL10_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL10_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL10_RESETVAL         (0x00000000u)

/* MDCTL11 */


#define CSL_PSC_MDCTL11_EMUIHBIE_MASK    (0x00000400u)
#define CSL_PSC_MDCTL11_EMUIHBIE_SHIFT   (0x0000000Au)
#define CSL_PSC_MDCTL11_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL11_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL11_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL11_EMURSTIE_MASK    (0x00000200u)
#define CSL_PSC_MDCTL11_EMURSTIE_SHIFT   (0x00000009u)
#define CSL_PSC_MDCTL11_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL11_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL11_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL11_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDCTL11_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDCTL11_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL11_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL11_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL11_NEXT_MASK        (0x0000001Fu)
#define CSL_PSC_MDCTL11_NEXT_SHIFT       (0x00000000u)
#define CSL_PSC_MDCTL11_NEXT_RESETVAL    (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL11_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL11_NEXT_SYNCRST     (0x00000001u)
#define CSL_PSC_MDCTL11_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL11_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL11_RESETVAL         (0x00000000u)

/* MDCTL12 */


#define CSL_PSC_MDCTL12_EMUIHBIE_MASK    (0x00000400u)
#define CSL_PSC_MDCTL12_EMUIHBIE_SHIFT   (0x0000000Au)
#define CSL_PSC_MDCTL12_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL12_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL12_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL12_EMURSTIE_MASK    (0x00000200u)
#define CSL_PSC_MDCTL12_EMURSTIE_SHIFT   (0x00000009u)
#define CSL_PSC_MDCTL12_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL12_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL12_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL12_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDCTL12_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDCTL12_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL12_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL12_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL12_NEXT_MASK        (0x0000001Fu)
#define CSL_PSC_MDCTL12_NEXT_SHIFT       (0x00000000u)
#define CSL_PSC_MDCTL12_NEXT_RESETVAL (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL12_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL12_NEXT_SYNCRST     (0x00000001u)
#define CSL_PSC_MDCTL12_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL12_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL12_RESETVAL (0x00000000u)

/* MDCTL13 */


#define CSL_PSC_MDCTL13_EMUIHBIE_MASK    (0x00000400u)
#define CSL_PSC_MDCTL13_EMUIHBIE_SHIFT   (0x0000000Au)
#define CSL_PSC_MDCTL13_EMUIHBIE_RESETVAL (0x00000000u)
/*----EMUIHBIE Tokens----*/
#define CSL_PSC_MDCTL13_EMUIHBIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL13_EMUIHBIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL13_EMURSTIE_MASK    (0x00000200u)
#define CSL_PSC_MDCTL13_EMURSTIE_SHIFT   (0x00000009u)
#define CSL_PSC_MDCTL13_EMURSTIE_RESETVAL (0x00000000u)
/*----EMURSTIE Tokens----*/
#define CSL_PSC_MDCTL13_EMURSTIE_DISABLE (0x00000000u)
#define CSL_PSC_MDCTL13_EMURSTIE_ENABLE (0x00000001u)

#define CSL_PSC_MDCTL13_LRSTZ_MASK       (0x00000100u)
#define CSL_PSC_MDCTL13_LRSTZ_SHIFT      (0x00000008u)
#define CSL_PSC_MDCTL13_LRSTZ_RESETVAL   (0x00000000u)
/*----LRSTz Tokens----*/
#define CSL_PSC_MDCTL13_LRSTZ_ASSERT (0x00000000u)
#define CSL_PSC_MDCTL13_LRSTZ_DEASSERT (0x00000001u)


#define CSL_PSC_MDCTL13_NEXT_MASK        (0x0000001Fu)
#define CSL_PSC_MDCTL13_NEXT_SHIFT       (0x00000000u)
#define CSL_PSC_MDCTL13_NEXT_RESETVAL    (0x00000000u)
/*----NEXT Tokens----*/
#define CSL_PSC_MDCTL13_NEXT_SWRSTDISABLE (0x00000000u)
#define CSL_PSC_MDCTL13_NEXT_SYNCRST     (0x00000001u)
#define CSL_PSC_MDCTL13_NEXT_DISABLE (0x00000002u)
#define CSL_PSC_MDCTL13_NEXT_ENABLE (0x00000003u)

#define CSL_PSC_MDCTL13_RESETVAL         (0x00000000u)

#endif
