/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_pwrdwnL2.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for L2PWRDWN
 */

#ifndef _CSLR_PWRDWNL2_H_
#define _CSLR_PWRDWNL2_H_

#include <cslr.h>
#include <tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint8 RSVD0[64];
    volatile Uint32 L2PDWAKE[2];
    volatile Uint8 RSVD1[8];
    volatile Uint32 L2PDSLEEP[2];
    volatile Uint8 RSVD2[8];
    volatile Uint32 L2PDSTAT[2];
} CSL_L2pwrdwnRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_L2pwrdwnRegs *CSL_L2pwrdwnRegsOvly;
/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* L2PDWAKE */

#define CSL_L2PWRDWN_L2PDWAKE_P1_MASK    (0x00000002u)
#define CSL_L2PWRDWN_L2PDWAKE_P1_SHIFT   (0x00000001u)
#define CSL_L2PWRDWN_L2PDWAKE_P1_RESETVAL (0x00000000u)

/*----P1 Tokens----*/
#define CSL_L2PWRDWN_L2PDWAKE_P1_DISABLE (0x00000000u)
#define CSL_L2PWRDWN_L2PDWAKE_P1_ENABLE  (0x00000001u)

#define CSL_L2PWRDWN_L2PDWAKE_P0_MASK    (0x00000001u)
#define CSL_L2PWRDWN_L2PDWAKE_P0_SHIFT   (0x00000000u)
#define CSL_L2PWRDWN_L2PDWAKE_P0_RESETVAL (0x00000000u)

/*----P0 Tokens----*/
#define CSL_L2PWRDWN_L2PDWAKE_P0_DISABLE (0x00000000u)
#define CSL_L2PWRDWN_L2PDWAKE_P0_ENABLE  (0x00000001u)

#define CSL_L2PWRDWN_L2PDWAKE_RESETVAL   (0x00000000u)

/* L2PDSLEEP */

#define CSL_L2PWRDWN_L2PDSLEEP_P1_MASK   (0x00000002u)
#define CSL_L2PWRDWN_L2PDSLEEP_P1_SHIFT  (0x00000001u)
#define CSL_L2PWRDWN_L2PDSLEEP_P1_RESETVAL (0x00000000u)

/*----P1 Tokens----*/
#define CSL_L2PWRDWN_L2PDSLEEP_P1_DISABLE (0x00000000u)
#define CSL_L2PWRDWN_L2PDSLEEP_P1_ENABLE (0x00000001u)

#define CSL_L2PWRDWN_L2PDSLEEP_P0_MASK   (0x00000001u)
#define CSL_L2PWRDWN_L2PDSLEEP_P0_SHIFT  (0x00000000u)
#define CSL_L2PWRDWN_L2PDSLEEP_P0_RESETVAL (0x00000000u)

/*----P0 Tokens----*/
#define CSL_L2PWRDWN_L2PDSLEEP_P0_DISABLE (0x00000000u)
#define CSL_L2PWRDWN_L2PDSLEEP_P0_ENABLE (0x00000001u)

#define CSL_L2PWRDWN_L2PDSLEEP_RESETVAL  (0x00000000u)

/* L2PDSTAT */

#define CSL_L2PWRDWN_L2PDSTAT_P1_MASK    (0x00000002u)
#define CSL_L2PWRDWN_L2PDSTAT_P1_SHIFT   (0x00000001u)
#define CSL_L2PWRDWN_L2PDSTAT_P1_RESETVAL (0x00000000u)

#define CSL_L2PWRDWN_L2PDSTAT_P0_MASK    (0x00000001u)
#define CSL_L2PWRDWN_L2PDSTAT_P0_SHIFT   (0x00000000u)
#define CSL_L2PWRDWN_L2PDSTAT_P0_RESETVAL (0x00000000u)

#define CSL_L2PWRDWN_L2PDSTAT_RESETVAL   (0x00000000u)

#endif
