/* =============================================================================
 *  Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_sec.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for SEC
 *  ============================================================================
 */

#ifndef _CSLR_SEC_H_
#define _CSLR_SEC_H_

#include <cslr.h>

#include "tistdtypes.h"


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID_REG;
    volatile Uint32 SCAN_REG;
    volatile Uint32 TEST_REG;
    volatile Uint32 SEC_TAP_CTL;
    volatile Uint32 PUBLIC_KEY0;
    volatile Uint32 PUBLIC_KEY1;
    volatile Uint32 PUBLIC_KEY2;
    volatile Uint32 PUBLIC_KEY3;
} CSL_Sec_ctlRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID_REG */

#define CSL_SEC_CTL_PID_REG_SCHEME_MASK  (0xC0000000u)
#define CSL_SEC_CTL_PID_REG_SCHEME_SHIFT (0x0000001Eu)
#define CSL_SEC_CTL_PID_REG_SCHEME_RESETVAL (0x00000001u)


#define CSL_SEC_CTL_PID_REG_FUNC_GROUP_MASK (0x0FFF0000u)
#define CSL_SEC_CTL_PID_REG_FUNC_GROUP_SHIFT (0x00000010u)
#define CSL_SEC_CTL_PID_REG_FUNC_GROUP_RESETVAL (0x00000484u)

#define CSL_SEC_CTL_PID_REG_RTL_REV_MASK (0x0000F800u)
#define CSL_SEC_CTL_PID_REG_RTL_REV_SHIFT (0x0000000Bu)
#define CSL_SEC_CTL_PID_REG_RTL_REV_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PID_REG_MAJOR_REV_MASK (0x00000700u)
#define CSL_SEC_CTL_PID_REG_MAJOR_REV_SHIFT (0x00000008u)
#define CSL_SEC_CTL_PID_REG_MAJOR_REV_RESETVAL (0x00000001u)

#define CSL_SEC_CTL_PID_REG_CUSTOM_MASK  (0x000000C0u)
#define CSL_SEC_CTL_PID_REG_CUSTOM_SHIFT (0x00000006u)
#define CSL_SEC_CTL_PID_REG_CUSTOM_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PID_REG_MINOR_REV_MASK (0x0000003Fu)
#define CSL_SEC_CTL_PID_REG_MINOR_REV_SHIFT (0x00000000u)
#define CSL_SEC_CTL_PID_REG_MINOR_REV_RESETVAL (0x00000007u)

#define CSL_SEC_CTL_PID_REG_RESETVAL     (0x44840107u)

/* SCAN_REG */


#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_PASS_MASK (0x00000200u)
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_PASS_SHIFT (0x00000009u)
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_PASS_RESETVAL (0x00000000u)
/*----SEC_CKSUM_PASS Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_PASS_MATCHED (0x00000001u)

#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_DONE_MASK (0x00000100u)
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_DONE_SHIFT (0x00000008u)
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_DONE_RESETVAL (0x00000000u)
/*----SEC_CKSUM_DONE Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_SEC_CKSUM_DONE_COMPLETED (0x00000001u)


#define CSL_SEC_CTL_SCAN_REG_RWIR_MASK_EN_MASK (0x00000020u)
#define CSL_SEC_CTL_SCAN_REG_RWIR_MASK_EN_SHIFT (0x00000005u)
#define CSL_SEC_CTL_SCAN_REG_RWIR_MASK_EN_RESETVAL (0x00000000u)
/*----RWIR_MASK_EN Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_RWIR_MASK_EN_ENABLED (0x00000001u)

#define CSL_SEC_CTL_SCAN_REG_SEC_OV_REQ_MASK (0x00000010u)
#define CSL_SEC_CTL_SCAN_REG_SEC_OV_REQ_SHIFT (0x00000004u)
#define CSL_SEC_CTL_SCAN_REG_SEC_OV_REQ_RESETVAL (0x00000000u)
/*----SEC_OV_REQ Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_SEC_OV_REQ_KERNEL_INVOKE (0x00000001u)

#define CSL_SEC_CTL_SCAN_REG_TEST_AS_SEC_MASK (0x00000008u)
#define CSL_SEC_CTL_SCAN_REG_TEST_AS_SEC_SHIFT (0x00000003u)
#define CSL_SEC_CTL_SCAN_REG_TEST_AS_SEC_RESETVAL (0x00000000u)
/*----TEST_AS_SEC Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_TEST_AS_SEC_TEST_SECURE (0x00000001u)
#define CSL_SEC_CTL_SCAN_REG_TEST_AS_SEC_TEST_NONSECURE (0x00000000u)

#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_MASK (0x00000007u)
#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_SHIFT (0x00000000u)
#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_RESETVAL (0x00000000u)
/*----DEVICE_TYPE Tokens----*/
#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_TEST (0x00000000u)
#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_SECURE (0x00000002u)
#define CSL_SEC_CTL_SCAN_REG_DEVICE_TYPE_NONSECURE (0x00000003u)

#define CSL_SEC_CTL_SCAN_REG_RESETVAL    (0x00000000u)

/* TEST_REG */


#define CSL_SEC_CTL_TEST_REG_TEST_AS_SEC_MASK (0x00040000u)
#define CSL_SEC_CTL_TEST_REG_TEST_AS_SEC_SHIFT (0x00000012u)
#define CSL_SEC_CTL_TEST_REG_TEST_AS_SEC_RESETVAL (0x00000000u)
/*----TEST_AS_SEC Tokens----*/
#define CSL_SEC_CTL_TEST_REG_TEST_AS_SEC_SET (0x00000001u)

#define CSL_SEC_CTL_TEST_REG_SRAM_N_CACHE_MASK (0x00020000u)
#define CSL_SEC_CTL_TEST_REG_SRAM_N_CACHE_SHIFT (0x00000011u)
#define CSL_SEC_CTL_TEST_REG_SRAM_N_CACHE_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_TEST_REG_SEC_UPDATE_MASK (0x00010000u)
#define CSL_SEC_CTL_TEST_REG_SEC_UPDATE_SHIFT (0x00000010u)
#define CSL_SEC_CTL_TEST_REG_SEC_UPDATE_RESETVAL (0x00000000u)
/*----SEC_UPDATE Tokens----*/
#define CSL_SEC_CTL_TEST_REG_SEC_UPDATE_SET (0x00000001u)


#define CSL_SEC_CTL_TEST_REG_SEC_TAP_WRITTEN_MASK (0x00000020u)
#define CSL_SEC_CTL_TEST_REG_SEC_TAP_WRITTEN_SHIFT (0x00000005u)
#define CSL_SEC_CTL_TEST_REG_SEC_TAP_WRITTEN_RESETVAL (0x00000000u)
/*----SEC_TAP_WRITTEN Tokens----*/
#define CSL_SEC_CTL_TEST_REG_SEC_TAP_WRITTEN_COMPLETE (0x00000001u)

#define CSL_SEC_CTL_TEST_REG_SEC_TEST_WRITTEN_MASK (0x00000010u)
#define CSL_SEC_CTL_TEST_REG_SEC_TEST_WRITTEN_SHIFT (0x00000004u)
#define CSL_SEC_CTL_TEST_REG_SEC_TEST_WRITTEN_RESETVAL (0x00000000u)
/*----SEC_TEST_WRITTEN Tokens----*/
#define CSL_SEC_CTL_TEST_REG_SEC_TEST_WRITTEN_COMPLETE (0x00000001u)

#define CSL_SEC_CTL_TEST_REG_SEC_ROM_PASS_MASK (0x00000008u)
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_PASS_SHIFT (0x00000003u)
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_PASS_RESETVAL (0x00000000u)
/*----SEC_ROM_PASS Tokens----*/
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_PASS_PASS (0x00000001u)
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_PASS_FAILED (0x00000001u)

#define CSL_SEC_CTL_TEST_REG_SEC_ROM_DONE_MASK (0x00000004u)
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_DONE_SHIFT (0x00000002u)
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_DONE_RESETVAL (0x00000000u)
/*----SEC_ROM_DONE Tokens----*/
#define CSL_SEC_CTL_TEST_REG_SEC_ROM_DONE_COMPLETE (0x00000001u)

#define CSL_SEC_CTL_TEST_REG_MMR_UNLOCK_MASK (0x00000002u)
#define CSL_SEC_CTL_TEST_REG_MMR_UNLOCK_SHIFT (0x00000001u)
#define CSL_SEC_CTL_TEST_REG_MMR_UNLOCK_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_TEST_REG_SEC_OV_MASK (0x00000001u)
#define CSL_SEC_CTL_TEST_REG_SEC_OV_SHIFT (0x00000000u)
#define CSL_SEC_CTL_TEST_REG_SEC_OV_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_TEST_REG_RESETVAL    (0x00000000u)

/* SEC_TAP_CTL */

#define CSL_SEC_CTL_SEC_TAP_CTL_TEST_TAP_EN_MASK (0xFFFF0000u)
#define CSL_SEC_CTL_SEC_TAP_CTL_TEST_TAP_EN_SHIFT (0x00000010u)
#define CSL_SEC_CTL_SEC_TAP_CTL_TEST_TAP_EN_RESETVAL (0x0000FFFFu)
/*----TEST_TAP_EN Tokens----*/
#define CSL_SEC_CTL_SEC_TAP_CTL_TEST_TAP_EN_ICEPICKSEL (0x00000001u)
#define CSL_SEC_CTL_SEC_TAP_CTL_TEST_TAP_EN_ICEPICKNOTSEL (0x00000000u)

#define CSL_SEC_CTL_SEC_TAP_CTL_EMU_TAP_EN_MASK (0x0000FFFFu)
#define CSL_SEC_CTL_SEC_TAP_CTL_EMU_TAP_EN_SHIFT (0x00000000u)
#define CSL_SEC_CTL_SEC_TAP_CTL_EMU_TAP_EN_RESETVAL (0x0000FFFFu)
/*----EMU_TAP_EN Tokens----*/
#define CSL_SEC_CTL_SEC_TAP_CTL_EMU_TAP_EN_ICEPICKSEL (0x00000001u)
#define CSL_SEC_CTL_SEC_TAP_CTL_EMU_TAP_EN_ICEPICKNOTSEL (0x00000000u)

#define CSL_SEC_CTL_SEC_TAP_CTL_RESETVAL (0xFFFFFFFFu)

/* PUBLIC_KEY0 */

#define CSL_SEC_CTL_PUBLIC_KEY0_PUBLIC_KEY_MASK (0xFFFFFFFFu)
#define CSL_SEC_CTL_PUBLIC_KEY0_PUBLIC_KEY_SHIFT (0x00000000u)
#define CSL_SEC_CTL_PUBLIC_KEY0_PUBLIC_KEY_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PUBLIC_KEY0_RESETVAL (0x00000000u)

/* PUBLIC_KEY1 */

#define CSL_SEC_CTL_PUBLIC_KEY1_PUBLIC_KEY_MASK (0xFFFFFFFFu)
#define CSL_SEC_CTL_PUBLIC_KEY1_PUBLIC_KEY_SHIFT (0x00000000u)
#define CSL_SEC_CTL_PUBLIC_KEY1_PUBLIC_KEY_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PUBLIC_KEY1_RESETVAL (0x00000000u)

/* PUBLIC_KEY2 */

#define CSL_SEC_CTL_PUBLIC_KEY2_PUBLIC_KEY_MASK (0xFFFFFFFFu)
#define CSL_SEC_CTL_PUBLIC_KEY2_PUBLIC_KEY_SHIFT (0x00000000u)
#define CSL_SEC_CTL_PUBLIC_KEY2_PUBLIC_KEY_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PUBLIC_KEY2_RESETVAL (0x00000000u)

/* PUBLIC_KEY3 */

#define CSL_SEC_CTL_PUBLIC_KEY3_PUBLIC_KEY_MASK (0xFFFFFFFFu)
#define CSL_SEC_CTL_PUBLIC_KEY3_PUBLIC_KEY_SHIFT (0x00000000u)
#define CSL_SEC_CTL_PUBLIC_KEY3_PUBLIC_KEY_RESETVAL (0x00000000u)

#define CSL_SEC_CTL_PUBLIC_KEY3_RESETVAL (0x00000000u)

#endif
