/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_smc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for SMC
 *  ============================================================================
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  23-Mar-2006 NG  File Created
 *
 * =============================================================================
 */
#ifndef _CSLR_SMC_H_
#define _CSLR_SMC_H_

#include <cslr.h>
#include "tistdtypes.h"

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 SL2PFCPEN;
    volatile Uint32 SL2PFCFLUSH;
    volatile Uint32 SL2MPFSR;
    volatile Uint32 SL2MPFAR;
    volatile Uint32 SL2PDSTAT;
    volatile Uint8 RSVD0[236];
    volatile Uint32 SL2AMLSTAT0;
    volatile Uint32 SL2AMLSTAT1;
    volatile Uint32 SL2AMLSTAT2;
    volatile Uint32 SL2AMLSTAT3;
    volatile Uint8 RSVD1[16];
    volatile Uint32 SL2AMLDATA[4];
    volatile Uint8 RSVD2[208];
    volatile Uint32 SL2PDSLEEP[6];
    volatile Uint8 RSVD3[8];
    volatile Uint32 SL2PDWAKE[6];
} CSL_SmcRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_SmcRegs  *CSL_SmcRegsOvly;


/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SL2PFCPEN */

#define CSL_SMC_SL2PFCPEN_PAGE31_MASK    (0x80000000u)
#define CSL_SMC_SL2PFCPEN_PAGE31_SHIFT   (0x0000001Fu)
#define CSL_SMC_SL2PFCPEN_PAGE31_RESETVAL (0x00000000u)
/*----PAGE31 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE31_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE31_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE30_MASK    (0x40000000u)
#define CSL_SMC_SL2PFCPEN_PAGE30_SHIFT   (0x0000001Eu)
#define CSL_SMC_SL2PFCPEN_PAGE30_RESETVAL (0x00000000u)
/*----PAGE30 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE30_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE30_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE29_MASK    (0x20000000u)
#define CSL_SMC_SL2PFCPEN_PAGE29_SHIFT   (0x0000001Du)
#define CSL_SMC_SL2PFCPEN_PAGE29_RESETVAL (0x00000000u)
/*----PAGE29 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE29_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE29_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE28_MASK    (0x10000000u)
#define CSL_SMC_SL2PFCPEN_PAGE28_SHIFT   (0x0000001Cu)
#define CSL_SMC_SL2PFCPEN_PAGE28_RESETVAL (0x00000000u)
/*----PAGE28 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE28_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE28_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE27_MASK    (0x08000000u)
#define CSL_SMC_SL2PFCPEN_PAGE27_SHIFT   (0x0000001Bu)
#define CSL_SMC_SL2PFCPEN_PAGE27_RESETVAL (0x00000000u)
/*----PAGE27 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE27_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE27_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE26_MASK    (0x04000000u)
#define CSL_SMC_SL2PFCPEN_PAGE26_SHIFT   (0x0000001Au)
#define CSL_SMC_SL2PFCPEN_PAGE26_RESETVAL (0x00000000u)
/*----PAGE26 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE26_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE26_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE25_MASK    (0x02000000u)
#define CSL_SMC_SL2PFCPEN_PAGE25_SHIFT   (0x00000019u)
#define CSL_SMC_SL2PFCPEN_PAGE25_RESETVAL (0x00000000u)
/*----PAGE25 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE25_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE25_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE24_MASK    (0x01000000u)
#define CSL_SMC_SL2PFCPEN_PAGE24_SHIFT   (0x00000018u)
#define CSL_SMC_SL2PFCPEN_PAGE24_RESETVAL (0x00000000u)
/*----PAGE24 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE24_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE24_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE23_MASK    (0x00800000u)
#define CSL_SMC_SL2PFCPEN_PAGE23_SHIFT   (0x00000017u)
#define CSL_SMC_SL2PFCPEN_PAGE23_RESETVAL (0x00000000u)
/*----PAGE23 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE23_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE23_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE22_MASK    (0x00400000u)
#define CSL_SMC_SL2PFCPEN_PAGE22_SHIFT   (0x00000016u)
#define CSL_SMC_SL2PFCPEN_PAGE22_RESETVAL (0x00000000u)
/*----PAGE22 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE22_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE22_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE21_MASK    (0x00200000u)
#define CSL_SMC_SL2PFCPEN_PAGE21_SHIFT   (0x00000015u)
#define CSL_SMC_SL2PFCPEN_PAGE21_RESETVAL (0x00000000u)
/*----PAGE21 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE21_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE21_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE20_MASK    (0x00100000u)
#define CSL_SMC_SL2PFCPEN_PAGE20_SHIFT   (0x00000014u)
#define CSL_SMC_SL2PFCPEN_PAGE20_RESETVAL (0x00000000u)
/*----PAGE20 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE20_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE20_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE19_MASK    (0x00080000u)
#define CSL_SMC_SL2PFCPEN_PAGE19_SHIFT   (0x00000013u)
#define CSL_SMC_SL2PFCPEN_PAGE19_RESETVAL (0x00000000u)
/*----PAGE19 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE19_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE19_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE18_MASK    (0x00040000u)
#define CSL_SMC_SL2PFCPEN_PAGE18_SHIFT   (0x00000012u)
#define CSL_SMC_SL2PFCPEN_PAGE18_RESETVAL (0x00000000u)
/*----PAGE18 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE18_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE18_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE17_MASK    (0x00020000u)
#define CSL_SMC_SL2PFCPEN_PAGE17_SHIFT   (0x00000011u)
#define CSL_SMC_SL2PFCPEN_PAGE17_RESETVAL (0x00000000u)
/*----PAGE17 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE17_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE17_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE16_MASK    (0x00010000u)
#define CSL_SMC_SL2PFCPEN_PAGE16_SHIFT   (0x00000010u)
#define CSL_SMC_SL2PFCPEN_PAGE16_RESETVAL (0x00000000u)
/*----PAGE16 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE16_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE16_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE15_MASK    (0x00008000u)
#define CSL_SMC_SL2PFCPEN_PAGE15_SHIFT   (0x0000000Fu)
#define CSL_SMC_SL2PFCPEN_PAGE15_RESETVAL (0x00000000u)
/*----PAGE15 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE15_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE15_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE14_MASK    (0x00004000u)
#define CSL_SMC_SL2PFCPEN_PAGE14_SHIFT   (0x0000000Eu)
#define CSL_SMC_SL2PFCPEN_PAGE14_RESETVAL (0x00000000u)
/*----PAGE14 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE14_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE14_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE13_MASK    (0x00002000u)
#define CSL_SMC_SL2PFCPEN_PAGE13_SHIFT   (0x0000000Du)
#define CSL_SMC_SL2PFCPEN_PAGE13_RESETVAL (0x00000000u)
/*----PAGE13 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE13_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE13_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE12_MASK    (0x00001000u)
#define CSL_SMC_SL2PFCPEN_PAGE12_SHIFT   (0x0000000Cu)
#define CSL_SMC_SL2PFCPEN_PAGE12_RESETVAL (0x00000000u)
/*----PAGE12 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE12_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE12_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE11_MASK    (0x00000800u)
#define CSL_SMC_SL2PFCPEN_PAGE11_SHIFT   (0x0000000Bu)
#define CSL_SMC_SL2PFCPEN_PAGE11_RESETVAL (0x00000000u)
/*----PAGE11 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE11_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE11_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE10_MASK    (0x00000400u)
#define CSL_SMC_SL2PFCPEN_PAGE10_SHIFT   (0x0000000Au)
#define CSL_SMC_SL2PFCPEN_PAGE10_RESETVAL (0x00000000u)
/*----PAGE10 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE10_DIS     (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE10_EN      (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE9_MASK     (0x00000200u)
#define CSL_SMC_SL2PFCPEN_PAGE9_SHIFT    (0x00000009u)
#define CSL_SMC_SL2PFCPEN_PAGE9_RESETVAL (0x00000000u)
/*----PAGE9 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE9_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE9_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE8_MASK     (0x00000100u)
#define CSL_SMC_SL2PFCPEN_PAGE8_SHIFT    (0x00000008u)
#define CSL_SMC_SL2PFCPEN_PAGE8_RESETVAL (0x00000000u)
/*----PAGE8 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE8_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE8_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE7_MASK     (0x00000080u)
#define CSL_SMC_SL2PFCPEN_PAGE7_SHIFT    (0x00000007u)
#define CSL_SMC_SL2PFCPEN_PAGE7_RESETVAL (0x00000000u)
/*----PAGE7 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE7_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE7_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE6_MASK     (0x00000040u)
#define CSL_SMC_SL2PFCPEN_PAGE6_SHIFT    (0x00000006u)
#define CSL_SMC_SL2PFCPEN_PAGE6_RESETVAL (0x00000000u)
/*----PAGE6 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE6_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE6_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE5_MASK     (0x00000020u)
#define CSL_SMC_SL2PFCPEN_PAGE5_SHIFT    (0x00000005u)
#define CSL_SMC_SL2PFCPEN_PAGE5_RESETVAL (0x00000000u)
/*----PAGE5 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE5_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE5_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE4_MASK     (0x00000010u)
#define CSL_SMC_SL2PFCPEN_PAGE4_SHIFT    (0x00000004u)
#define CSL_SMC_SL2PFCPEN_PAGE4_RESETVAL (0x00000000u)
/*----PAGE4 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE4_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE4_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE3_MASK     (0x00000008u)
#define CSL_SMC_SL2PFCPEN_PAGE3_SHIFT    (0x00000003u)
#define CSL_SMC_SL2PFCPEN_PAGE3_RESETVAL (0x00000000u)
/*----PAGE3 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE3_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE3_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE2_MASK     (0x00000004u)
#define CSL_SMC_SL2PFCPEN_PAGE2_SHIFT    (0x00000002u)
#define CSL_SMC_SL2PFCPEN_PAGE2_RESETVAL (0x00000000u)
/*----PAGE2 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE2_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE2_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE1_MASK     (0x00000002u)
#define CSL_SMC_SL2PFCPEN_PAGE1_SHIFT    (0x00000001u)
#define CSL_SMC_SL2PFCPEN_PAGE1_RESETVAL (0x00000000u)
/*----PAGE1 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE1_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE1_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_PAGE0_MASK     (0x00000001u)
#define CSL_SMC_SL2PFCPEN_PAGE0_SHIFT    (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE0_RESETVAL (0x00000000u)
/*----PAGE0 Tokens----*/
#define CSL_SMC_SL2PFCPEN_PAGE0_DIS      (0x00000000u)
#define CSL_SMC_SL2PFCPEN_PAGE0_EN       (0x00000001u)

#define CSL_SMC_SL2PFCPEN_RESETVAL       (0x00000000u)

/* SL2PFCFLUSH */


#define CSL_SMC_SL2PFCFLUSH_FLUSH_MASK   (0x00000001u)
#define CSL_SMC_SL2PFCFLUSH_FLUSH_SHIFT  (0x00000000u)
#define CSL_SMC_SL2PFCFLUSH_FLUSH_RESETVAL (0x00000000u)
/*----FLUSH Tokens----*/
#define CSL_SMC_SL2PFCFLUSH_FLUSH_FLUSH  (0x00000001u)

#define CSL_SMC_SL2PFCFLUSH_RESETVAL     (0x00000000u)

/* SL2MPFSR */


#define CSL_SMC_SL2MPFSR_CPU_ID_MASK     (0x0000001Cu)
#define CSL_SMC_SL2MPFSR_CPU_ID_SHIFT    (0x00000002u)
#define CSL_SMC_SL2MPFSR_CPU_ID_RESETVAL (0x00000003u)
/*----CPU_ID Tokens----*/
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU0     (0x00000000u)
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU1     (0x00000001u)
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU2     (0x00000002u)
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU3     (0x00000003u)
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU4     (0x00000004u)
#define CSL_SMC_SL2MPFSR_CPU_ID_CPU5     (0x00000005u)

#define CSL_SMC_SL2MPFSR_MODE_MASK       (0x00000002u)
#define CSL_SMC_SL2MPFSR_MODE_SHIFT      (0x00000001u)
#define CSL_SMC_SL2MPFSR_MODE_RESETVAL   (0x00000000u)
/*----MODE Tokens----*/
#define CSL_SMC_SL2MPFSR_MODE_SECURE     (0x00000000u)
#define CSL_SMC_SL2MPFSR_MODE_NONSECURE  (0x00000001u)

#define CSL_SMC_SL2MPFSR_CLEAR_MASK      (0x00000001u)
#define CSL_SMC_SL2MPFSR_CLEAR_SHIFT     (0x00000000u)
#define CSL_SMC_SL2MPFSR_CLEAR_RESETVAL  (0x00000000u)
/*----CLEAR Tokens----*/
#define CSL_SMC_SL2MPFSR_CLEAR_CLEAR     (0x00000001u)

#define CSL_SMC_SL2MPFSR_RESETVAL        (0x0000000Cu)

/* SL2MPFAR */

#define CSL_SMC_SL2MPFAR_FAULT_ADDRESS_MASK (0xFFFFFFFFu)
#define CSL_SMC_SL2MPFAR_FAULT_ADDRESS_SHIFT (0x00000000u)
#define CSL_SMC_SL2MPFAR_FAULT_ADDRESS_RESETVAL (0x00000000u)

#define CSL_SMC_SL2MPFAR_RESETVAL        (0x00000000u)

/* SL2PDSTAT */


#define CSL_SMC_SL2PDSTAT_P3_MASK        (0x00000008u)
#define CSL_SMC_SL2PDSTAT_P3_SHIFT       (0x00000003u)
#define CSL_SMC_SL2PDSTAT_P3_RESETVAL    (0x00000000u)

#define CSL_SMC_SL2PDSTAT_P2_MASK        (0x00000004u)
#define CSL_SMC_SL2PDSTAT_P2_SHIFT       (0x00000002u)
#define CSL_SMC_SL2PDSTAT_P2_RESETVAL    (0x00000000u)



#define CSL_SMC_SL2PDSTAT_RESETVAL       (0x00000000u)

/* SL2AMLSTAT0 */


#define CSL_SMC_SL2AMLSTAT0_ADDR_MASK    (0x00FFFFE0u)
#define CSL_SMC_SL2AMLSTAT0_ADDR_SHIFT   (0x00000005u)
#define CSL_SMC_SL2AMLSTAT0_ADDR_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT0_CPU_ID_MASK  (0x0000001Cu)
#define CSL_SMC_SL2AMLSTAT0_CPU_ID_SHIFT (0x00000002u)
#define CSL_SMC_SL2AMLSTAT0_CPU_ID_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT0_LINKV_MASK   (0x00000002u)
#define CSL_SMC_SL2AMLSTAT0_LINKV_SHIFT  (0x00000001u)
#define CSL_SMC_SL2AMLSTAT0_LINKV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT0_LINKDTV_MASK (0x00000001u)
#define CSL_SMC_SL2AMLSTAT0_LINKDTV_SHIFT (0x00000000u)
#define CSL_SMC_SL2AMLSTAT0_LINKDTV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT0_RESETVAL     (0x00000000u)

/* SL2AMLSTAT1 */


#define CSL_SMC_SL2AMLSTAT1_ADDR_MASK    (0x00FFFFE0u)
#define CSL_SMC_SL2AMLSTAT1_ADDR_SHIFT   (0x00000005u)
#define CSL_SMC_SL2AMLSTAT1_ADDR_RESETVAL (0x00000001u)

#define CSL_SMC_SL2AMLSTAT1_CPU_ID_MASK  (0x0000001Cu)
#define CSL_SMC_SL2AMLSTAT1_CPU_ID_SHIFT (0x00000002u)
#define CSL_SMC_SL2AMLSTAT1_CPU_ID_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT1_LINKV_MASK   (0x00000002u)
#define CSL_SMC_SL2AMLSTAT1_LINKV_SHIFT  (0x00000001u)
#define CSL_SMC_SL2AMLSTAT1_LINKV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT1_LINKDTV_MASK (0x00000001u)
#define CSL_SMC_SL2AMLSTAT1_LINKDTV_SHIFT (0x00000000u)
#define CSL_SMC_SL2AMLSTAT1_LINKDTV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT1_RESETVAL     (0x00000020u)

/* SL2AMLSTAT2 */


#define CSL_SMC_SL2AMLSTAT2_ADDR_MASK    (0x00FFFFE0u)
#define CSL_SMC_SL2AMLSTAT2_ADDR_SHIFT   (0x00000005u)
#define CSL_SMC_SL2AMLSTAT2_ADDR_RESETVAL (0x00000002u)

#define CSL_SMC_SL2AMLSTAT2_CPU_ID_MASK  (0x0000001Cu)
#define CSL_SMC_SL2AMLSTAT2_CPU_ID_SHIFT (0x00000002u)
#define CSL_SMC_SL2AMLSTAT2_CPU_ID_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT2_LINKV_MASK   (0x00000002u)
#define CSL_SMC_SL2AMLSTAT2_LINKV_SHIFT  (0x00000001u)
#define CSL_SMC_SL2AMLSTAT2_LINKV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT2_LINKDTV_MASK (0x00000001u)
#define CSL_SMC_SL2AMLSTAT2_LINKDTV_SHIFT (0x00000000u)
#define CSL_SMC_SL2AMLSTAT2_LINKDTV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT2_RESETVAL     (0x00000040u)

/* SL2AMLSTAT3 */


#define CSL_SMC_SL2AMLSTAT3_ADDR_MASK    (0x00FFFFE0u)
#define CSL_SMC_SL2AMLSTAT3_ADDR_SHIFT   (0x00000005u)
#define CSL_SMC_SL2AMLSTAT3_ADDR_RESETVAL (0x00000003u)

#define CSL_SMC_SL2AMLSTAT3_CPU_ID_MASK  (0x0000001Cu)
#define CSL_SMC_SL2AMLSTAT3_CPU_ID_SHIFT (0x00000002u)
#define CSL_SMC_SL2AMLSTAT3_CPU_ID_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT3_LINKV_MASK   (0x00000002u)
#define CSL_SMC_SL2AMLSTAT3_LINKV_SHIFT  (0x00000001u)
#define CSL_SMC_SL2AMLSTAT3_LINKV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT3_LINKDTV_MASK (0x00000001u)
#define CSL_SMC_SL2AMLSTAT3_LINKDTV_SHIFT (0x00000000u)
#define CSL_SMC_SL2AMLSTAT3_LINKDTV_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLSTAT3_RESETVAL     (0x00000060u)

/* SL2AMLDATA */

#define CSL_SMC_SL2AMLDATA_LINKDATA_MASK (0xFFFFFFFFu)
#define CSL_SMC_SL2AMLDATA_LINKDATA_SHIFT (0x00000000u)
#define CSL_SMC_SL2AMLDATA_LINKDATA_RESETVAL (0x00000000u)

#define CSL_SMC_SL2AMLDATA_RESETVAL      (0x00000000u)

/* SL2PDSLEEP */


#define CSL_SMC_SL2PDSLEEP_P3_MASK       (0x00000008u)
#define CSL_SMC_SL2PDSLEEP_P3_SHIFT      (0x00000003u)
#define CSL_SMC_SL2PDSLEEP_P3_RESETVAL   (0x00000000u)
/*----P3 Tokens----*/
#define CSL_SMC_SL2PDSLEEP_P3_SLEEP      (0x00000001u)

#define CSL_SMC_SL2PDSLEEP_P2_MASK       (0x00000004u)
#define CSL_SMC_SL2PDSLEEP_P2_SHIFT      (0x00000002u)
#define CSL_SMC_SL2PDSLEEP_P2_RESETVAL   (0x00000000u)
/*----P2 Tokens----*/
#define CSL_SMC_SL2PDSLEEP_P2_SLEEP      (0x00000001u)


#define CSL_SMC_SL2PDSLEEP_RESETVAL      (0x00000000u)

/* SL2PDWAKE */


#define CSL_SMC_SL2PDWAKE_P3_MASK        (0x00000008u)
#define CSL_SMC_SL2PDWAKE_P3_SHIFT       (0x00000003u)
#define CSL_SMC_SL2PDWAKE_P3_RESETVAL    (0x00000000u)
/*----P3 Tokens----*/
#define CSL_SMC_SL2PDWAKE_P3_WAKE        (0x00000001u)

#define CSL_SMC_SL2PDWAKE_P2_MASK        (0x00000004u)
#define CSL_SMC_SL2PDWAKE_P2_SHIFT       (0x00000002u)
#define CSL_SMC_SL2PDWAKE_P2_RESETVAL    (0x00000000u)
/*----P2 Tokens----*/
#define CSL_SMC_SL2PDWAKE_P2_WAKE        (0x00000001u)


#define CSL_SMC_SL2PDWAKE_RESETVAL       (0x00000000u)

#endif
