/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_smcp.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for SMCP
 * =============================================================================
 */

#ifndef _CSLR_SMCP_H_
#define _CSLR_SMCP_H_

#include <cslr.h>

#include <tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 SL2BNKMSK;
    volatile Uint32 SL2PWSCNT[8];
    volatile Uint32 SL2PFCCNT;
    volatile Uint32 SL2PCMD;
    volatile Uint32 SL2PSTAT;
    volatile Uint32 SL2STATMASK;
} CSL_SmcpRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_SmcpRegs  *CSL_SmcpRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SL2BNKMSK */


#define CSL_SMCP_SL2BNKMSK_BANK3_MASK    (0x00000008u)
#define CSL_SMCP_SL2BNKMSK_BANK3_SHIFT   (0x00000003u)
#define CSL_SMCP_SL2BNKMSK_BANK3_RESETVAL (0x00000001u)

#define CSL_SMCP_SL2BNKMSK_BANK2_MASK    (0x00000004u)
#define CSL_SMCP_SL2BNKMSK_BANK2_SHIFT   (0x00000002u)
#define CSL_SMCP_SL2BNKMSK_BANK2_RESETVAL (0x00000001u)

#define CSL_SMCP_SL2BNKMSK_BANK1_MASK    (0x00000002u)
#define CSL_SMCP_SL2BNKMSK_BANK1_SHIFT   (0x00000001u)
#define CSL_SMCP_SL2BNKMSK_BANK1_RESETVAL (0x00000001u)

#define CSL_SMCP_SL2BNKMSK_BANK0_MASK    (0x00000001u)
#define CSL_SMCP_SL2BNKMSK_BANK0_SHIFT   (0x00000000u)
#define CSL_SMCP_SL2BNKMSK_BANK0_RESETVAL (0x00000001u)

#define CSL_SMCP_SL2BNKMSK_RESETVAL      (0x0000000Fu)

/* SL2PWSCNT */

#define CSL_SMCP_SL2PWSCNT_WSCNT_MASK    (0xFFFFFFFFu)
#define CSL_SMCP_SL2PWSCNT_WSCNT_SHIFT   (0x00000000u)
#define CSL_SMCP_SL2PWSCNT_WSCNT_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2PWSCNT_RESETVAL      (0x00000000u)

/* SL2PFCCNT */

#define CSL_SMCP_SL2PFCCNT_PFCCNT_MASK   (0xFFFFFFFFu)
#define CSL_SMCP_SL2PFCCNT_PFCCNT_SHIFT  (0x00000000u)
#define CSL_SMCP_SL2PFCCNT_PFCCNT_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2PFCCNT_RESETVAL      (0x00000000u)

/* SL2PCMD */


#define CSL_SMCP_SL2PCMD_ENPROFILE_MASK  (0x00000002u)
#define CSL_SMCP_SL2PCMD_ENPROFILE_SHIFT (0x00000001u)
#define CSL_SMCP_SL2PCMD_ENPROFILE_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2PCMD_CLEAR_MASK      (0x00000001u)
#define CSL_SMCP_SL2PCMD_CLEAR_SHIFT     (0x00000000u)
#define CSL_SMCP_SL2PCMD_CLEAR_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PCMD_RESETVAL        (0x00000000u)

/* SL2PSTAT */


#define CSL_SMCP_SL2PSTAT_PSAT_MASK      (0x00000100u)
#define CSL_SMCP_SL2PSTAT_PSAT_SHIFT     (0x00000008u)
#define CSL_SMCP_SL2PSTAT_PSAT_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT7_MASK      (0x00000080u)
#define CSL_SMCP_SL2PSTAT_SAT7_SHIFT     (0x00000007u)
#define CSL_SMCP_SL2PSTAT_SAT7_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT6_MASK      (0x00000040u)
#define CSL_SMCP_SL2PSTAT_SAT6_SHIFT     (0x00000006u)
#define CSL_SMCP_SL2PSTAT_SAT6_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT5_MASK      (0x00000020u)
#define CSL_SMCP_SL2PSTAT_SAT5_SHIFT     (0x00000005u)
#define CSL_SMCP_SL2PSTAT_SAT5_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT4_MASK      (0x00000010u)
#define CSL_SMCP_SL2PSTAT_SAT4_SHIFT     (0x00000004u)
#define CSL_SMCP_SL2PSTAT_SAT4_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT3_MASK      (0x00000008u)
#define CSL_SMCP_SL2PSTAT_SAT3_SHIFT     (0x00000003u)
#define CSL_SMCP_SL2PSTAT_SAT3_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT2_MASK      (0x00000004u)
#define CSL_SMCP_SL2PSTAT_SAT2_SHIFT     (0x00000002u)
#define CSL_SMCP_SL2PSTAT_SAT2_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT1_MASK      (0x00000002u)
#define CSL_SMCP_SL2PSTAT_SAT1_SHIFT     (0x00000001u)
#define CSL_SMCP_SL2PSTAT_SAT1_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_SAT0_MASK      (0x00000001u)
#define CSL_SMCP_SL2PSTAT_SAT0_SHIFT     (0x00000000u)
#define CSL_SMCP_SL2PSTAT_SAT0_RESETVAL  (0x00000000u)

#define CSL_SMCP_SL2PSTAT_RESETVAL       (0x00000000u)

/* SL2STATMASK */


#define CSL_SMCP_SL2STATMASK_MASK_WS7_MASK (0x00000080u)
#define CSL_SMCP_SL2STATMASK_MASK_WS7_SHIFT (0x00000007u)
#define CSL_SMCP_SL2STATMASK_MASK_WS7_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS3_MASK (0x00000080u)
#define CSL_SMCP_SL2STATMASK_MASK_WS3_SHIFT (0x00000007u)
#define CSL_SMCP_SL2STATMASK_MASK_WS3_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS6_MASK (0x00000040u)
#define CSL_SMCP_SL2STATMASK_MASK_WS6_SHIFT (0x00000006u)
#define CSL_SMCP_SL2STATMASK_MASK_WS6_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS2_MASK (0x00000040u)
#define CSL_SMCP_SL2STATMASK_MASK_WS2_SHIFT (0x00000006u)
#define CSL_SMCP_SL2STATMASK_MASK_WS2_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS5_MASK (0x00000020u)
#define CSL_SMCP_SL2STATMASK_MASK_WS5_SHIFT (0x00000005u)
#define CSL_SMCP_SL2STATMASK_MASK_WS5_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS1_MASK (0x00000020u)
#define CSL_SMCP_SL2STATMASK_MASK_WS1_SHIFT (0x00000005u)
#define CSL_SMCP_SL2STATMASK_MASK_WS1_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS4_MASK (0x00000010u)
#define CSL_SMCP_SL2STATMASK_MASK_WS4_SHIFT (0x00000004u)
#define CSL_SMCP_SL2STATMASK_MASK_WS4_RESETVAL (0x00000000u)

#define CSL_SMCP_SL2STATMASK_MASK_WS0_MASK (0x00000010u)
#define CSL_SMCP_SL2STATMASK_MASK_WS0_SHIFT (0x00000004u)
#define CSL_SMCP_SL2STATMASK_MASK_WS0_RESETVAL (0x00000000u)


#define CSL_SMCP_SL2STATMASK_RESETVAL    (0x00000000u)

#endif
