/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_tsip.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for TSIP
 *  ============================================================================
 */
#ifndef _CSLR_TSIP_H_
#define _CSLR_TSIP_H_

#include <cslr.h>
#include "tistdtypes.h"

/* Minimum unit = 1 byte */
/**************************************************************************\
* Register Overlay Structure for ERR
\**************************************************************************/
typedef struct  {
    volatile Uint32 ERRCTL;
    volatile Uint32 ERRCNT;
    volatile Uint32 ERRQ;
    volatile Uint8 RSVD6[4];
} CSL_TsipErrRegs;

/**************************************************************************\
* Register Overlay Structure for XCHEN
\**************************************************************************/
typedef struct  {
    volatile Uint32 XCHEN;
    volatile Uint8 RSVD8[28];
} CSL_TsipXchenRegs;

/**************************************************************************\
* Register Overlay Structure for RCHEN
\**************************************************************************/
typedef struct  {
    volatile Uint32 RCHEN;
    volatile Uint8 RSVD10[28];
} CSL_TsipRchenRegs;

/**************************************************************************\
* Register Overlay Structure for DXCH
\**************************************************************************/
typedef struct  {
    volatile Uint32 ABASE;
    volatile Uint32 AFALLOC;
    volatile Uint32 AFSIZE;
    volatile Uint32 AFCNT;
    volatile Uint8 RSVD0[16];
    volatile Uint32 BBASE;
    volatile Uint32 BFALLOC;
    volatile Uint32 BFSIZE;
    volatile Uint32 BFCNT;
    volatile Uint8 RSVD12[16];
} CSL_TsipDxchRegs;

/**************************************************************************\
* Register Overlay Structure for DRCH
\**************************************************************************/
typedef struct  {
    volatile Uint32 ABASE;
    volatile Uint32 AFALLOC;
    volatile Uint32 AFSIZE;
    volatile Uint32 AFCNT;
    volatile Uint8 RSVD0[16];
    volatile Uint32 BBASE;
    volatile Uint32 BFALLOC;
    volatile Uint32 BFSIZE;
    volatile Uint32 BFCNT;
    volatile Uint8 RSVD14[16];
} CSL_TsipDrchRegs;

/**************************************************************************\
* Register Overlay Structure for XBM
\**************************************************************************/
typedef struct  {
    volatile Uint32 XBMA[64];
    volatile Uint32 XBMB[64];
} CSL_TsipXbmRegs;

/**************************************************************************\
* Register Overlay Structure for RBM
\**************************************************************************/
typedef struct  {
    volatile Uint32 RBMA[64];
    volatile Uint32 RBMB[64];
} CSL_TsipRbmRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 EMUTST;
    volatile Uint32 RST;
    volatile Uint8 RSVD0[116];
    volatile Uint32 SIUCTL;
    volatile Uint8 RSVD1[28];
    volatile Uint32 XCLK;
    volatile Uint32 XCTL;
    volatile Uint32 XSIZE;
    volatile Uint8 RSVD2[20];
    volatile Uint32 RCLK;
    volatile Uint32 RCTL;
    volatile Uint32 RSIZE;
    volatile Uint8 RSVD3[52];
    volatile Uint32 TDMUCTL;
    volatile Uint32 XFRFC;
    volatile Uint32 RFRFC;
    volatile Uint32 TDMUCFG;
    volatile Uint32 XBMST;
    volatile Uint32 RBMST;
    volatile Uint8 RSVD4[104];
    volatile Uint32 DMACTL;
    volatile Uint32 XDLY;
    volatile Uint32 RDLY;
    volatile Uint8 RSVD5[4];
    volatile Uint32 XCHST;
    volatile Uint32 RCHST;
    volatile Uint8 RSVD7[104];
    CSL_TsipErrRegs ERR[6];
    volatile Uint8 RSVD9[1440];
    CSL_TsipXchenRegs XCHEN[6];
    volatile Uint8 RSVD11[832];
    CSL_TsipRchenRegs RCHEN[6];
    volatile Uint8 RSVD13[832];
    CSL_TsipDxchRegs DXCH[6];
    volatile Uint8 RSVD15[1664];
    CSL_TsipDrchRegs DRCH[6];
    volatile Uint8 RSVD16[26240];
    CSL_TsipXbmRegs XBM[6];
    volatile Uint8 RSVD17[13312];
    CSL_TsipRbmRegs RBM[6];
    volatile Uint8 RSVD18[13312];
    volatile Uint32 XPING0;
    volatile Uint8 RSVD19[1020];
    volatile Uint32 XPONG0;
    volatile Uint8 RSVD20[1020];
    volatile Uint32 XPING1;
    volatile Uint8 RSVD21[1020];
    volatile Uint32 XPONG1;
    volatile Uint8 RSVD22[1020];
    volatile Uint32 XPING2;
    volatile Uint8 RSVD23[1020];
    volatile Uint32 XPONG2;
    volatile Uint8 RSVD24[1020];
    volatile Uint32 XPING3;
    volatile Uint8 RSVD25[1020];
    volatile Uint32 XPONG3;
    volatile Uint8 RSVD26[1020];
    volatile Uint32 XPING4;
    volatile Uint8 RSVD27[1020];
    volatile Uint32 XPONG4;
    volatile Uint8 RSVD28[1020];
    volatile Uint32 XPING5;
    volatile Uint8 RSVD29[1020];
    volatile Uint32 XPONG5;
    volatile Uint8 RSVD30[21500];
    volatile Uint32 RPING0;
    volatile Uint8 RSVD31[1020];
    volatile Uint32 RPONG0;
    volatile Uint8 RSVD32[1020];
    volatile Uint32 RPING1;
    volatile Uint8 RSVD33[1020];
    volatile Uint32 RPONG1;
    volatile Uint8 RSVD34[1020];
    volatile Uint32 RPING2;
    volatile Uint8 RSVD35[1020];
    volatile Uint32 RPONG2;
    volatile Uint8 RSVD36[1020];
    volatile Uint32 RPING3;
    volatile Uint8 RSVD37[1020];
    volatile Uint32 RPONG3;
    volatile Uint8 RSVD38[1020];
    volatile Uint32 RPING4;
    volatile Uint8 RSVD39[1020];
    volatile Uint32 RPONG4;
    volatile Uint8 RSVD40[1020];
    volatile Uint32 RPING5;
    volatile Uint8 RSVD41[1020];
    volatile Uint32 RPONG5;
} CSL_TsipRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_TsipRegs             *CSL_TsipRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* ERRCTL */

#define CSL_TSIP_ERRCTL_CLRQOV_MASK      (0x00000100u)
#define CSL_TSIP_ERRCTL_CLRQOV_SHIFT     (0x00000008u)
#define CSL_TSIP_ERRCTL_CLRQOV_RESETVAL  (0x00000000u)
/*----CLRQOV Tokens----*/
#define CSL_TSIP_ERRCTL_CLRQOV_CLR       (0x00000001u)


#define CSL_TSIP_ERRCTL_CLRQ_MASK        (0x00000002u)
#define CSL_TSIP_ERRCTL_CLRQ_SHIFT       (0x00000001u)
#define CSL_TSIP_ERRCTL_CLRQ_RESETVAL    (0x00000000u)
/*----CLRQ Tokens----*/
#define CSL_TSIP_ERRCTL_CLRQ_CLR         (0x00000001u)

#define CSL_TSIP_ERRCTL_POPQ_MASK        (0x00000001u)
#define CSL_TSIP_ERRCTL_POPQ_SHIFT       (0x00000000u)
#define CSL_TSIP_ERRCTL_POPQ_RESETVAL    (0x00000000u)
/*----POPQ Tokens----*/
#define CSL_TSIP_ERRCTL_POPQ_POP         (0x00000001u)

#define CSL_TSIP_ERRCTL_RESETVAL         (0x00000000u)

/* ERRCNT */

#define CSL_TSIP_ERRCNT_EQOV_MASK        (0x00000100u)
#define CSL_TSIP_ERRCNT_EQOV_SHIFT       (0x00000008u)
#define CSL_TSIP_ERRCNT_EQOV_RESETVAL    (0x00000000u)


#define CSL_TSIP_ERRCNT_ECNT_MASK        (0x0000001Fu)
#define CSL_TSIP_ERRCNT_ECNT_SHIFT       (0x00000000u)
#define CSL_TSIP_ERRCNT_ECNT_RESETVAL    (0x00000000u)

#define CSL_TSIP_ERRCNT_RESETVAL         (0x00000000u)

/* ERRQ */

#define CSL_TSIP_ERRQ_ERRC_MASK          (0xFF000000u)
#define CSL_TSIP_ERRQ_ERRC_SHIFT         (0x00000018u)
#define CSL_TSIP_ERRQ_ERRC_RESETVAL      (0x00000000u)

#define CSL_TSIP_ERRQ_INFO_MASK          (0x00FFFFFFu)
#define CSL_TSIP_ERRQ_INFO_SHIFT         (0x00000000u)
#define CSL_TSIP_ERRQ_INFO_RESETVAL      (0x00000000u)

#define CSL_TSIP_ERRQ_RESETVAL           (0x00000000u)

/* XCHEN */


#define CSL_TSIP_XCHEN_CID_MASK          (0x0000FF00u)
#define CSL_TSIP_XCHEN_CID_SHIFT         (0x00000008u)
#define CSL_TSIP_XCHEN_CID_RESETVAL      (0x00000000u)


#define CSL_TSIP_XCHEN_CHENB_MASK        (0x00000001u)
#define CSL_TSIP_XCHEN_CHENB_SHIFT       (0x00000000u)
#define CSL_TSIP_XCHEN_CHENB_RESETVAL    (0x00000000u)
/*----CHENB Tokens----*/
#define CSL_TSIP_XCHEN_CHENB_ENB         (0x00000001u)
#define CSL_TSIP_XCHEN_CHENB_DIS         (0x00000000u)

#define CSL_TSIP_XCHEN_RESETVAL          (0x00000000u)

/* RCHEN */


#define CSL_TSIP_RCHEN_CID_MASK          (0x0000FF00u)
#define CSL_TSIP_RCHEN_CID_SHIFT         (0x00000008u)
#define CSL_TSIP_RCHEN_CID_RESETVAL      (0x00000000u)


#define CSL_TSIP_RCHEN_CHENB_MASK        (0x00000001u)
#define CSL_TSIP_RCHEN_CHENB_SHIFT       (0x00000000u)
#define CSL_TSIP_RCHEN_CHENB_RESETVAL    (0x00000000u)
/*----CHENB Tokens----*/
#define CSL_TSIP_RCHEN_CHENB_ENB         (0x00000001u)
#define CSL_TSIP_RCHEN_CHENB_DIS         (0x00000000u)

#define CSL_TSIP_RCHEN_RESETVAL          (0x00000000u)

/* ABASE */

#define CSL_TSIP_ABASE_BADDR_MASK        (0xFFFFFFFFu)
#define CSL_TSIP_ABASE_BADDR_SHIFT       (0x00000000u)
#define CSL_TSIP_ABASE_BADDR_RESETVAL    (0x00000000u)

#define CSL_TSIP_ABASE_RESETVAL          (0x00000000u)

/* AFALLOC */


#define CSL_TSIP_AFALLOC_FALLOC_MASK     (0x00000FFFu)
#define CSL_TSIP_AFALLOC_FALLOC_SHIFT    (0x00000000u)
#define CSL_TSIP_AFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_AFALLOC_RESETVAL        (0x00000000u)

/* AFSIZE */


#define CSL_TSIP_AFSIZE_FSIZE_MASK       (0x00000FFFu)
#define CSL_TSIP_AFSIZE_FSIZE_SHIFT      (0x00000000u)
#define CSL_TSIP_AFSIZE_FSIZE_RESETVAL   (0x00000000u)

#define CSL_TSIP_AFSIZE_RESETVAL         (0x00000000u)

/* AFCNT */

#define CSL_TSIP_AFCNT_FCOUNT_MASK       (0x000000FFu)
#define CSL_TSIP_AFCNT_FCOUNT_SHIFT      (0x00000000u)
#define CSL_TSIP_AFCNT_FCOUNT_RESETVAL   (0x00000000u)

#define CSL_TSIP_AFCNT_RESETVAL          (0x00000000u)

/* BBASE */

#define CSL_TSIP_BBASE_BADDR_MASK        (0xFFFFFFFFu)
#define CSL_TSIP_BBASE_BADDR_SHIFT       (0x00000000u)
#define CSL_TSIP_BBASE_BADDR_RESETVAL    (0x00000000u)

#define CSL_TSIP_BBASE_RESETVAL          (0x00000000u)

/* BFALLOC */


#define CSL_TSIP_BFALLOC_FALLOC_MASK     (0x00000FFFu)
#define CSL_TSIP_BFALLOC_FALLOC_SHIFT    (0x00000000u)
#define CSL_TSIP_BFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_BFALLOC_RESETVAL        (0x00000000u)

/* BFSIZE */


#define CSL_TSIP_BFSIZE_FSIZE_MASK       (0x00000FFFu)
#define CSL_TSIP_BFSIZE_FSIZE_SHIFT      (0x00000000u)
#define CSL_TSIP_BFSIZE_FSIZE_RESETVAL   (0x00000000u)

#define CSL_TSIP_BFSIZE_RESETVAL         (0x00000000u)

/* BFCNT */

#define CSL_TSIP_BFCNT_FCOUNT_MASK       (0x000000FFu)
#define CSL_TSIP_BFCNT_FCOUNT_SHIFT      (0x00000000u)
#define CSL_TSIP_BFCNT_FCOUNT_RESETVAL   (0x00000000u)

#define CSL_TSIP_BFCNT_RESETVAL          (0x00000000u)

/* ABASE */

#define CSL_TSIP_ABASE_BADDR_MASK        (0xFFFFFFFFu)
#define CSL_TSIP_ABASE_BADDR_SHIFT       (0x00000000u)
#define CSL_TSIP_ABASE_BADDR_RESETVAL    (0x00000000u)

#define CSL_TSIP_ABASE_RESETVAL          (0x00000000u)

/* AFALLOC */


#define CSL_TSIP_AFALLOC_FALLOC_MASK     (0x00000FFFu)
#define CSL_TSIP_AFALLOC_FALLOC_SHIFT    (0x00000000u)
#define CSL_TSIP_AFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_AFALLOC_RESETVAL        (0x00000000u)

/* AFSIZE */


#define CSL_TSIP_AFSIZE_FSIZE_MASK       (0x00000FFFu)
#define CSL_TSIP_AFSIZE_FSIZE_SHIFT      (0x00000000u)
#define CSL_TSIP_AFSIZE_FSIZE_RESETVAL   (0x00000000u)

#define CSL_TSIP_AFSIZE_RESETVAL         (0x00000000u)

/* AFCNT */

#define CSL_TSIP_AFCNT_FCOUNT_MASK       (0x000000FFu)
#define CSL_TSIP_AFCNT_FCOUNT_SHIFT      (0x00000000u)
#define CSL_TSIP_AFCNT_FCOUNT_RESETVAL   (0x00000000u)

#define CSL_TSIP_AFCNT_RESETVAL          (0x00000000u)

/* BBASE */

#define CSL_TSIP_BBASE_BADDR_MASK        (0xFFFFFFFFu)
#define CSL_TSIP_BBASE_BADDR_SHIFT       (0x00000000u)
#define CSL_TSIP_BBASE_BADDR_RESETVAL    (0x00000000u)

#define CSL_TSIP_BBASE_RESETVAL          (0x00000000u)

/* BFALLOC */


#define CSL_TSIP_BFALLOC_FALLOC_MASK     (0x00000FFFu)
#define CSL_TSIP_BFALLOC_FALLOC_SHIFT    (0x00000000u)
#define CSL_TSIP_BFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_BFALLOC_RESETVAL        (0x00000000u)

/* BFSIZE */


#define CSL_TSIP_BFSIZE_FSIZE_MASK       (0x00000FFFu)
#define CSL_TSIP_BFSIZE_FSIZE_SHIFT      (0x00000000u)
#define CSL_TSIP_BFSIZE_FSIZE_RESETVAL   (0x00000000u)

#define CSL_TSIP_BFSIZE_RESETVAL         (0x00000000u)

/* BFCNT */

#define CSL_TSIP_BFCNT_FCOUNT_MASK       (0x000000FFu)
#define CSL_TSIP_BFCNT_FCOUNT_SHIFT      (0x00000000u)
#define CSL_TSIP_BFCNT_FCOUNT_RESETVAL   (0x00000000u)

#define CSL_TSIP_BFCNT_RESETVAL          (0x00000000u)

/* XBMA */

#define CSL_TSIP_XBMA_CH_MASK            (0xFFFFFFFFu)
#define CSL_TSIP_XBMA_CH_SHIFT           (0x00000000u)
#define CSL_TSIP_XBMA_CH_RESETVAL        (0x00000000u)

#define CSL_TSIP_XBMA_RESETVAL           (0x00000000u)

/* XBMB */

#define CSL_TSIP_XBMB_CH_MASK            (0xFFFFFFFFu)
#define CSL_TSIP_XBMB_CH_SHIFT           (0x00000000u)
#define CSL_TSIP_XBMB_CH_RESETVAL        (0x00000000u)

#define CSL_TSIP_XBMB_RESETVAL           (0x00000000u)

/* RBMA */

#define CSL_TSIP_RBMA_CH_MASK            (0xFFFFFFFFu)
#define CSL_TSIP_RBMA_CH_SHIFT           (0x00000000u)
#define CSL_TSIP_RBMA_CH_RESETVAL        (0x00000000u)

#define CSL_TSIP_RBMA_RESETVAL           (0x00000000u)

/* RBMB */

#define CSL_TSIP_RBMB_CH_MASK            (0xFFFFFFFFu)
#define CSL_TSIP_RBMB_CH_SHIFT           (0x00000000u)
#define CSL_TSIP_RBMB_CH_RESETVAL        (0x00000000u)

#define CSL_TSIP_RBMB_RESETVAL           (0x00000000u)

/* PID */

#define CSL_TSIP_PID_MODID_MASK          (0xFFFF0000u)
#define CSL_TSIP_PID_MODID_SHIFT         (0x00000010u)
#define CSL_TSIP_PID_MODID_RESETVAL      (0x00000060u)

#define CSL_TSIP_PID_MAJOR_MASK          (0x0000FF00u)
#define CSL_TSIP_PID_MAJOR_SHIFT         (0x00000008u)
#define CSL_TSIP_PID_MAJOR_RESETVAL      (0x00000001u)

#define CSL_TSIP_PID_MINOR_MASK          (0x000000FFu)
#define CSL_TSIP_PID_MINOR_SHIFT         (0x00000000u)
#define CSL_TSIP_PID_MINOR_RESETVAL      (0x00000000u)

#define CSL_TSIP_PID_RESETVAL            (0x00600100u)

/* EMUTST */


#define CSL_TSIP_EMUTST_TSTDIV_MASK      (0x01F00000u)
#define CSL_TSIP_EMUTST_TSTDIV_SHIFT     (0x00000014u)
#define CSL_TSIP_EMUTST_TSTDIV_RESETVAL  (0x00000000u)

#define CSL_TSIP_EMUTST_TSTCLK_MASK      (0x00080000u)
#define CSL_TSIP_EMUTST_TSTCLK_SHIFT     (0x00000013u)
#define CSL_TSIP_EMUTST_TSTCLK_RESETVAL  (0x00000000u)
/*----TSTCLK Tokens----*/
#define CSL_TSIP_EMUTST_TSTCLK_EXTERNAL  (0x00000000u)
#define CSL_TSIP_EMUTST_TSTCLK_INTERNAL  (0x00000001u)

#define CSL_TSIP_EMUTST_IOLB_MASK        (0x00040000u)
#define CSL_TSIP_EMUTST_IOLB_SHIFT       (0x00000012u)
#define CSL_TSIP_EMUTST_IOLB_RESETVAL    (0x00000000u)
/*----IOLB Tokens----*/
#define CSL_TSIP_EMUTST_IOLB_INTERNAL_DLB (0x00000000u)
#define CSL_TSIP_EMUTST_IOLB_IO_BUF_DLB  (0x00000001u)

#define CSL_TSIP_EMUTST_LBS_MASK         (0x00020000u)
#define CSL_TSIP_EMUTST_LBS_SHIFT        (0x00000011u)
#define CSL_TSIP_EMUTST_LBS_RESETVAL     (0x00000000u)
/*----LBS Tokens----*/
#define CSL_TSIP_EMUTST_LBS_DLB          (0x00000000u)
#define CSL_TSIP_EMUTST_LBS_LLB          (0x00000001u)

#define CSL_TSIP_EMUTST_SIUTST_MASK      (0x00010000u)
#define CSL_TSIP_EMUTST_SIUTST_SHIFT     (0x00000010u)
#define CSL_TSIP_EMUTST_SIUTST_RESETVAL  (0x00000000u)
/*----SIUTST Tokens----*/
#define CSL_TSIP_EMUTST_SIUTST_NORMAL_MODE (0x00000000u)
#define CSL_TSIP_EMUTST_SIUTST_LOOPBACK_MODE (0x00000001u)

#define CSL_TSIP_EMUTST_TSTKEY_MASK      (0x0000FF00u)
#define CSL_TSIP_EMUTST_TSTKEY_SHIFT     (0x00000008u)
#define CSL_TSIP_EMUTST_TSTKEY_RESETVAL  (0x00000000u)


#define CSL_TSIP_EMUTST_SOFT_MASK        (0x00000002u)
#define CSL_TSIP_EMUTST_SOFT_SHIFT       (0x00000001u)
#define CSL_TSIP_EMUTST_SOFT_RESETVAL    (0x00000001u)
/*----SOFT Tokens----*/
#define CSL_TSIP_EMUTST_SOFT_DISABLE     (0x00000000u)
#define CSL_TSIP_EMUTST_SOFT_ENABLE      (0x00000001u)

#define CSL_TSIP_EMUTST_FREE_MASK        (0x00000001u)
#define CSL_TSIP_EMUTST_FREE_SHIFT       (0x00000000u)
#define CSL_TSIP_EMUTST_FREE_RESETVAL    (0x00000001u)
/*----FREE Tokens----*/
#define CSL_TSIP_EMUTST_FREE_DISABLE     (0x00000000u)
#define CSL_TSIP_EMUTST_FREE_ENABLE      (0x00000001u)

#define CSL_TSIP_EMUTST_RESETVAL         (0x00000003u)

/* RST */


#define CSL_TSIP_RST_DMARST_MASK         (0x00000002u)
#define CSL_TSIP_RST_DMARST_SHIFT        (0x00000001u)
#define CSL_TSIP_RST_DMARST_RESETVAL     (0x00000000u)
/*----DMARST Tokens----*/
#define CSL_TSIP_RST_DMARST_RST          (0x00000001u)

#define CSL_TSIP_RST_SIURST_MASK         (0x00000001u)
#define CSL_TSIP_RST_SIURST_SHIFT        (0x00000000u)
#define CSL_TSIP_RST_SIURST_RESETVAL     (0x00000000u)
/*----SIURST Tokens----*/
#define CSL_TSIP_RST_SIURST_RST          (0x00000001u)

#define CSL_TSIP_RST_RESETVAL            (0x00000000u)

/* SIUCTL */

#define CSL_TSIP_SIUCTL_CLKD_MASK        (0x00000010u)
#define CSL_TSIP_SIUCTL_CLKD_SHIFT       (0x00000004u)
#define CSL_TSIP_SIUCTL_CLKD_RESETVAL    (0x00000000u)
/*----CLKD Tokens----*/
#define CSL_TSIP_SIUCTL_CLKD_REDUN       (0x00000000u)
#define CSL_TSIP_SIUCTL_CLKD_DUAL        (0x00000001u)


#define CSL_TSIP_SIUCTL_RCVENB_MASK      (0x00000002u)
#define CSL_TSIP_SIUCTL_RCVENB_SHIFT     (0x00000001u)
#define CSL_TSIP_SIUCTL_RCVENB_RESETVAL  (0x00000000u)
/*----RCVENB Tokens----*/
#define CSL_TSIP_SIUCTL_RCVENB_ENABLE    (0x00000001u)
#define CSL_TSIP_SIUCTL_RCVENB_DISABLE   (0x00000000u)

#define CSL_TSIP_SIUCTL_XMTENB_MASK      (0x00000001u)
#define CSL_TSIP_SIUCTL_XMTENB_SHIFT     (0x00000000u)
#define CSL_TSIP_SIUCTL_XMTENB_RESETVAL  (0x00000000u)
/*----XMTENB Tokens----*/
#define CSL_TSIP_SIUCTL_XMTENB_ENABLE    (0x00000001u)
#define CSL_TSIP_SIUCTL_XMTENB_DISABLE   (0x00000000u)

#define CSL_TSIP_SIUCTL_RESETVAL         (0x00000000u)

/* XCLK */


#define CSL_TSIP_XCLK_XMTSRC_MASK        (0x00000001u)
#define CSL_TSIP_XCLK_XMTSRC_SHIFT       (0x00000000u)
#define CSL_TSIP_XCLK_XMTSRC_RESETVAL    (0x00000000u)
/*----XMTSRC Tokens----*/
#define CSL_TSIP_XCLK_XMTSRC_ACLK        (0x00000000u)
#define CSL_TSIP_XCLK_XMTSRC_BCLK        (0x00000001u)

#define CSL_TSIP_XCLK_RESETVAL           (0x00000000u)

/* XCTL */


#define CSL_TSIP_XCTL_DATD_MASK          (0x3FFF0000u)
#define CSL_TSIP_XCTL_DATD_SHIFT         (0x00000010u)
#define CSL_TSIP_XCTL_DATD_RESETVAL      (0x00000000u)

#define CSL_TSIP_XCTL_DIS_MASK           (0x00000300u)
#define CSL_TSIP_XCTL_DIS_SHIFT          (0x00000008u)
#define CSL_TSIP_XCTL_DIS_RESETVAL       (0x00000000u)
/*----DIS Tokens----*/
#define CSL_TSIP_XCTL_DIS_HIMPED         (0x00000000u)
#define CSL_TSIP_XCTL_DIS_LOW            (0x00000002u)
#define CSL_TSIP_XCTL_DIS_HIGH           (0x00000003u)

#define CSL_TSIP_XCTL_FSYNCP_MASK        (0x00000080u)
#define CSL_TSIP_XCTL_FSYNCP_SHIFT       (0x00000007u)
#define CSL_TSIP_XCTL_FSYNCP_RESETVAL    (0x00000000u)
/*----FSYNCP Tokens----*/
#define CSL_TSIP_XCTL_FSYNCP_ALOW        (0x00000000u)
#define CSL_TSIP_XCTL_FSYNCP_AHIGH       (0x00000001u)

#define CSL_TSIP_XCTL_FCLKP_MASK         (0x00000040u)
#define CSL_TSIP_XCTL_FCLKP_SHIFT        (0x00000006u)
#define CSL_TSIP_XCTL_FCLKP_RESETVAL     (0x00000000u)
/*----FCLKP Tokens----*/
#define CSL_TSIP_XCTL_FCLKP_RISING       (0x00000000u)
#define CSL_TSIP_XCTL_FCLKP_FALLING      (0x00000001u)

#define CSL_TSIP_XCTL_DCLKP_MASK         (0x00000020u)
#define CSL_TSIP_XCTL_DCLKP_SHIFT        (0x00000005u)
#define CSL_TSIP_XCTL_DCLKP_RESETVAL     (0x00000000u)
/*----DCLKP Tokens----*/
#define CSL_TSIP_XCTL_DCLKP_RISING       (0x00000000u)
#define CSL_TSIP_XCTL_DCLKP_FALLING      (0x00000001u)


#define CSL_TSIP_XCTL_DATR_MASK          (0x00000006u)
#define CSL_TSIP_XCTL_DATR_SHIFT         (0x00000001u)
#define CSL_TSIP_XCTL_DATR_RESETVAL      (0x00000000u)
/*----DATR Tokens----*/
#define CSL_TSIP_XCTL_DATR_8M            (0x00000000u)
#define CSL_TSIP_XCTL_DATR_16M           (0x00000001u)
#define CSL_TSIP_XCTL_DATR_32M           (0x00000002u)

#define CSL_TSIP_XCTL_CLKM_MASK          (0x00000001u)
#define CSL_TSIP_XCTL_CLKM_SHIFT         (0x00000000u)
#define CSL_TSIP_XCTL_CLKM_RESETVAL      (0x00000000u)
/*----CLKM Tokens----*/
#define CSL_TSIP_XCTL_CLKM_DBL           (0x00000000u)
#define CSL_TSIP_XCTL_CLKM_SGL           (0x00000001u)

#define CSL_TSIP_XCTL_RESETVAL           (0x00000000u)

/* XSIZE */
#define CSL_TSIP_XSIZE_FCNT_MASK         (0x00FF0000u)
#define CSL_TSIP_XSIZE_FCNT_SHIFT        (0x00000010u)
#define CSL_TSIP_XSIZE_FCNT_RESETVAL     (0x00000003u)

#define CSL_TSIP_XSIZE_FSIZ_MASK         (0x0000007Fu)
#define CSL_TSIP_XSIZE_FSIZ_SHIFT        (0x00000000u)
#define CSL_TSIP_XSIZE_FSIZ_RESETVAL     (0x0000007Fu)

#define CSL_TSIP_XSIZE_RESETVAL          (0x0003007Fu)

/* RCLK */


#define CSL_TSIP_RCLK_SRC_MASK           (0x00000001u)
#define CSL_TSIP_RCLK_SRC_SHIFT          (0x00000000u)
#define CSL_TSIP_RCLK_SRC_RESETVAL       (0x00000000u)
/*----SRC Tokens----*/
#define CSL_TSIP_RCLK_SRC_ACLK           (0x00000000u)
#define CSL_TSIP_RCLK_SRC_BCLK           (0x00000001u)

#define CSL_TSIP_RCLK_RESETVAL           (0x00000000u)

/* RCTL */


#define CSL_TSIP_RCTL_DATD_MASK          (0x3FFF0000u)
#define CSL_TSIP_RCTL_DATD_SHIFT         (0x00000010u)
#define CSL_TSIP_RCTL_DATD_RESETVAL      (0x00000000u)

#define CSL_TSIP_RCTL_FSYNCP_MASK        (0x00000080u)
#define CSL_TSIP_RCTL_FSYNCP_SHIFT       (0x00000007u)
#define CSL_TSIP_RCTL_FSYNCP_RESETVAL    (0x00000000u)
/*----FSYNCP Tokens----*/
#define CSL_TSIP_RCTL_FSYNCP_ALOW        (0x00000000u)
#define CSL_TSIP_RCTL_FSYNCP_AHIGH       (0x00000001u)

#define CSL_TSIP_RCTL_FCLKP_MASK         (0x00000040u)
#define CSL_TSIP_RCTL_FCLKP_SHIFT        (0x00000006u)
#define CSL_TSIP_RCTL_FCLKP_RESETVAL     (0x00000000u)
/*----FCLKP Tokens----*/
#define CSL_TSIP_RCTL_FCLKP_RISING       (0x00000000u)
#define CSL_TSIP_RCTL_FCLKP_FALLING      (0x00000001u)

#define CSL_TSIP_RCTL_DCLKP_MASK         (0x00000020u)
#define CSL_TSIP_RCTL_DCLKP_SHIFT        (0x00000005u)
#define CSL_TSIP_RCTL_DCLKP_RESETVAL     (0x00000000u)
/*----DCLKP Tokens----*/
#define CSL_TSIP_RCTL_DCLKP_RISING       (0x00000000u)
#define CSL_TSIP_RCTL_DCLKP_FALLING      (0x00000001u)


#define CSL_TSIP_RCTL_DATR_MASK          (0x00000006u)
#define CSL_TSIP_RCTL_DATR_SHIFT         (0x00000001u)
#define CSL_TSIP_RCTL_DATR_RESETVAL      (0x00000000u)
/*----DATR Tokens----*/
#define CSL_TSIP_RCTL_DATR_8M            (0x00000000u)
#define CSL_TSIP_RCTL_DATR_16M           (0x00000001u)
#define CSL_TSIP_RCTL_DATR_32M           (0x00000002u)

#define CSL_TSIP_RCTL_CLKM_MASK          (0x00000001u)
#define CSL_TSIP_RCTL_CLKM_SHIFT         (0x00000000u)
#define CSL_TSIP_RCTL_CLKM_RESETVAL      (0x00000000u)
/*----CLKM Tokens----*/
#define CSL_TSIP_RCTL_CLKM_DBL           (0x00000000u)
#define CSL_TSIP_RCTL_CLKM_SGL           (0x00000001u)

#define CSL_TSIP_RCTL_RESETVAL           (0x00000000u)

/* RSIZE */


#define CSL_TSIP_RSIZE_FCNT_MASK         (0x00FF0000u)
#define CSL_TSIP_RSIZE_FCNT_SHIFT        (0x00000010u)
#define CSL_TSIP_RSIZE_FCNT_RESETVAL     (0x00000003u)

#define CSL_TSIP_RSIZE_FSIZ_MASK         (0x0000007Fu)
#define CSL_TSIP_RSIZE_FSIZ_SHIFT        (0x00000000u)
#define CSL_TSIP_RSIZE_FSIZ_RESETVAL     (0x0000007Fu)

#define CSL_TSIP_RSIZE_RESETVAL          (0x0003007Fu)

/* TDMUCTL */


#define CSL_TSIP_TDMUCTL_DMAENB_MASK     (0x00000001u)
#define CSL_TSIP_TDMUCTL_DMAENB_SHIFT    (0x00000000u)
#define CSL_TSIP_TDMUCTL_DMAENB_RESETVAL (0x00000000u)
/*----DMAENB Tokens----*/
#define CSL_TSIP_TDMUCTL_DMAENB_ENB      (0x00000001u)
#define CSL_TSIP_TDMUCTL_DMAENB_DIS      (0x00000000u)

#define CSL_TSIP_TDMUCTL_RESETVAL        (0x00000000u)

/* XFRFC */


#define CSL_TSIP_XFRFC_FRFC_MASK         (0x00FFFFFFu)
#define CSL_TSIP_XFRFC_FRFC_SHIFT        (0x00000000u)
#define CSL_TSIP_XFRFC_FRFC_RESETVAL     (0x00000000u)

#define CSL_TSIP_XFRFC_RESETVAL          (0x00000000u)

/* RFRFC */


#define CSL_TSIP_RFRFC_FRFC_MASK         (0x00FFFFFFu)
#define CSL_TSIP_RFRFC_FRFC_SHIFT        (0x00000000u)
#define CSL_TSIP_RFRFC_FRFC_RESETVAL     (0x00000000u)

#define CSL_TSIP_RFRFC_RESETVAL          (0x00000000u)

/* TDMUCFG */


#define CSL_TSIP_TDMUCFG_BEND_MASK       (0x00000001u)
#define CSL_TSIP_TDMUCFG_BEND_SHIFT      (0x00000000u)
#define CSL_TSIP_TDMUCFG_BEND_RESETVAL   (0x00000000u)
/*----BEND Tokens----*/
#define CSL_TSIP_TDMUCFG_BEND_LITTLE     (0x00000000u)
#define CSL_TSIP_TDMUCFG_BEND_BIG        (0x00000001u)

#define CSL_TSIP_TDMUCFG_RESETVAL        (0x00000000u)

/* XBMST */


#define CSL_TSIP_XBMST_CH5BMS_MASK       (0x00000C00u)
#define CSL_TSIP_XBMST_CH5BMS_SHIFT      (0x0000000Au)
#define CSL_TSIP_XBMST_CH5BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_CH4BMS_MASK       (0x00000300u)
#define CSL_TSIP_XBMST_CH4BMS_SHIFT      (0x00000008u)
#define CSL_TSIP_XBMST_CH4BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_CH3BMS_MASK       (0x000000C0u)
#define CSL_TSIP_XBMST_CH3BMS_SHIFT      (0x00000006u)
#define CSL_TSIP_XBMST_CH3BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_CH2BMS_MASK       (0x00000030u)
#define CSL_TSIP_XBMST_CH2BMS_SHIFT      (0x00000004u)
#define CSL_TSIP_XBMST_CH2BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_CH1BMS_MASK       (0x0000000Cu)
#define CSL_TSIP_XBMST_CH1BMS_SHIFT      (0x00000002u)
#define CSL_TSIP_XBMST_CH1BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_CH0BMS_MASK       (0x00000003u)
#define CSL_TSIP_XBMST_CH0BMS_SHIFT      (0x00000000u)
#define CSL_TSIP_XBMST_CH0BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_XBMST_RESETVAL          (0x00000000u)

/* RBMST */


#define CSL_TSIP_RBMST_CH5BMS_MASK       (0x00000C00u)
#define CSL_TSIP_RBMST_CH5BMS_SHIFT      (0x0000000Au)
#define CSL_TSIP_RBMST_CH5BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_CH4BMS_MASK       (0x00000300u)
#define CSL_TSIP_RBMST_CH4BMS_SHIFT      (0x00000008u)
#define CSL_TSIP_RBMST_CH4BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_CH3BMS_MASK       (0x000000C0u)
#define CSL_TSIP_RBMST_CH3BMS_SHIFT      (0x00000006u)
#define CSL_TSIP_RBMST_CH3BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_CH2BMS_MASK       (0x00000030u)
#define CSL_TSIP_RBMST_CH2BMS_SHIFT      (0x00000004u)
#define CSL_TSIP_RBMST_CH2BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_CH1BMS_MASK       (0x0000000Cu)
#define CSL_TSIP_RBMST_CH1BMS_SHIFT      (0x00000002u)
#define CSL_TSIP_RBMST_CH1BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_CH0BMS_MASK       (0x00000003u)
#define CSL_TSIP_RBMST_CH0BMS_SHIFT      (0x00000000u)
#define CSL_TSIP_RBMST_CH0BMS_RESETVAL   (0x00000000u)

#define CSL_TSIP_RBMST_RESETVAL          (0x00000000u)

/* DMACTL */

#define CSL_TSIP_DMACTL_MAXPRI_MASK      (0x00000070u)
#define CSL_TSIP_DMACTL_MAXPRI_SHIFT     (0x00000004u)
#define CSL_TSIP_DMACTL_MAXPRI_RESETVAL  (0x00000007u)


#define CSL_TSIP_DMACTL_PRI_MASK         (0x00000007u)
#define CSL_TSIP_DMACTL_PRI_SHIFT        (0x00000000u)
#define CSL_TSIP_DMACTL_PRI_RESETVAL     (0x00000007u)

#define CSL_TSIP_DMACTL_RESETVAL         (0x00000077u)

/* XDLY */


#define CSL_TSIP_XDLY_SFINT_MASK         (0x0000C000u)
#define CSL_TSIP_XDLY_SFINT_SHIFT        (0x0000000Eu)
#define CSL_TSIP_XDLY_SFINT_RESETVAL     (0x00000000u)
/*----SFINT Tokens----*/
#define CSL_TSIP_XDLY_SFINT_ACK          (0x00000000u)
#define CSL_TSIP_XDLY_SFINT_DLY          (0x00000001u)
#define CSL_TSIP_XDLY_SFINT_ACKORDLY     (0x00000002u)
#define CSL_TSIP_XDLY_SFINT_ACKNDLY      (0x00000003u)

#define CSL_TSIP_XDLY_FRINT_MASK         (0x00003000u)
#define CSL_TSIP_XDLY_FRINT_SHIFT        (0x0000000Cu)
#define CSL_TSIP_XDLY_FRINT_RESETVAL     (0x00000000u)
/*----FRINT Tokens----*/
#define CSL_TSIP_XDLY_FRINT_ACK          (0x00000000u)
#define CSL_TSIP_XDLY_FRINT_DLY          (0x00000001u)
#define CSL_TSIP_XDLY_FRINT_ACKORDLY     (0x00000002u)
#define CSL_TSIP_XDLY_FRINT_ACKNDLY      (0x00000003u)

#define CSL_TSIP_XDLY_FDLY_MASK          (0x0000007Fu)
#define CSL_TSIP_XDLY_FDLY_SHIFT         (0x00000000u)
#define CSL_TSIP_XDLY_FDLY_RESETVAL      (0x0000007Fu)

#define CSL_TSIP_XDLY_RESETVAL           (0x0000007Fu)

/* RDLY */


#define CSL_TSIP_RDLY_SFINT_MASK         (0x0000C000u)
#define CSL_TSIP_RDLY_SFINT_SHIFT        (0x0000000Eu)
#define CSL_TSIP_RDLY_SFINT_RESETVAL     (0x00000000u)
/*----SFINT Tokens----*/
#define CSL_TSIP_RDLY_SFINT_ACK          (0x00000000u)
#define CSL_TSIP_RDLY_SFINT_DLY          (0x00000001u)
#define CSL_TSIP_RDLY_SFINT_ACKORDLY     (0x00000002u)
#define CSL_TSIP_RDLY_SFINT_ACKNDLY      (0x00000003u)

#define CSL_TSIP_RDLY_FRINT_MASK         (0x00003000u)
#define CSL_TSIP_RDLY_FRINT_SHIFT        (0x0000000Cu)
#define CSL_TSIP_RDLY_FRINT_RESETVAL     (0x00000000u)
/*----FRINT Tokens----*/
#define CSL_TSIP_RDLY_FRINT_ACK          (0x00000000u)
#define CSL_TSIP_RDLY_FRINT_DLY          (0x00000001u)
#define CSL_TSIP_RDLY_FRINT_ACKORDLY     (0x00000002u)
#define CSL_TSIP_RDLY_FRINT_ACKNDLY      (0x00000003u)

#define CSL_TSIP_RDLY_FDLY_MASK          (0x0000007Fu)
#define CSL_TSIP_RDLY_FDLY_SHIFT         (0x00000000u)
#define CSL_TSIP_RDLY_FDLY_RESETVAL      (0x0000007Fu)

#define CSL_TSIP_RDLY_RESETVAL           (0x0000007Fu)

/* XCHST */


#define CSL_TSIP_XCHST_CH5CS_MASK        (0x00000C00u)
#define CSL_TSIP_XCHST_CH5CS_SHIFT       (0x0000000Au)
#define CSL_TSIP_XCHST_CH5CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_CH4CS_MASK        (0x00000300u)
#define CSL_TSIP_XCHST_CH4CS_SHIFT       (0x00000008u)
#define CSL_TSIP_XCHST_CH4CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_CH3CS_MASK        (0x000000C0u)
#define CSL_TSIP_XCHST_CH3CS_SHIFT       (0x00000006u)
#define CSL_TSIP_XCHST_CH3CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_CH2CS_MASK        (0x00000030u)
#define CSL_TSIP_XCHST_CH2CS_SHIFT       (0x00000004u)
#define CSL_TSIP_XCHST_CH2CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_CH1CS_MASK        (0x0000000Cu)
#define CSL_TSIP_XCHST_CH1CS_SHIFT       (0x00000002u)
#define CSL_TSIP_XCHST_CH1CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_CH0CS_MASK        (0x00000003u)
#define CSL_TSIP_XCHST_CH0CS_SHIFT       (0x00000000u)
#define CSL_TSIP_XCHST_CH0CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_XCHST_RESETVAL          (0x00000000u)

/* RCHST */


#define CSL_TSIP_RCHST_CH5CS_MASK        (0x00000C00u)
#define CSL_TSIP_RCHST_CH5CS_SHIFT       (0x0000000Au)
#define CSL_TSIP_RCHST_CH5CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_CH4CS_MASK        (0x00000300u)
#define CSL_TSIP_RCHST_CH4CS_SHIFT       (0x00000008u)
#define CSL_TSIP_RCHST_CH4CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_CH3CS_MASK        (0x000000C0u)
#define CSL_TSIP_RCHST_CH3CS_SHIFT       (0x00000006u)
#define CSL_TSIP_RCHST_CH3CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_CH2CS_MASK        (0x00000030u)
#define CSL_TSIP_RCHST_CH2CS_SHIFT       (0x00000004u)
#define CSL_TSIP_RCHST_CH2CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_CH1CS_MASK        (0x0000000Cu)
#define CSL_TSIP_RCHST_CH1CS_SHIFT       (0x00000002u)
#define CSL_TSIP_RCHST_CH1CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_CH0CS_MASK        (0x00000003u)
#define CSL_TSIP_RCHST_CH0CS_SHIFT       (0x00000000u)
#define CSL_TSIP_RCHST_CH0CS_RESETVAL    (0x00000000u)

#define CSL_TSIP_RCHST_RESETVAL          (0x00000000u)

/* XPING0 */

#define CSL_TSIP_XPING0_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING0_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING0_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING0_RESETVAL         (0x00000000u)

/* XPONG0 */

#define CSL_TSIP_XPONG0_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG0_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG0_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG0_RESETVAL         (0x00000000u)

/* XPING1 */

#define CSL_TSIP_XPING1_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING1_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING1_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING1_RESETVAL         (0x00000000u)

/* XPONG1 */

#define CSL_TSIP_XPONG1_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG1_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG1_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG1_RESETVAL         (0x00000000u)

/* XPING2 */

#define CSL_TSIP_XPING2_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING2_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING2_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING2_RESETVAL         (0x00000000u)

/* XPONG2 */

#define CSL_TSIP_XPONG2_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG2_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG2_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG2_RESETVAL         (0x00000000u)

/* XPING3 */

#define CSL_TSIP_XPING3_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING3_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING3_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING3_RESETVAL         (0x00000000u)

/* XPONG3 */

#define CSL_TSIP_XPONG3_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG3_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG3_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG3_RESETVAL         (0x00000000u)

/* XPING4 */

#define CSL_TSIP_XPING4_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING4_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING4_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING4_RESETVAL         (0x00000000u)

/* XPONG4 */

#define CSL_TSIP_XPONG4_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG4_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG4_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG4_RESETVAL         (0x00000000u)

/* XPING5 */

#define CSL_TSIP_XPING5_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPING5_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPING5_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPING5_RESETVAL         (0x00000000u)

/* XPONG5 */

#define CSL_TSIP_XPONG5_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_XPONG5_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_XPONG5_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_XPONG5_RESETVAL         (0x00000000u)

/* RPING0 */

#define CSL_TSIP_RPING0_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING0_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING0_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING0_RESETVAL         (0x00000000u)

/* RPONG0 */

#define CSL_TSIP_RPONG0_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG0_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG0_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG0_RESETVAL         (0x00000000u)

/* RPING1 */

#define CSL_TSIP_RPING1_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING1_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING1_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING1_RESETVAL         (0x00000000u)

/* RPONG1 */

#define CSL_TSIP_RPONG1_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG1_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG1_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG1_RESETVAL         (0x00000000u)

/* RPING2 */

#define CSL_TSIP_RPING2_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING2_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING2_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING2_RESETVAL         (0x00000000u)

/* RPONG2 */

#define CSL_TSIP_RPONG2_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG2_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG2_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG2_RESETVAL         (0x00000000u)

/* RPING3 */

#define CSL_TSIP_RPING3_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING3_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING3_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING3_RESETVAL         (0x00000000u)

/* RPONG3 */

#define CSL_TSIP_RPONG3_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG3_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG3_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG3_RESETVAL         (0x00000000u)

/* RPING4 */

#define CSL_TSIP_RPING4_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING4_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING4_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING4_RESETVAL         (0x00000000u)

/* RPONG4 */

#define CSL_TSIP_RPONG4_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG4_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG4_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG4_RESETVAL         (0x00000000u)

/* RPING5 */

#define CSL_TSIP_RPING5_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPING5_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPING5_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPING5_RESETVAL         (0x00000000u)

/* RPONG5 */

#define CSL_TSIP_RPONG5_DAT_MASK         (0xFFFFFFFFu)
#define CSL_TSIP_RPONG5_DAT_SHIFT        (0x00000000u)
#define CSL_TSIP_RPONG5_DAT_RESETVAL     (0x00000000u)

#define CSL_TSIP_RPONG5_RESETVAL         (0x00000000u)

#endif
