/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2002, 2003, 2004, 2005, 2006
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/** ============================================================================
 *   @file  cslr_utopia2.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for UTOPIA2
 *  ============================================================================
 */
#ifndef _CSLR_UTOPIA2_H_
#define _CSLR_UTOPIA2_H_

#include <cslr.h>
#include <tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 UCR;
    volatile Uint32 PDR;
    volatile Uint32 XCAPR;
    volatile Uint32 UIER;
    volatile Uint32 UIPR;
    volatile Uint32 CDR;
    volatile Uint32 EIER;
    volatile Uint32 EIPR;
    volatile Uint32 RMMR0;
    volatile Uint32 RMMR1;
    volatile Uint32 RMMR2;
    volatile Uint32 RMMR3;
    volatile Uint32 RMMR4;
    volatile Uint32 RMMR5;
    volatile Uint32 RMMR6;
    volatile Uint32 RMMR7;
    volatile Uint32 RRSR;
} CSL_Utopia2Regs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_Utopia2Regs             *CSL_Utopia2RegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* UCR */

#define CSL_UTOPIA2_UCR_BEND_MASK (0x80000000u)
#define CSL_UTOPIA2_UCR_BEND_SHIFT (0x0000001Fu)
#define CSL_UTOPIA2_UCR_BEND_RESETVAL (0x00000000u)
/*----BEND Tokens----*/
#define CSL_UTOPIA2_UCR_BEND_LITTLE (0x00000000u)
#define CSL_UTOPIA2_UCR_BEND_BIG (0x00000001u)


#define CSL_UTOPIA2_UCR_SLID_MASK (0x1F000000u)
#define CSL_UTOPIA2_UCR_SLID_SHIFT (0x00000018u)
#define CSL_UTOPIA2_UCR_SLID_RESETVAL (0x00000000u)


#define CSL_UTOPIA2_UCR_XUDC_MASK (0x003C0000u)
#define CSL_UTOPIA2_UCR_XUDC_SHIFT (0x00000012u)
#define CSL_UTOPIA2_UCR_XUDC_RESETVAL (0x00000000u)
/*----XUDC Tokens----*/
#define CSL_UTOPIA2_UCR_XUDC_STANDARD (0x00000000u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER1 (0x00000001u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER2 (0x00000002u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER3 (0x00000003u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER4 (0x00000004u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER5 (0x00000005u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER6 (0x00000006u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER7 (0x00000007u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER8 (0x00000008u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER9 (0x00000009u)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER10 (0x0000000Au)
#define CSL_UTOPIA2_UCR_XUDC_EXTRAHEADER11 (0x0000000Bu)


#define CSL_UTOPIA2_UCR_UXEN_MASK (0x00010000u)
#define CSL_UTOPIA2_UCR_UXEN_SHIFT (0x00000010u)
#define CSL_UTOPIA2_UCR_UXEN_RESETVAL (0x00000000u)
/*----UXEN Tokens----*/
#define CSL_UTOPIA2_UCR_UXEN_TX_PORT_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UCR_UXEN_TX_PORT_ENABLE (0x00000001u)


#define CSL_UTOPIA2_UCR_MPHY_MASK (0x00004000u)
#define CSL_UTOPIA2_UCR_MPHY_SHIFT (0x0000000Eu)
#define CSL_UTOPIA2_UCR_MPHY_RESETVAL (0x00000001u)
/*----MPHY Tokens----*/
#define CSL_UTOPIA2_UCR_MPHY_SINGLE_PHYMODE (0x00000000u)
#define CSL_UTOPIA2_UCR_MPHY_MULTI_PHYMODE (0x00000001u)

#define CSL_UTOPIA2_UCR_U16M_MASK (0x00002000u)
#define CSL_UTOPIA2_UCR_U16M_SHIFT (0x0000000Du)
#define CSL_UTOPIA2_UCR_U16M_RESETVAL (0x00000000u)
/*----U16M Tokens----*/
#define CSL_UTOPIA2_UCR_U16M_ (0x00000000u)
#define CSL_UTOPIA2_UCR_U16M_ (0x00000000u)


#define CSL_UTOPIA2_UCR_RUDC_MASK (0x0000003Cu)
#define CSL_UTOPIA2_UCR_RUDC_SHIFT (0x00000002u)
#define CSL_UTOPIA2_UCR_RUDC_RESETVAL (0x00000000u)
/*----RUDC Tokens----*/
#define CSL_UTOPIA2_UCR_RUDC_STANDARD (0x00000000u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER1 (0x00000001u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER2 (0x00000002u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER3 (0x00000003u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER4 (0x00000004u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER5 (0x00000005u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER6 (0x00000006u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER7 (0x00000007u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER8 (0x00000008u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER9 (0x00000009u)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER10 (0x0000000Au)
#define CSL_UTOPIA2_UCR_RUDC_EXTRAHEADER11 (0x0000000Bu)


#define CSL_UTOPIA2_UCR_UREN_MASK (0x00000001u)
#define CSL_UTOPIA2_UCR_UREN_SHIFT (0x00000000u)
#define CSL_UTOPIA2_UCR_UREN_RESETVAL (0x00000000u)
/*----UREN Tokens----*/
#define CSL_UTOPIA2_UCR_UREN_RX_PORT_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UCR_UREN_RX_PORT_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UCR_RESETVAL (0x40004000u)

/* PDR */


#define CSL_UTOPIA2_PDR_PHY30_MASK (0x40000000u)
#define CSL_UTOPIA2_PDR_PHY30_SHIFT (0x0000001Eu)
#define CSL_UTOPIA2_PDR_PHY30_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY29_MASK (0x20000000u)
#define CSL_UTOPIA2_PDR_PHY29_SHIFT (0x0000001Du)
#define CSL_UTOPIA2_PDR_PHY29_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY28_MASK (0x10000000u)
#define CSL_UTOPIA2_PDR_PHY28_SHIFT (0x0000001Cu)
#define CSL_UTOPIA2_PDR_PHY28_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY27_MASK (0x08000000u)
#define CSL_UTOPIA2_PDR_PHY27_SHIFT (0x0000001Bu)
#define CSL_UTOPIA2_PDR_PHY27_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY26_MASK (0x04000000u)
#define CSL_UTOPIA2_PDR_PHY26_SHIFT (0x0000001Au)
#define CSL_UTOPIA2_PDR_PHY26_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY25_MASK (0x02000000u)
#define CSL_UTOPIA2_PDR_PHY25_SHIFT (0x00000019u)
#define CSL_UTOPIA2_PDR_PHY25_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY24_MASK (0x01000000u)
#define CSL_UTOPIA2_PDR_PHY24_SHIFT (0x00000018u)
#define CSL_UTOPIA2_PDR_PHY24_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY23_MASK (0x00800000u)
#define CSL_UTOPIA2_PDR_PHY23_SHIFT (0x00000017u)
#define CSL_UTOPIA2_PDR_PHY23_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY22_MASK (0x00400000u)
#define CSL_UTOPIA2_PDR_PHY22_SHIFT (0x00000016u)
#define CSL_UTOPIA2_PDR_PHY22_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY21_MASK (0x00200000u)
#define CSL_UTOPIA2_PDR_PHY21_SHIFT (0x00000015u)
#define CSL_UTOPIA2_PDR_PHY21_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY20_MASK (0x00100000u)
#define CSL_UTOPIA2_PDR_PHY20_SHIFT (0x00000014u)
#define CSL_UTOPIA2_PDR_PHY20_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY19_MASK (0x00080000u)
#define CSL_UTOPIA2_PDR_PHY19_SHIFT (0x00000013u)
#define CSL_UTOPIA2_PDR_PHY19_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY18_MASK (0x00040000u)
#define CSL_UTOPIA2_PDR_PHY18_SHIFT (0x00000012u)
#define CSL_UTOPIA2_PDR_PHY18_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY17_MASK (0x00020000u)
#define CSL_UTOPIA2_PDR_PHY17_SHIFT (0x00000011u)
#define CSL_UTOPIA2_PDR_PHY17_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY16_MASK (0x00010000u)
#define CSL_UTOPIA2_PDR_PHY16_SHIFT (0x00000010u)
#define CSL_UTOPIA2_PDR_PHY16_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY15_MASK (0x00008000u)
#define CSL_UTOPIA2_PDR_PHY15_SHIFT (0x0000000Fu)
#define CSL_UTOPIA2_PDR_PHY15_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY14_MASK (0x00004000u)
#define CSL_UTOPIA2_PDR_PHY14_SHIFT (0x0000000Eu)
#define CSL_UTOPIA2_PDR_PHY14_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY13_MASK (0x00002000u)
#define CSL_UTOPIA2_PDR_PHY13_SHIFT (0x0000000Du)
#define CSL_UTOPIA2_PDR_PHY13_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY12_MASK (0x00001000u)
#define CSL_UTOPIA2_PDR_PHY12_SHIFT (0x0000000Cu)
#define CSL_UTOPIA2_PDR_PHY12_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY11_MASK (0x00000800u)
#define CSL_UTOPIA2_PDR_PHY11_SHIFT (0x0000000Bu)
#define CSL_UTOPIA2_PDR_PHY11_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY10_MASK (0x00000400u)
#define CSL_UTOPIA2_PDR_PHY10_SHIFT (0x0000000Au)
#define CSL_UTOPIA2_PDR_PHY10_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY9_MASK (0x00000200u)
#define CSL_UTOPIA2_PDR_PHY9_SHIFT (0x00000009u)
#define CSL_UTOPIA2_PDR_PHY9_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY8_MASK (0x00000100u)
#define CSL_UTOPIA2_PDR_PHY8_SHIFT (0x00000008u)
#define CSL_UTOPIA2_PDR_PHY8_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY7_MASK (0x00000080u)
#define CSL_UTOPIA2_PDR_PHY7_SHIFT (0x00000007u)
#define CSL_UTOPIA2_PDR_PHY7_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY6_MASK (0x00000040u)
#define CSL_UTOPIA2_PDR_PHY6_SHIFT (0x00000006u)
#define CSL_UTOPIA2_PDR_PHY6_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY5_MASK (0x00000020u)
#define CSL_UTOPIA2_PDR_PHY5_SHIFT (0x00000005u)
#define CSL_UTOPIA2_PDR_PHY5_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY4_MASK (0x00000010u)
#define CSL_UTOPIA2_PDR_PHY4_SHIFT (0x00000004u)
#define CSL_UTOPIA2_PDR_PHY4_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY3_MASK (0x00000008u)
#define CSL_UTOPIA2_PDR_PHY3_SHIFT (0x00000003u)
#define CSL_UTOPIA2_PDR_PHY3_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY2_MASK (0x00000004u)
#define CSL_UTOPIA2_PDR_PHY2_SHIFT (0x00000002u)
#define CSL_UTOPIA2_PDR_PHY2_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY1_MASK (0x00000002u)
#define CSL_UTOPIA2_PDR_PHY1_SHIFT (0x00000001u)
#define CSL_UTOPIA2_PDR_PHY1_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_PDR_PHY0_MASK (0x00000001u)
#define CSL_UTOPIA2_PDR_PHY0_SHIFT (0x00000000u)
#define CSL_UTOPIA2_PDR_PHY0_RESETVAL (0x00000000u)


#define CSL_UTOPIA2_PDR_RESETVAL (0x00000000u)

/* XCAPR */


#define CSL_UTOPIA2_XCAPR_CAP30_MASK (0x40000000u)
#define CSL_UTOPIA2_XCAPR_CAP30_SHIFT (0x0000001Eu)
#define CSL_UTOPIA2_XCAPR_CAP30_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP29_MASK (0x20000000u)
#define CSL_UTOPIA2_XCAPR_CAP29_SHIFT (0x0000001Du)
#define CSL_UTOPIA2_XCAPR_CAP29_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP28_MASK (0x10000000u)
#define CSL_UTOPIA2_XCAPR_CAP28_SHIFT (0x0000001Cu)
#define CSL_UTOPIA2_XCAPR_CAP28_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP27_MASK (0x08000000u)
#define CSL_UTOPIA2_XCAPR_CAP27_SHIFT (0x0000001Bu)
#define CSL_UTOPIA2_XCAPR_CAP27_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP26_MASK (0x04000000u)
#define CSL_UTOPIA2_XCAPR_CAP26_SHIFT (0x0000001Au)
#define CSL_UTOPIA2_XCAPR_CAP26_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP25_MASK (0x02000000u)
#define CSL_UTOPIA2_XCAPR_CAP25_SHIFT (0x00000019u)
#define CSL_UTOPIA2_XCAPR_CAP25_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP24_MASK (0x01000000u)
#define CSL_UTOPIA2_XCAPR_CAP24_SHIFT (0x00000018u)
#define CSL_UTOPIA2_XCAPR_CAP24_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP23_MASK (0x00800000u)
#define CSL_UTOPIA2_XCAPR_CAP23_SHIFT (0x00000017u)
#define CSL_UTOPIA2_XCAPR_CAP23_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP22_MASK (0x00400000u)
#define CSL_UTOPIA2_XCAPR_CAP22_SHIFT (0x00000016u)
#define CSL_UTOPIA2_XCAPR_CAP22_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP21_MASK (0x00200000u)
#define CSL_UTOPIA2_XCAPR_CAP21_SHIFT (0x00000015u)
#define CSL_UTOPIA2_XCAPR_CAP21_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP20_MASK (0x00100000u)
#define CSL_UTOPIA2_XCAPR_CAP20_SHIFT (0x00000014u)
#define CSL_UTOPIA2_XCAPR_CAP20_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP19_MASK (0x00080000u)
#define CSL_UTOPIA2_XCAPR_CAP19_SHIFT (0x00000013u)
#define CSL_UTOPIA2_XCAPR_CAP19_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP18_MASK (0x00040000u)
#define CSL_UTOPIA2_XCAPR_CAP18_SHIFT (0x00000012u)
#define CSL_UTOPIA2_XCAPR_CAP18_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP17_MASK (0x00020000u)
#define CSL_UTOPIA2_XCAPR_CAP17_SHIFT (0x00000011u)
#define CSL_UTOPIA2_XCAPR_CAP17_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP16_MASK (0x00010000u)
#define CSL_UTOPIA2_XCAPR_CAP16_SHIFT (0x00000010u)
#define CSL_UTOPIA2_XCAPR_CAP16_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP15_MASK (0x00008000u)
#define CSL_UTOPIA2_XCAPR_CAP15_SHIFT (0x0000000Fu)
#define CSL_UTOPIA2_XCAPR_CAP15_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP14_MASK (0x00004000u)
#define CSL_UTOPIA2_XCAPR_CAP14_SHIFT (0x0000000Eu)
#define CSL_UTOPIA2_XCAPR_CAP14_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP13_MASK (0x00002000u)
#define CSL_UTOPIA2_XCAPR_CAP13_SHIFT (0x0000000Du)
#define CSL_UTOPIA2_XCAPR_CAP13_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP12_MASK (0x00001000u)
#define CSL_UTOPIA2_XCAPR_CAP12_SHIFT (0x0000000Cu)
#define CSL_UTOPIA2_XCAPR_CAP12_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP11_MASK (0x00000800u)
#define CSL_UTOPIA2_XCAPR_CAP11_SHIFT (0x0000000Bu)
#define CSL_UTOPIA2_XCAPR_CAP11_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP10_MASK (0x00000400u)
#define CSL_UTOPIA2_XCAPR_CAP10_SHIFT (0x0000000Au)
#define CSL_UTOPIA2_XCAPR_CAP10_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP9_MASK (0x00000200u)
#define CSL_UTOPIA2_XCAPR_CAP9_SHIFT (0x00000009u)
#define CSL_UTOPIA2_XCAPR_CAP9_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP8_MASK (0x00000100u)
#define CSL_UTOPIA2_XCAPR_CAP8_SHIFT (0x00000008u)
#define CSL_UTOPIA2_XCAPR_CAP8_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP7_MASK (0x00000080u)
#define CSL_UTOPIA2_XCAPR_CAP7_SHIFT (0x00000007u)
#define CSL_UTOPIA2_XCAPR_CAP7_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP6_MASK (0x00000040u)
#define CSL_UTOPIA2_XCAPR_CAP6_SHIFT (0x00000006u)
#define CSL_UTOPIA2_XCAPR_CAP6_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP5_MASK (0x00000020u)
#define CSL_UTOPIA2_XCAPR_CAP5_SHIFT (0x00000005u)
#define CSL_UTOPIA2_XCAPR_CAP5_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP4_MASK (0x00000010u)
#define CSL_UTOPIA2_XCAPR_CAP4_SHIFT (0x00000004u)
#define CSL_UTOPIA2_XCAPR_CAP4_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP3_MASK (0x00000008u)
#define CSL_UTOPIA2_XCAPR_CAP3_SHIFT (0x00000003u)
#define CSL_UTOPIA2_XCAPR_CAP3_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP2_MASK (0x00000004u)
#define CSL_UTOPIA2_XCAPR_CAP2_SHIFT (0x00000002u)
#define CSL_UTOPIA2_XCAPR_CAP2_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP1_MASK (0x00000002u)
#define CSL_UTOPIA2_XCAPR_CAP1_SHIFT (0x00000001u)
#define CSL_UTOPIA2_XCAPR_CAP1_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_XCAPR_CAP0_MASK (0x00000001u)
#define CSL_UTOPIA2_XCAPR_CAP0_SHIFT (0x00000000u)
#define CSL_UTOPIA2_XCAPR_CAP0_RESETVAL (0x00000000u)


#define CSL_UTOPIA2_XCAPR_RESETVAL (0x00000000u)

/* UIER */


#define CSL_UTOPIA2_UIER_RQIE7_MASK (0x00800000u)
#define CSL_UTOPIA2_UIER_RQIE7_SHIFT (0x00000017u)
#define CSL_UTOPIA2_UIER_RQIE7_RESETVAL (0x00000000u)
/*----RQIE7 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE7_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE7_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE6_MASK (0x00400000u)
#define CSL_UTOPIA2_UIER_RQIE6_SHIFT (0x00000016u)
#define CSL_UTOPIA2_UIER_RQIE6_RESETVAL (0x00000000u)
/*----RQIE6 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE6_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE6_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE5_MASK (0x00200000u)
#define CSL_UTOPIA2_UIER_RQIE5_SHIFT (0x00000015u)
#define CSL_UTOPIA2_UIER_RQIE5_RESETVAL (0x00000000u)
/*----RQIE5 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE5_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE5_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE4_MASK (0x00100000u)
#define CSL_UTOPIA2_UIER_RQIE4_SHIFT (0x00000014u)
#define CSL_UTOPIA2_UIER_RQIE4_RESETVAL (0x00000000u)
/*----RQIE4 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE4_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE4_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE3_MASK (0x00080000u)
#define CSL_UTOPIA2_UIER_RQIE3_SHIFT (0x00000013u)
#define CSL_UTOPIA2_UIER_RQIE3_RESETVAL (0x00000000u)
/*----RQIE3 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE3_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE3_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE2_MASK (0x00040000u)
#define CSL_UTOPIA2_UIER_RQIE2_SHIFT (0x00000012u)
#define CSL_UTOPIA2_UIER_RQIE2_RESETVAL (0x00000000u)
/*----RQIE2 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE2_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE2_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE1_MASK (0x00020000u)
#define CSL_UTOPIA2_UIER_RQIE1_SHIFT (0x00000011u)
#define CSL_UTOPIA2_UIER_RQIE1_RESETVAL (0x00000000u)
/*----RQIE1 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE1_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE1_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RQIE0_MASK (0x00010000u)
#define CSL_UTOPIA2_UIER_RQIE0_SHIFT (0x00000010u)
#define CSL_UTOPIA2_UIER_RQIE0_RESETVAL (0x00000000u)
/*----RQIE0 Tokens----*/
#define CSL_UTOPIA2_UIER_RQIE0_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_RQIE0_ENABLE (0x00000001u)


#define CSL_UTOPIA2_UIER_XQIE7_MASK (0x00000080u)
#define CSL_UTOPIA2_UIER_XQIE7_SHIFT (0x00000007u)
#define CSL_UTOPIA2_UIER_XQIE7_RESETVAL (0x00000000u)
/*----XQIE7 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE7_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE7_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE6_MASK (0x00000040u)
#define CSL_UTOPIA2_UIER_XQIE6_SHIFT (0x00000006u)
#define CSL_UTOPIA2_UIER_XQIE6_RESETVAL (0x00000000u)
/*----XQIE5 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE6_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE6_ENABLE (0x00000001u)


#define CSL_UTOPIA2_UIER_XQIE5_MASK (0x00000020u)
#define CSL_UTOPIA2_UIER_XQIE5_SHIFT (0x00000005u)
#define CSL_UTOPIA2_UIER_XQIE5_RESETVAL (0x00000000u)
/*----XQIE5 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE5_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE5_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE4_MASK (0x00000010u)
#define CSL_UTOPIA2_UIER_XQIE4_SHIFT (0x00000004u)
#define CSL_UTOPIA2_UIER_XQIE4_RESETVAL (0x00000000u)
/*----XQIE4 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE4_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE4_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE3_MASK (0x00000008u)
#define CSL_UTOPIA2_UIER_XQIE3_SHIFT (0x00000003u)
#define CSL_UTOPIA2_UIER_XQIE3_RESETVAL (0x00000000u)
/*----XQIE3 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE3_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE3_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE2_MASK (0x00000004u)
#define CSL_UTOPIA2_UIER_XQIE2_SHIFT (0x00000002u)
#define CSL_UTOPIA2_UIER_XQIE2_RESETVAL (0x00000000u)
/*----XQIE2 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE2_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE2_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE1_MASK (0x00000002u)
#define CSL_UTOPIA2_UIER_XQIE1_SHIFT (0x00000001u)
#define CSL_UTOPIA2_UIER_XQIE1_RESETVAL (0x00000000u)
/*----XQIE1 Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE1_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE1_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_XQIE0_MASK (0x00000001u)
#define CSL_UTOPIA2_UIER_XQIE0_SHIFT (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE0_RESETVAL (0x00000000u)
/*----XQIE0  Tokens----*/
#define CSL_UTOPIA2_UIER_XQIE0_DISABLE (0x00000000u)
#define CSL_UTOPIA2_UIER_XQIE0_ENABLE (0x00000001u)

#define CSL_UTOPIA2_UIER_RESETVAL (0x00000000u)

/* UIPR */


#define CSL_UTOPIA2_UIPR_RQIP7_MASK (0x00800000u)
#define CSL_UTOPIA2_UIPR_RQIP7_SHIFT (0x00000017u)
#define CSL_UTOPIA2_UIPR_RQIP7_RESETVAL (0x00000000u)
/*----RQIP7 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP7_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP6_MASK (0x00400000u)
#define CSL_UTOPIA2_UIPR_RQIP6_SHIFT (0x00000016u)
#define CSL_UTOPIA2_UIPR_RQIP6_RESETVAL (0x00000000u)
/*----RQIP6 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP6_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP5_MASK (0x00200000u)
#define CSL_UTOPIA2_UIPR_RQIP5_SHIFT (0x00000015u)
#define CSL_UTOPIA2_UIPR_RQIP5_RESETVAL (0x00000000u)
/*----RQIP5 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP5_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP4_MASK (0x00100000u)
#define CSL_UTOPIA2_UIPR_RQIP4_SHIFT (0x00000014u)
#define CSL_UTOPIA2_UIPR_RQIP4_RESETVAL (0x00000000u)
/*----RQIP4 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP4_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP3_MASK (0x00080000u)
#define CSL_UTOPIA2_UIPR_RQIP3_SHIFT (0x00000013u)
#define CSL_UTOPIA2_UIPR_RQIP3_RESETVAL (0x00000000u)
/*----RQIP3 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP3_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP2_MASK (0x00040000u)
#define CSL_UTOPIA2_UIPR_RQIP2_SHIFT (0x00000012u)
#define CSL_UTOPIA2_UIPR_RQIP2_RESETVAL (0x00000000u)
/*----RQIP2 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP2_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP1_MASK (0x00020000u)
#define CSL_UTOPIA2_UIPR_RQIP1_SHIFT (0x00000011u)
#define CSL_UTOPIA2_UIPR_RQIP1_RESETVAL (0x00000000u)
/*----RQIP1 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP1_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RQIP0_MASK (0x00010000u)
#define CSL_UTOPIA2_UIPR_RQIP0_SHIFT (0x00000010u)
#define CSL_UTOPIA2_UIPR_RQIP0_RESETVAL (0x00000000u)
/*----RQIP0 Tokens----*/
#define CSL_UTOPIA2_UIPR_RQIP0_CLEAR (0x00000001u)


#define CSL_UTOPIA2_UIPR_XQIP7_MASK (0x00000080u)
#define CSL_UTOPIA2_UIPR_XQIP7_SHIFT (0x00000007u)
#define CSL_UTOPIA2_UIPR_XQIP7_RESETVAL (0x00000000u)
/*----XQIP7 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP7_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP6_MASK (0x00000040u)
#define CSL_UTOPIA2_UIPR_XQIP6_SHIFT (0x00000006u)
#define CSL_UTOPIA2_UIPR_XQIP6_RESETVAL (0x00000000u)
/*----XQIP6 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP6_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP5_MASK (0x00000020u)
#define CSL_UTOPIA2_UIPR_XQIP5_SHIFT (0x00000005u)
#define CSL_UTOPIA2_UIPR_XQIP5_RESETVAL (0x00000000u)
/*----XQIP5 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP5_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP4_MASK (0x00000010u)
#define CSL_UTOPIA2_UIPR_XQIP4_SHIFT (0x00000004u)
#define CSL_UTOPIA2_UIPR_XQIP4_RESETVAL (0x00000000u)
/*----XQIP4 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP4_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP3_MASK (0x00000008u)
#define CSL_UTOPIA2_UIPR_XQIP3_SHIFT (0x00000003u)
#define CSL_UTOPIA2_UIPR_XQIP3_RESETVAL (0x00000000u)
/*----XQIP3 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP3_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP2_MASK (0x00000004u)
#define CSL_UTOPIA2_UIPR_XQIP2_SHIFT (0x00000002u)
#define CSL_UTOPIA2_UIPR_XQIP2_RESETVAL (0x00000000u)
/*----XQIP2 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP2_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP1_MASK (0x00000002u)
#define CSL_UTOPIA2_UIPR_XQIP1_SHIFT (0x00000001u)
#define CSL_UTOPIA2_UIPR_XQIP1_RESETVAL (0x00000000u)
/*----XQIP1 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP1_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_XQIP0_MASK (0x00000001u)
#define CSL_UTOPIA2_UIPR_XQIP0_SHIFT (0x00000000u)
#define CSL_UTOPIA2_UIPR_XQIP0_RESETVAL (0x00000000u)
/*----XQIP0 Tokens----*/
#define CSL_UTOPIA2_UIPR_XQIP0_CLEAR (0x00000001u)

#define CSL_UTOPIA2_UIPR_RESETVAL (0x00000000u)

/* CDR */


#define CSL_UTOPIA2_CDR_XCCNT_MASK (0x00FF0000u)
#define CSL_UTOPIA2_CDR_XCCNT_SHIFT (0x00000010u)
#define CSL_UTOPIA2_CDR_XCCNT_RESETVAL (0x000000FFu)
/*----XCCNT Tokens----*/
#define CSL_UTOPIA2_CDR_XCCNT_DISABLE (0x00000000u)


#define CSL_UTOPIA2_CDR_RCCNT_MASK (0x000000FFu)
#define CSL_UTOPIA2_CDR_RCCNT_SHIFT (0x00000000u)
#define CSL_UTOPIA2_CDR_RCCNT_RESETVAL (0x000000FFu)
/*----RCCNT Tokens----*/
#define CSL_UTOPIA2_CDR_RCCNT_DISABLE (0x00000000u)

#define CSL_UTOPIA2_CDR_RESETVAL (0x00FF00FFu)

/* EIER */


#define CSL_UTOPIA2_EIER_XCPE_MASK (0x00040000u)
#define CSL_UTOPIA2_EIER_XCPE_SHIFT (0x00000012u)
#define CSL_UTOPIA2_EIER_XCPE_RESETVAL (0x00000000u)
/*----XCPE Tokens----*/
#define CSL_UTOPIA2_EIER_XCPE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_XCPE_ENABLE (0x00000001u)

#define CSL_UTOPIA2_EIER_XCFE_MASK (0x00020000u)
#define CSL_UTOPIA2_EIER_XCFE_SHIFT (0x00000011u)
#define CSL_UTOPIA2_EIER_XCFE_RESETVAL (0x00000000u)
/*----XCFE Tokens----*/
#define CSL_UTOPIA2_EIER_XCFE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_XCFE_ENABLE (0x00000001u)

#define CSL_UTOPIA2_EIER_XQSE_MASK (0x00010000u)
#define CSL_UTOPIA2_EIER_XQSE_SHIFT (0x00000010u)
#define CSL_UTOPIA2_EIER_XQSE_RESETVAL (0x00000000u)
/*----XQSE Tokens----*/
#define CSL_UTOPIA2_EIER_XQSE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_XQSE_ENABLE (0x00000001u)


#define CSL_UTOPIA2_EIER_RCPE_MASK (0x00000004u)
#define CSL_UTOPIA2_EIER_RCPE_SHIFT (0x00000002u)
#define CSL_UTOPIA2_EIER_RCPE_RESETVAL (0x00000000u)
/*----RCPE Tokens----*/
#define CSL_UTOPIA2_EIER_RCPE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_RCPE_ENABLE (0x00000001u)

#define CSL_UTOPIA2_EIER_RCFE_MASK (0x00000002u)
#define CSL_UTOPIA2_EIER_RCFE_SHIFT (0x00000001u)
#define CSL_UTOPIA2_EIER_RCFE_RESETVAL (0x00000000u)
/*----RCFE Tokens----*/
#define CSL_UTOPIA2_EIER_RCFE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_RCFE_ENABLE (0x00000001u)

#define CSL_UTOPIA2_EIER_RQSE_MASK (0x00000001u)
#define CSL_UTOPIA2_EIER_RQSE_SHIFT (0x00000000u)
#define CSL_UTOPIA2_EIER_RQSE_RESETVAL (0x00000000u)
/*----RQSE Tokens----*/
#define CSL_UTOPIA2_EIER_RQSE_DISABLE (0x00000000u)
#define CSL_UTOPIA2_EIER_RQSE_ENABLE (0x00000001u)

#define CSL_UTOPIA2_EIER_RESETVAL (0x00000000u)

/* EIPR */


#define CSL_UTOPIA2_EIPR_XCPP_MASK (0x00040000u)
#define CSL_UTOPIA2_EIPR_XCPP_SHIFT (0x00000012u)
#define CSL_UTOPIA2_EIPR_XCPP_RESETVAL (0x00000000u)
/*----XCPP Tokens----*/
#define CSL_UTOPIA2_EIPR_XCPP_CLEAR (0x00000000u)

#define CSL_UTOPIA2_EIPR_XCFP_MASK (0x00020000u)
#define CSL_UTOPIA2_EIPR_XCFP_SHIFT (0x00000011u)
#define CSL_UTOPIA2_EIPR_XCFP_RESETVAL (0x00000000u)
/*----XCFP Tokens----*/
#define CSL_UTOPIA2_EIPR_XCFP_CLEAR (0x00000000u)

#define CSL_UTOPIA2_EIPR_XQSP_MASK (0x00010000u)
#define CSL_UTOPIA2_EIPR_XQSP_SHIFT (0x00000010u)
#define CSL_UTOPIA2_EIPR_XQSP_RESETVAL (0x00000000u)


#define CSL_UTOPIA2_EIPR_RCPP_MASK (0x00000004u)
#define CSL_UTOPIA2_EIPR_RCPP_SHIFT (0x00000002u)
#define CSL_UTOPIA2_EIPR_RCPP_RESETVAL (0x00000000u)
/*----RCPP Tokens----*/
#define CSL_UTOPIA2_EIPR_RCPP_CLEAR (0x00000000u)

#define CSL_UTOPIA2_EIPR_RCFP_MASK (0x00000002u)
#define CSL_UTOPIA2_EIPR_RCFP_SHIFT (0x00000001u)
#define CSL_UTOPIA2_EIPR_RCFP_RESETVAL (0x00000000u)
/*----RCFP Tokens----*/
#define CSL_UTOPIA2_EIPR_RCFP_CLEAR (0x00000000u)

#define CSL_UTOPIA2_EIPR_RQSP_MASK (0x00000001u)
#define CSL_UTOPIA2_EIPR_RQSP_SHIFT (0x00000000u)
#define CSL_UTOPIA2_EIPR_RQSP_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_EIPR_RESETVAL (0x00000000u)

/* RMMR0 */

#define CSL_UTOPIA2_RMMR0_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR0_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR0_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR0_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR0_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR0_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR0_RESETVAL (0x00000000u)

/* RMMR1 */

#define CSL_UTOPIA2_RMMR1_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR1_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR1_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR1_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR1_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR1_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR1_RESETVAL (0x00000000u)

/* RMMR2 */

#define CSL_UTOPIA2_RMMR2_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR2_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR2_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR2_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR2_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR2_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR2_RESETVAL (0x00000000u)

/* RMMR3 */

#define CSL_UTOPIA2_RMMR3_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR3_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR3_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR3_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR3_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR3_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR3_RESETVAL (0x00000000u)

/* RMMR4 */

#define CSL_UTOPIA2_RMMR4_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR4_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR4_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR4_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR4_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR4_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR4_RESETVAL (0x00000000u)

/* RMMR5 */

#define CSL_UTOPIA2_RMMR5_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR5_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR5_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR5_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR5_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR5_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR5_RESETVAL (0x00000000u)

/* RMMR6 */

#define CSL_UTOPIA2_RMMR6_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR6_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR6_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR6_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR6_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR6_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR6_RESETVAL (0x00000000u)

/* RMMR7 */

#define CSL_UTOPIA2_RMMR7_MATCH_MASK (0xFFFF0000u)
#define CSL_UTOPIA2_RMMR7_MATCH_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RMMR7_MATCH_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR7_MASK_MASK (0x0000FFFFu)
#define CSL_UTOPIA2_RMMR7_MASK_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RMMR7_MASK_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RMMR7_RESETVAL (0x00000000u)

/* RRSR */


#define CSL_UTOPIA2_RRSR_RBYT_MASK (0x003F0000u)
#define CSL_UTOPIA2_RRSR_RBYT_SHIFT (0x00000010u)
#define CSL_UTOPIA2_RRSR_RBYT_RESETVAL (0x00000000u)


#define CSL_UTOPIA2_RRSR_RBIT_MASK (0x00000007u)
#define CSL_UTOPIA2_RRSR_RBIT_SHIFT (0x00000000u)
#define CSL_UTOPIA2_RRSR_RBIT_RESETVAL (0x00000000u)

#define CSL_UTOPIA2_RRSR_RESETVAL (0x00000000u)

#endif

